const plugin = require('tailwindcss/plugin');

module.exports = plugin(function ({ matchUtilities, addComponents }) {
    addComponents({
        '.icon': {
            '--bg-image': 'none',
            '--icon-size': `var(--icon-size-base)`,
            'min-height': `var(--line-height-base)`,
            'display': 'inline-flex',
            'align-items': 'center',
            'flex-flow': 'row',
            'background-image': 'none !important',
            'background-blend-mode': 'initial',

            '&::before': {
                'aspect-ratio': '1 / 1',
                'content': '" "',
                'display': 'inline-block',
                'background-color': 'currentColor',
                'width': `var(--icon-size)`,
                '-webkit-mask': `var(--icon-src)`,
                'mask': `var(--icon-src)`,
                'mask-repeat': 'no-repeat',
                '-webkit-mask-repeat': 'no-repeat',
                'mask-position': 'center',
                '-webkit-mask-position': 'center',
                'background-image': 'var(--bg-image)',
                'background-blend-mode': 'var(--bg-blend-mode)',
            }
        }
    })

    matchUtilities(
        {
            'icon': (value) => ({
                '--icon-src': value
            })
        },
        {
            values: {
                'zoom-out-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M13.5 7.5c0 1.477-.534 2.83-1.42 3.875a.65.65 0 0 1 .024.021l1.75 1.75a.5.5 0 0 1-.708.708l-1.75-1.75a.65.65 0 0 1-.02-.023A6 6 0 1 1 13.5 7.5Zm-8-.5a.5.5 0 0 0 0 1h4a.5.5 0 0 0 0-1h-4Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'zoom-out': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5 7.5a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1h-4a.5.5 0 0 1-.5-.5Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.25 7.5a6.25 6.25 0 1 1 11.009 4.052l1.595 1.594a.5.5 0 0 1-.708.708l-1.594-1.595A6.25 6.25 0 0 1 1.25 7.5ZM7.5 2.25a5.25 5.25 0 1 0 0 10.5 5.25 5.25 0 0 0 0-10.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'zoom-in-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M13.968 7.484a6.46 6.46 0 0 1-1.586 4.25.499.499 0 0 1 .171.112l2.358 2.358a.5.5 0 1 1-.707.707l-2.358-2.357a.499.499 0 0 1-.112-.172 6.484 6.484 0 1 1 2.234-4.897ZM7.984 5.126a.5.5 0 1 0-1 0v1.858H5.126a.5.5 0 1 0 0 1h1.858v1.858a.5.5 0 0 0 1 0V7.984h1.858a.5.5 0 0 0 0-1H7.984V5.126Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'zoom-in': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M7.484 4.626a.5.5 0 0 1 .5.5v1.858h1.858a.5.5 0 0 1 0 1H7.984v1.858a.5.5 0 0 1-1 0V7.984H5.126a.5.5 0 1 1 0-1h1.858V5.126a.5.5 0 0 1 .5-.5Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12.382 11.734a6.484 6.484 0 1 0-.648.648.5.5 0 0 0 .112.172l2.358 2.357a.5.5 0 1 0 .707-.707l-2.357-2.358a.5.5 0 0 0-.172-.112Zm-4.898 1.234A5.484 5.484 0 1 0 7.484 2a5.484 5.484 0 0 0 0 10.968Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'zap-off-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 18'%3e%3cpath fill='%230E1011' d='m9.814.979-1.14 5.696-2.278-2.279L9.814.98ZM12.557 10.557 9.35 7.35l5.15 1.404-1.943 1.803ZM10.635 12.342l4.261 4.262a.5.5 0 0 0 .708-.708l-14.5-14.5a.5.5 0 1 0-.708.708L4.543 6.25 1.537 9.256l5.837 1.591-1.881 6.27 5.142-4.775Z'/%3e%3c/svg%3e")`,
                'zap-off': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 18'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.814.979 8.74 6.348a.5.5 0 1 1-.98-.196l.426-2.13-1.082 1.082a.5.5 0 1 1-.708-.708L9.814.98Zm-9.418.417a.5.5 0 0 1 .708 0l14.5 14.5a.5.5 0 0 1-.708.707l-4.26-4.26-5.143 4.775 1.88-6.27-5.836-1.592L4.543 6.25.396 2.104a.5.5 0 0 1 0-.708ZM5.25 6.957 3.463 8.744l4.915 1.34L5.25 6.958Zm3.335 3.335-1.078 3.59 2.42-2.247-1.342-1.343ZM9.58 7.93a.5.5 0 0 1 .614-.35L14.5 8.753l-1.955 1.816a.5.5 0 1 1-.68-.733l.637-.591-2.57-.701a.5.5 0 0 1-.35-.614Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'zap-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 18'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.814.979 8.582 7.14l5.917 1.614-9.006 8.364 1.88-6.27-5.836-1.592L9.814.979ZM3.463 8.744l5.163 1.409-1.119 3.73 4.994-4.637L7.418 7.86l.768-3.839-4.723 4.723Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='m12.5 9.246-4.993 4.636 1.12-3.73-5.164-1.408 4.723-4.723-.768 3.839 5.083 1.386Z'/%3e%3c/svg%3e")`,
                'zap': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 18'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.814.979 8.582 7.14l5.917 1.614-9.006 8.364 1.88-6.27-5.836-1.592L9.814.979ZM3.463 8.744l5.163 1.409-1.119 3.73 4.994-4.637L7.418 7.86l.768-3.839-4.723 4.723Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'youtube-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.946 14h.26a99.934 99.934 0 0 0 2.301-.041 45.88 45.88 0 0 0 1.983-.098c.601-.046 1.16-.11 1.508-.207l.007-.002c.409-.12.777-.35 1.07-.665a2.503 2.503 0 0 0 .604-1.152c.217-1.26.325-2.54.32-3.82a22.008 22.008 0 0 0-.327-3.91c-.1-.42-.306-.806-.598-1.12a2.382 2.382 0 0 0-1.087-.67c-.343-.088-.899-.146-1.5-.188a50.24 50.24 0 0 0-1.98-.09A98.586 98.586 0 0 0 8.053 2h-.108a55.836 55.836 0 0 0-.703.005c-.46.005-1.087.016-1.75.036-.663.02-1.368.052-1.983.099-.601.045-1.16.109-1.508.206l-.007.002c-.409.12-.777.35-1.07.665a2.503 2.503 0 0 0-.604 1.152 22.01 22.01 0 0 0-.32 3.849 22.012 22.012 0 0 0 .33 3.924c.112.407.322.78.613 1.08.292.302.655.521 1.055.635l.003.001c.347.097.907.16 1.508.207.615.046 1.32.077 1.983.098a90.574 90.574 0 0 0 2.3.04h.153ZM6.765 5.076A.5.5 0 0 0 6 5.5v5a.5.5 0 0 0 .765.424l4-2.5a.5.5 0 0 0 0-.848l-4-2.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'youtube': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.765 5.076A.5.5 0 0 0 6 5.5v5a.5.5 0 0 0 .765.424l4-2.5a.5.5 0 0 0 0-.848l-4-2.5ZM9.557 8 7 9.598V6.402L9.557 8Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 2h-.054a55.836 55.836 0 0 0-.703.005c-.46.005-1.087.016-1.75.036-.663.02-1.368.052-1.983.099-.601.045-1.16.109-1.508.206l-.007.002c-.409.12-.777.35-1.07.665a2.503 2.503 0 0 0-.604 1.152 22.01 22.01 0 0 0-.32 3.849 22.012 22.012 0 0 0 .33 3.924c.112.407.322.78.613 1.08.292.302.655.521 1.055.635l.003.001c.347.097.907.16 1.508.207.615.046 1.32.077 1.983.098a90.574 90.574 0 0 0 2.3.04h.153L8 14h.206a99.934 99.934 0 0 0 2.301-.041 45.88 45.88 0 0 0 1.983-.098c.601-.046 1.16-.11 1.508-.207l.007-.002c.409-.12.777-.35 1.07-.665a2.503 2.503 0 0 0 .604-1.152c.217-1.26.325-2.54.32-3.82a22.008 22.008 0 0 0-.327-3.91c-.1-.42-.306-.806-.598-1.12a2.382 2.382 0 0 0-1.087-.67c-.343-.088-.899-.146-1.5-.188a50.24 50.24 0 0 0-1.98-.09A98.586 98.586 0 0 0 8.053 2H8Zm0 1h-.052a61.933 61.933 0 0 0-.694.005c-.456.005-1.075.015-1.73.036-.657.02-1.345.05-1.939.096-.605.046-1.07.104-1.31.17-.232.07-.445.202-.617.387-.169.182-.292.409-.354.658A21.012 21.012 0 0 0 1 8.012v.005a21.01 21.01 0 0 0 .302 3.68c.07.238.194.453.36.626.172.177.383.303.61.368.24.067.706.126 1.313.172.595.046 1.282.076 1.939.096a88.557 88.557 0 0 0 2.275.04h.15l.05.001H8.203a89.108 89.108 0 0 0 2.274-.04c.657-.021 1.344-.051 1.938-.097.606-.046 1.07-.104 1.311-.17.232-.07.445-.202.617-.387.169-.182.292-.408.354-.658.206-1.199.308-2.414.304-3.632V8.01a21.012 21.012 0 0 0-.304-3.687 1.502 1.502 0 0 0-.354-.659 1.382 1.382 0 0 0-.611-.384c-.246-.061-.712-.114-1.313-.156a49.247 49.247 0 0 0-1.94-.088A97.675 97.675 0 0 0 8.052 3H8Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'x-square-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 1A2.5 2.5 0 0 0 1 3.5v9A2.5 2.5 0 0 0 3.5 15h9a2.5 2.5 0 0 0 2.5-2.5v-9A2.5 2.5 0 0 0 12.5 1h-9Zm2.354 4.146a.5.5 0 1 0-.708.708L7.293 8l-2.147 2.146a.5.5 0 0 0 .708.708L8 8.707l2.146 2.147a.5.5 0 0 0 .708-.708L8.707 8l2.147-2.146a.5.5 0 0 0-.708-.708L8 7.293 5.854 5.146Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'x-square': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5.854 5.146a.5.5 0 1 0-.708.708L7.293 8l-2.147 2.146a.5.5 0 0 0 .708.708L8 8.707l2.146 2.147a.5.5 0 0 0 .708-.708L8.707 8l2.147-2.146a.5.5 0 0 0-.708-.708L8 7.293 5.854 5.146Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.25 1A2.25 2.25 0 0 0 1 3.25v9.5A2.25 2.25 0 0 0 3.25 15h9.5A2.25 2.25 0 0 0 15 12.75v-9.5A2.25 2.25 0 0 0 12.75 1h-9.5ZM2 3.25C2 2.56 2.56 2 3.25 2h9.5c.69 0 1.25.56 1.25 1.25v9.5c0 .69-.56 1.25-1.25 1.25h-9.5C2.56 14 2 13.44 2 12.75v-9.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'x-circle-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0ZM5.146 5.146a.5.5 0 0 1 .708 0L8 7.293l2.146-2.147a.5.5 0 0 1 .708.708L8.707 8l2.147 2.146a.5.5 0 0 1-.708.708L8 8.707l-2.146 2.147a.5.5 0 0 1-.708-.708L7.293 8 5.146 5.854a.5.5 0 0 1 0-.708Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'x-circle': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5.146 5.147a.5.5 0 0 1 .708 0L8 7.293l2.146-2.146a.5.5 0 0 1 .708.707L8.707 8l2.147 2.146a.5.5 0 0 1-.708.708L8 8.707l-2.146 2.147a.5.5 0 1 1-.708-.707L7.293 8 5.146 5.854a.5.5 0 0 1 0-.707Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'x': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M12.854 3.854a.5.5 0 0 0-.708-.708L8 7.293 3.854 3.146a.5.5 0 1 0-.708.708L7.293 8l-4.147 4.146a.5.5 0 0 0 .708.708L8 8.707l4.146 4.147a.5.5 0 0 0 .708-.708L8.707 8l4.147-4.146Z'/%3e%3c/svg%3e")`,
                'wrench-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m1.13 3.986.72.721A1 1 0 0 0 2.557 5H4a1 1 0 0 0 1-1V2.557a1 1 0 0 0-.293-.707l-.72-.72a4 4 0 0 1 4.801 5.159l5.694 5.693a1.768 1.768 0 1 1-2.5 2.5L6.288 8.788A4 4 0 0 1 1.13 3.986Zm10.724 7.16a.5.5 0 0 0-.708.708l1 1a.5.5 0 0 0 .708-.708l-1-1Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'wrench': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.834 2.005A1 1 0 0 1 5 2.557V4a1 1 0 0 1-1 1H2.557a1 1 0 0 1-.707-.293l-.72-.72a4.006 4.006 0 0 0-.12 1.294 4 4 0 0 0 5.278 3.507l5.694 5.694a1.768 1.768 0 1 0 2.5-2.5L8.788 6.288A4 4 0 0 0 3.987 1.13l.72.72a1 1 0 0 1 .127.156Zm1.126.152a2 2 0 0 1 .04.4V4a2 2 0 0 1-2 2H2.557a2 2 0 0 1-.4-.04 3.001 3.001 0 0 0 3.81 1.881l.588-.2 6.134 6.134a.768.768 0 1 0 1.086-1.086L7.641 6.555l.2-.589a3.001 3.001 0 0 0-1.882-3.81Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'wind': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5 4a2 2 0 1 1 2 2H1.5a.5.5 0 0 1 0-1H7a1 1 0 1 0-1-1v.095a.5.5 0 0 1-1 0V4Zm5 2a2.5 2.5 0 0 1 5 0v.25A2.75 2.75 0 0 1 12.25 9H1.5a.5.5 0 0 1 0-1h10.75A1.75 1.75 0 0 0 14 6.25V6a1.5 1.5 0 0 0-3 0v.05a.5.5 0 0 1-1 0V6Zm-9 5.5a.5.5 0 0 1 .5-.5H9a2 2 0 1 1-2 2v-.124a.5.5 0 1 1 1 0V13a1 1 0 1 0 1-1H1.5a.5.5 0 0 1-.5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'wifi-off': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M1.603 1.396a.5.5 0 1 0-.707.708l1.82 1.82A10.55 10.55 0 0 0 .096 6.089l.73.684A9.54 9.54 0 0 1 3.45 4.658L4.942 6.15a7.523 7.523 0 0 0-2.657 1.993l.73.684a6.514 6.514 0 0 1 2.693-1.912l1.633 1.633a4.496 4.496 0 0 0-2.863 1.65l.733.687a3.494 3.494 0 0 1 3.095-1.372l4.09 4.09a.5.5 0 0 0 .707-.707l-11.5-11.5ZM12.984 8.827A6.493 6.493 0 0 0 9.09 6.591L8 5.5a7.484 7.484 0 0 1 5.714 2.643l-.73.684ZM8 3.5c-.624 0-1.234.06-1.825.175L5.34 2.84C6.19 2.618 7.08 2.5 8 2.5c3.152 0 5.98 1.39 7.905 3.589l-.73.684A9.478 9.478 0 0 0 8 3.5Z'/%3e%3cpath fill='%230E1011' d='M9.684 11.921a1.998 1.998 0 0 0-3.368 0L8 13.5l1.684-1.579Z'/%3e%3c/svg%3e")`,
                'wifi': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M11.929 4.567a7.856 7.856 0 0 0-5.93-2.692A7.856 7.856 0 0 0 .072 4.567l.548.513a7.108 7.108 0 0 1 5.38-2.455c2.15 0 4.076.951 5.382 2.455l.548-.513Z'/%3e%3cpath fill='%230E1011' d='M10.286 6.107A5.613 5.613 0 0 0 6 4.125c-1.717 0-3.254.77-4.286 1.982l.548.514A4.865 4.865 0 0 1 6 4.875c1.501 0 2.844.678 3.738 1.746l.548-.514Z'/%3e%3cpath fill='%230E1011' d='M8.641 7.649A3.369 3.369 0 0 0 6 6.375c-1.07 0-2.023.498-2.641 1.274l.549.515A2.62 2.62 0 0 1 6 7.125a2.62 2.62 0 0 1 2.092 1.039l.55-.515Z'/%3e%3cpath fill='%230E1011' d='M7.263 8.94a1.499 1.499 0 0 0-2.526 0L6 10.126l1.263-1.184Z'/%3e%3c/svg%3e")`,
                'wifi': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M15.905 6.089A10.475 10.475 0 0 0 8 2.5C4.847 2.5 2.02 3.89.095 6.089l.73.684A9.478 9.478 0 0 1 8 3.5a9.478 9.478 0 0 1 7.175 3.273l.73-.684Z'/%3e%3cpath fill='%230E1011' d='M13.714 8.143A7.484 7.484 0 0 0 8 5.5a7.483 7.483 0 0 0-5.715 2.643l.73.684A6.486 6.486 0 0 1 8 6.5c2.001 0 3.792.905 4.984 2.327l.73-.684Z'/%3e%3cpath fill='%230E1011' d='M11.522 10.198A4.492 4.492 0 0 0 8 8.5a4.492 4.492 0 0 0-3.522 1.698l.733.687A3.494 3.494 0 0 1 8 9.5c1.138 0 2.15.543 2.789 1.385l.733-.687Z'/%3e%3cpath fill='%230E1011' d='M9.684 11.921a1.998 1.998 0 0 0-3.368 0L8 13.5l1.684-1.579Z'/%3e%3c/svg%3e")`,
                'wifi': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='black' fill-rule='evenodd' d='M15.553 6.447a9.986 9.986 0 0 0-3.726-2.686A10 10 0 0 0 .447 6.447l1.418 1.418a8 8 0 0 1 12.27 0l1.418-1.418Zm-2.84 2.84A5.99 5.99 0 0 0 8 7a5.99 5.99 0 0 0-4.713 2.287l1.429 1.429A3.995 3.995 0 0 1 8 9c1.36 0 2.562.679 3.284 1.716l1.43-1.43Zm-2.89 2.89a2 2 0 0 0-3.646 0L8 14l1.823-1.823Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'watch-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5.382 1.288 5.18 2.703C6.02 2.254 6.98 2 8 2c1.02 0 1.98.254 2.82.702l-.202-1.414A1.5 1.5 0 0 0 9.133 0H6.867a1.5 1.5 0 0 0-1.485 1.288ZM10.618 14.712l.202-1.415C9.98 13.746 9.02 14 8 14c-1.02 0-1.98-.254-2.82-.703l.202 1.415A1.5 1.5 0 0 0 6.867 16h2.266a1.5 1.5 0 0 0 1.485-1.288Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 3a5 5 0 1 1 0 10A5 5 0 0 1 8 3Zm-.354 4.646 2-2 .708.708L8.707 8l1.147 1.146-.708.708-1.5-1.5a.5.5 0 0 1 0-.708Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'watch': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='m9.646 5.646-2 2a.5.5 0 0 0 0 .708l1.5 1.5.708-.708L8.707 8l1.647-1.646-.708-.708Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5 4c0-.024.002-.047.005-.07l.377-2.642A1.5 1.5 0 0 1 6.867 0h2.266a1.5 1.5 0 0 1 1.485 1.288l.377 2.641A.51.51 0 0 1 11 4c1.214.913 2 2.365 2 4.001a4.992 4.992 0 0 1-2 4 .509.509 0 0 1-.005.07l-.377 2.642A1.5 1.5 0 0 1 9.133 16H6.867a1.5 1.5 0 0 1-1.485-1.288l-.377-2.641A.502.502 0 0 1 5 12 4.992 4.992 0 0 1 3 8c0-1.636.786-3.088 2-4Zm1.372-2.57A.5.5 0 0 1 6.867 1h2.266a.5.5 0 0 1 .495.43l.278 1.946A4.985 4.985 0 0 0 8 3c-.675 0-1.318.134-1.906.376l.278-1.947ZM8 13c.675 0 1.318-.134 1.906-.376l-.278 1.947a.5.5 0 0 1-.495.429H6.867a.5.5 0 0 1-.495-.43l-.278-1.946A4.986 4.986 0 0 0 8 13ZM4 8a4 4 0 1 1 8 0 4 4 0 0 1-8 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'wallet-send-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M13 4.5A2.5 2.5 0 0 0 10.5 2h-8A2.5 2.5 0 0 0 0 4.5v7A2.5 2.5 0 0 0 2.5 14h3.585A1.5 1.5 0 0 1 7.5 12h4.585A1.5 1.5 0 0 1 14 10.085V6.5c0-.818-.393-1.544-1-2ZM12 4H1.72c-.72 0-.332-.592.048-.845A.923.923 0 0 1 2.279 3h8.603a1 1 0 0 1 .895.553L12 4Zm-2 6a1 1 0 1 0 0-2 1 1 0 0 0 0 2Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M13.854 11.146a.5.5 0 0 0-.708.708L14.293 13H7.5a.5.5 0 0 0 0 1h6.793l-1.147 1.146a.5.5 0 0 0 .708.708l2-2a.5.5 0 0 0 0-.708l-2-2Z'/%3e%3c/svg%3e")`,
                'wallet-send': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.81 2a1.94 1.94 0 0 1 .087-.002l6.852-.01V2H10.5A2.5 2.5 0 0 1 13 4.5c.607.456 1 1.182 1 2v2a.5.5 0 0 1-1 0v-2A1.5 1.5 0 0 0 11.5 5H1.78c-.288 0-.555-.08-.78-.218V11.5A1.5 1.5 0 0 0 2.5 13h2a.5.5 0 0 1 0 1h-2A2.5 2.5 0 0 1 0 11.5V3.898a1.9 1.9 0 0 1 .939-1.64C1.18 2.095 1.472 2 1.78 2h.028Zm-.335 1.104A.5.5 0 0 0 1.781 4h10.134A1.5 1.5 0 0 0 10.5 3H1.838a.895.895 0 0 0-.363.104Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M11 9a1 1 0 1 1-2 0 1 1 0 0 1 2 0ZM15.854 13.146l-2-2a.5.5 0 0 0-.708.708L14.293 13H7.5a.5.5 0 0 0 0 1h6.793l-1.147 1.146a.5.5 0 0 0 .708.708l2-2a.5.5 0 0 0 0-.708Z'/%3e%3c/svg%3e")`,
                'wallet-receive-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M13 4.5A2.5 2.5 0 0 0 10.5 2h-8A2.5 2.5 0 0 0 0 4.5v7A2.5 2.5 0 0 0 2.5 14h3.318l-.44-.44L8.44 10.5a1.5 1.5 0 0 1 2.476 1.56h3.022c.041-.18.063-.367.063-.56v-5c0-.818-.393-1.544-1-2ZM12 4H2.024a.461.461 0 0 1-.256-.845A.923.923 0 0 1 2.279 3h8.603a1 1 0 0 1 .895.553L12 4Zm-2 5a1 1 0 1 0 0-2 1 1 0 0 0 0 2Zm-.854 2.146a.5.5 0 0 1 .708.708L8.707 13H15.5a.5.5 0 0 1 0 1H8.707l1.147 1.146a.5.5 0 0 1-.708.708l-2-2a.5.5 0 0 1 0-.708l2-2Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'wallet-receive': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m1.81 2 .087-.002 6.852-.01V2H10.5A2.5 2.5 0 0 1 13 4.5c.607.456 1 1.182 1 2v2a.5.5 0 0 1-1 0v-2A1.5 1.5 0 0 0 11.5 5H1.78c-.288 0-.555-.08-.78-.218V11.5A1.5 1.5 0 0 0 2.5 13h2a.5.5 0 0 1 0 1h-2A2.5 2.5 0 0 1 0 11.5V3.898a1.9 1.9 0 0 1 .939-1.64C1.18 2.095 1.472 2 1.78 2h.028Zm-.335 1.104A.5.5 0 0 0 1.781 4h10.134A1.5 1.5 0 0 0 10.5 3H1.838a.895.895 0 0 0-.363.104Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M10 10a1 1 0 1 0 0-2 1 1 0 0 0 0 2ZM9.146 11.146a.5.5 0 0 1 .708.708L8.707 13H15.5a.5.5 0 0 1 0 1H8.707l1.147 1.146a.5.5 0 0 1-.708.708L6.793 13.5l2.353-2.354Z'/%3e%3c/svg%3e")`,
                'wallet-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.288 1.18A1.5 1.5 0 0 1 2 1h10.75A2.25 2.25 0 0 1 15 3.25v.25c.607.456 1 1.182 1 2v7a2.5 2.5 0 0 1-2.5 2.5h-11A2.5 2.5 0 0 1 0 12.5V3.15c0-.88.53-1.638 1.288-1.97ZM2.15 2c-.148 0-.29.028-.42.079A.5.5 0 0 0 2 3h11.5c.165 0 .327.016.484.047A1.25 1.25 0 0 0 12.75 2H2.15ZM12 10a1 1 0 1 0 0-2 1 1 0 0 0 0 2Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'wallet': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M12 10a1 1 0 1 0 0-2 1 1 0 0 0 0 2Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2 1a1.5 1.5 0 0 0-.712.18A2.15 2.15 0 0 0 0 3.15v9.35A2.5 2.5 0 0 0 2.5 15h11a2.5 2.5 0 0 0 2.5-2.5v-7c0-.818-.393-1.544-1-2v-.25A2.25 2.25 0 0 0 12.75 1H2Zm-.27 1.079c.13-.051.272-.079.42-.079h10.6a1.25 1.25 0 0 1 1.234 1.047A2.514 2.514 0 0 0 13.5 3H2a.5.5 0 0 1-.27-.921ZM1 3.621V12.5A1.5 1.5 0 0 0 2.5 14h11a1.5 1.5 0 0 0 1.5-1.5v-7A1.5 1.5 0 0 0 13.5 4H2c-.399 0-.742-.147-1-.38Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'volume-x-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.691 2.038A.5.5 0 0 1 8 2.5v11a.5.5 0 0 1-.854.354L4.293 11H2a2 2 0 0 1-2-2V7a2 2 0 0 1 2-2h2.293l2.853-2.854a.5.5 0 0 1 .545-.108ZM7 3.708 4.707 6H2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2.707L7 12.293V3.707Zm3.146 1.438a.5.5 0 0 1 .708 0L13 7.293l2.146-2.147a.5.5 0 0 1 .708.708L13.707 8l2.147 2.146a.5.5 0 0 1-.708.708L13 8.707l-2.146 2.147a.5.5 0 0 1-.708-.707L12.293 8l-2.147-2.146a.5.5 0 0 1 0-.708Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1 7a1 1 0 0 1 1-1h2.707L7 3.707v8.586L4.707 10H2a1 1 0 0 1-1-1V7Z'/%3e%3c/svg%3e")`,
                'volume-x': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.691 2.038A.5.5 0 0 1 8 2.5v11a.5.5 0 0 1-.854.354L4.293 11H2a2 2 0 0 1-2-2V7a2 2 0 0 1 2-2h2.293l2.853-2.854a.5.5 0 0 1 .545-.108ZM7 3.708 4.707 6H2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2.707L7 12.293V3.707Zm3.146 1.438a.5.5 0 0 1 .708 0L13 7.293l2.146-2.147a.5.5 0 0 1 .708.708L13.707 8l2.147 2.146a.5.5 0 0 1-.708.708L13 8.707l-2.146 2.147a.5.5 0 0 1-.708-.707L12.293 8l-2.147-2.146a.5.5 0 0 1 0-.708Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'volume-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.691 2.038A.5.5 0 0 1 8 2.5v11a.5.5 0 0 1-.854.354L4.293 11H2a2 2 0 0 1-2-2V7a2 2 0 0 1 2-2h2.293l2.853-2.854a.5.5 0 0 1 .545-.108ZM7 3.708 4.707 6H2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2.707L7 12.293V3.707Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1 7a1 1 0 0 1 1-1h2.707L7 3.707v8.586L4.707 10H2a1 1 0 0 1-1-1V7Z'/%3e%3c/svg%3e")`,
                'volume-2-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.691 2.038A.5.5 0 0 1 8 2.5v11a.5.5 0 0 1-.854.354L4.293 11H1.25C.56 11 0 10.44 0 9.75v-3.5C0 5.56.56 5 1.25 5h3.043l2.853-2.854a.5.5 0 0 1 .545-.108ZM7 3.708 4.854 5.853A.5.5 0 0 1 4.5 6H1.25a.25.25 0 0 0-.25.25v3.5c0 .138.112.25.25.25H4.5a.5.5 0 0 1 .354.146L7 12.293V3.707Zm5.146 8.438a5.864 5.864 0 0 0 0-8.292l.708-.708a6.864 6.864 0 0 1 0 9.708l-.708-.707Zm-2-2a3.035 3.035 0 0 0 0-4.292l.708-.708a4.036 4.036 0 0 1 0 5.708l-.708-.707Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M4.854 5.854 7 3.707v8.586l-2.146-2.146A.5.5 0 0 0 4.5 10H1.25A.25.25 0 0 1 1 9.75v-3.5A.25.25 0 0 1 1.25 6H4.5a.5.5 0 0 0 .354-.146Z'/%3e%3c/svg%3e")`,
                'volume-2': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.691 2.038A.5.5 0 0 1 8 2.5v11a.5.5 0 0 1-.854.354L4.293 11H1.25C.56 11 0 10.44 0 9.75v-3.5C0 5.56.56 5 1.25 5h3.043l2.853-2.854a.5.5 0 0 1 .545-.108ZM7 3.708 4.854 5.853A.5.5 0 0 1 4.5 6H1.25a.25.25 0 0 0-.25.25v3.5c0 .138.112.25.25.25H4.5a.5.5 0 0 1 .354.146L7 12.293V3.707Zm5.146 8.438a5.864 5.864 0 0 0 0-8.292l.708-.708a6.864 6.864 0 0 1 0 9.708l-.708-.707Zm-2-2a3.035 3.035 0 0 0 0-4.292l.708-.708a4.036 4.036 0 0 1 0 5.708l-.708-.707Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'volume-1-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.691 2.038A.5.5 0 0 1 8 2.5v11a.5.5 0 0 1-.854.354L4.293 11H1.25C.56 11 0 10.44 0 9.75v-3.5C0 5.56.56 5 1.25 5h3.043l2.853-2.854a.5.5 0 0 1 .545-.108ZM7 3.708 4.854 5.853A.5.5 0 0 1 4.5 6H1.25a.25.25 0 0 0-.25.25v3.5c0 .138.112.25.25.25H4.5a.5.5 0 0 1 .354.146L7 12.293V3.707Zm3.146 6.438a3.035 3.035 0 0 0 0-4.292l.708-.708a4.036 4.036 0 0 1 0 5.708l-.708-.707Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M4.854 5.854 7 3.707v8.586l-2.146-2.146A.5.5 0 0 0 4.5 10H1.25A.25.25 0 0 1 1 9.75v-3.5A.25.25 0 0 1 1.25 6H4.5a.5.5 0 0 0 .354-.146Z'/%3e%3c/svg%3e")`,
                'volume-1': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.691 2.038A.5.5 0 0 1 8 2.5v11a.5.5 0 0 1-.854.354L4.293 11H1.25C.56 11 0 10.44 0 9.75v-3.5C0 5.56.56 5 1.25 5h3.043l2.853-2.854a.5.5 0 0 1 .545-.108ZM7 3.708 4.854 5.853A.5.5 0 0 1 4.5 6H1.25a.25.25 0 0 0-.25.25v3.5c0 .138.112.25.25.25H4.5a.5.5 0 0 1 .354.146L7 12.293V3.707Zm3.146 6.438a3.035 3.035 0 0 0 0-4.292l.708-.708a4.036 4.036 0 0 1 0 5.708l-.708-.707Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'volume': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.691 2.038A.5.5 0 0 1 8 2.5v11a.5.5 0 0 1-.854.354L4.293 11H2a2 2 0 0 1-2-2V7a2 2 0 0 1 2-2h2.293l2.853-2.854a.5.5 0 0 1 .545-.108ZM7 3.708 4.707 6H2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2.707L7 12.293V3.707Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'voicemail': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 7.5A3.5 3.5 0 1 1 5.95 10h4.1a3.5 3.5 0 1 1 2.268.995.512.512 0 0 1-.068.005h-8.5a.513.513 0 0 1-.068-.005A3.5 3.5 0 0 1 0 7.5ZM3.5 5a2.5 2.5 0 1 0 0 5 2.5 2.5 0 0 0 0-5ZM10 7.5a2.5 2.5 0 1 1 5 0 2.5 2.5 0 0 1-5 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'video-off-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M1.104.396a.5.5 0 1 0-.708.708L2.293 3H2.25A2.25 2.25 0 0 0 0 5.25v5.5A2.25 2.25 0 0 0 2.25 13h7.5c.696 0 1.318-.316 1.73-.812l3.416 3.416a.5.5 0 0 0 .708-.708L1.104.396ZM15.235 11.924l-.83-.518L12.5 9.5V5.785l2.735-1.709A.5.5 0 0 1 16 4.5v7a.5.5 0 0 1-.765.424ZM12 5.25V9L6 3h3.75A2.25 2.25 0 0 1 12 5.25Z'/%3e%3c/svg%3e")`,
                'video-off': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M1.854 1.146a.5.5 0 1 0-.708.708L2.293 3H2.25A2.25 2.25 0 0 0 0 5.25v5.5A2.25 2.25 0 0 0 2.25 13h8.25a.5.5 0 0 0 0-1H2.25C1.56 12 1 11.44 1 10.75v-5.5C1 4.56 1.56 4 2.25 4h1.043l10.853 10.854a.5.5 0 0 0 .708-.708l-13-13ZM9.75 3H6.5a.5.5 0 0 0 0 1h3.25c.69 0 1.25.56 1.25 1.25V8a.5.5 0 0 0 .83.376L15 5.602V11.5a.5.5 0 0 0 1 0v-7a.5.5 0 0 0-.83-.376L12 6.898V5.25A2.25 2.25 0 0 0 9.75 3Z'/%3e%3c/svg%3e")`,
                'video-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.25 4C1.56 4 1 4.56 1 5.25v5.5c0 .69.56 1.25 1.25 1.25h7.5c.69 0 1.25-.56 1.25-1.25v-5.5C11 4.56 10.44 4 9.75 4h-7.5ZM0 5.25A2.25 2.25 0 0 1 2.25 3h7.5A2.25 2.25 0 0 1 12 5.25v5.5A2.25 2.25 0 0 1 9.75 13h-7.5A2.25 2.25 0 0 1 0 10.75v-5.5Zm15.742-1.187A.5.5 0 0 1 16 4.5v7a.5.5 0 0 1-.765.424l-2.735-1.71V5.786l2.735-1.709a.5.5 0 0 1 .507-.013ZM13.5 6.34v3.32l1.5.938V5.402l-1.5.938Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M13.5 9.66V6.34l1.5-.938v5.196l-1.5-.938ZM1 5.25C1 4.56 1.56 4 2.25 4h7.5c.69 0 1.25.56 1.25 1.25v5.5c0 .69-.56 1.25-1.25 1.25h-7.5C1.56 12 1 11.44 1 10.75v-5.5Z'/%3e%3c/svg%3e")`,
                'video': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.25 4C1.56 4 1 4.56 1 5.25v5.5c0 .69.56 1.25 1.25 1.25h7.5c.69 0 1.25-.56 1.25-1.25v-5.5C11 4.56 10.44 4 9.75 4h-7.5ZM0 5.25A2.25 2.25 0 0 1 2.25 3h7.5A2.25 2.25 0 0 1 12 5.25v.848l3.235-2.022A.5.5 0 0 1 16 4.5v7a.5.5 0 0 1-.765.424L12 9.902v.848A2.25 2.25 0 0 1 9.75 13h-7.5A2.25 2.25 0 0 1 0 10.75v-5.5Zm12 3.473 3 1.875V5.402l-3 1.875v1.446Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'users-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6 9.5a3.5 3.5 0 1 0 0-7 3.5 3.5 0 0 0 0 7ZM.226 12.19.07 13.436A7.979 7.979 0 0 0 5.94 16a7.98 7.98 0 0 0 5.975-2.68l-.141-1.13A2.5 2.5 0 0 0 9.293 10H8.5l-1.572.629a2.5 2.5 0 0 1-1.857 0L3.5 10h-.793a2.5 2.5 0 0 0-2.48 2.19ZM7.314 1.173a5.002 5.002 0 0 1 3.618 5.681A3.502 3.502 0 0 0 9.929 0C8.89 0 7.956.453 7.314 1.173ZM13.354 12.703a8.027 8.027 0 0 0 2.49-1.884l-.141-1.13a2.5 2.5 0 0 0-2.48-2.189h-.794l-1.571.629c-.126.05-.256.09-.386.119-.064.126-.133.25-.207.37a4.001 4.001 0 0 1 3.002 3.386l.087.699Z'/%3e%3c/svg%3e")`,
                'users': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 2.5a3.5 3.5 0 1 0 0 7 3.5 3.5 0 0 0 0-7ZM3.5 6a2.5 2.5 0 1 1 5 0 2.5 2.5 0 0 1-5 0ZM2.707 10H3.5l1.571.629a2.5 2.5 0 0 0 1.857 0L8.5 10h.793a2.5 2.5 0 0 1 2.48 2.19l.142 1.13A7.98 7.98 0 0 1 5.939 16 7.979 7.979 0 0 1 .07 13.436l.156-1.246A2.5 2.5 0 0 1 2.706 10Zm3.232 5a6.973 6.973 0 0 1-4.816-1.92l.095-.766A1.5 1.5 0 0 1 2.707 11h.6l1.393.557a3.5 3.5 0 0 0 2.6 0L8.692 11h.6a1.5 1.5 0 0 1 1.49 1.314l.082.66A6.975 6.975 0 0 1 5.939 15Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M8.99 1.049a2.625 2.625 0 1 1 1.76 4.945.375.375 0 0 0 .234.712 3.375 3.375 0 1 0-3.525-5.505.375.375 0 1 0 .549.511c.273-.293.609-.52.983-.663ZM12.152 7.625l-1.5.546a2.11 2.11 0 0 1-.662.126.375.375 0 1 0 .021.75 2.86 2.86 0 0 0 .897-.17l1.376-.502h.66c.995 0 1.786.67 1.9 1.5l.104.757a6.98 6.98 0 0 1-2.075 1.378.375.375 0 0 0 .299.688 7.704 7.704 0 0 0 2.44-1.67l.13-.13-.155-1.124c-.172-1.254-1.328-2.149-2.643-2.149h-.792Z'/%3e%3c/svg%3e")`,
                'user-x-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M12 4a4 4 0 1 1-8 0 4 4 0 0 1 8 0ZM8 9v7a7.99 7.99 0 0 1-6.52-3.363l.213-1.49A2.5 2.5 0 0 1 4.168 9H8ZM10.354 9.646a.5.5 0 0 0-.708.708l2.147 2.146-2.147 2.146a.5.5 0 0 0 .708.708l2.146-2.147 2.146 2.147a.5.5 0 0 0 .708-.708L13.207 12.5l2.147-2.146a.5.5 0 0 0-.708-.708L12.5 11.793l-2.146-2.147Z'/%3e%3c/svg%3e")`,
                'user-x': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 4a4 4 0 1 1-8 0 4 4 0 0 1 8 0Zm-1 0a3 3 0 1 1-6 0 3 3 0 0 1 6 0Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M8 9v1H4.168a1.5 1.5 0 0 0-1.485 1.288l-.154 1.08A6.986 6.986 0 0 0 8 15v1a7.99 7.99 0 0 1-6.52-3.363l.213-1.49A2.5 2.5 0 0 1 4.168 9H8ZM10.354 9.646a.5.5 0 0 0-.708.708l2.147 2.146-2.147 2.146a.5.5 0 0 0 .708.708l2.146-2.147 2.146 2.147a.5.5 0 0 0 .708-.708L13.207 12.5l2.147-2.146a.5.5 0 0 0-.708-.708L12.5 11.793l-2.146-2.147Z'/%3e%3c/svg%3e")`,
                'user-plus-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M12 4a4 4 0 1 1-8 0 4 4 0 0 1 8 0ZM4.168 9a2.5 2.5 0 0 0-2.475 2.146l-.213 1.491A7.99 7.99 0 0 0 8 16a8.05 8.05 0 0 0 1.505-.141A4.49 4.49 0 0 1 8 12.5c0-1.414.652-2.675 1.671-3.5H4.168Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 12.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0ZM12.5 10a.5.5 0 0 1 .5.5V12h1.5a.5.5 0 0 1 0 1H13v1.75a.5.5 0 0 1-1 0V13h-1.5a.5.5 0 0 1 0-1H12v-1.5a.5.5 0 0 1 .5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'user-plus': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 4a4 4 0 1 1-8 0 4 4 0 0 1 8 0Zm-1 0a3 3 0 1 1-6 0 3 3 0 0 1 6 0Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M8 15a6.986 6.986 0 0 1-5.47-2.633l.153-1.08A1.5 1.5 0 0 1 4.168 10h4.59c.253-.378.561-.715.913-1H4.168a2.5 2.5 0 0 0-2.475 2.146l-.213 1.491A7.99 7.99 0 0 0 8 16a8.05 8.05 0 0 0 1.505-.141 4.522 4.522 0 0 1-.772-.897C8.492 14.987 8.247 15 8 15Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 12.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0ZM12.5 10a.5.5 0 0 1 .5.5V12h1.5a.5.5 0 0 1 0 1H13v1.75a.5.5 0 0 1-1 0V13h-1.5a.5.5 0 0 1 0-1H12v-1.5a.5.5 0 0 1 .5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'user-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 4a4 4 0 1 1-8 0 4 4 0 0 1 8 0ZM4.168 9H5.5l1.382.691a2.5 2.5 0 0 0 2.236 0L10.5 9h1.332a2.5 2.5 0 0 1 2.475 2.146l.213 1.491A7.99 7.99 0 0 1 8 16a7.99 7.99 0 0 1-6.52-3.363l.213-1.49A2.5 2.5 0 0 1 4.168 9Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'user-circle-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='none'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0ZM8 9a3 3 0 1 0 0-6 3 3 0 0 0 0 6Zm-.005 5.3c1.937 0 3.67-.875 4.825-2.25l-.088-.442A2 2 0 0 0 10.77 10h-.534a1.5 1.5 0 0 0-.67.159l-.448.223a2.5 2.5 0 0 1-2.236 0l-.447-.223A1.5 1.5 0 0 0 5.764 10H5.23a2 2 0 0 0-1.961 1.608l-.09.452a6.286 6.286 0 0 0 4.816 2.24Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'user-circle': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='none'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11 6a3 3 0 1 1-6 0 3 3 0 0 1 6 0Zm-1 0a2 2 0 1 1-4 0 2 2 0 0 1 4 0Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-3.326 4.889a6.273 6.273 0 0 1-3.973 1.41 6.273 6.273 0 0 1-3.964-1.403l.218-1.092A1 1 0 0 1 5.23 11h.535a.5.5 0 0 1 .224.053l.447.223a3.5 3.5 0 0 0 3.13 0l.447-.223a.5.5 0 0 1 .224-.053h.534a1 1 0 0 1 .98.804l.218 1.085Zm.852-.839-.088-.442A2 2 0 0 0 10.77 10h-.534a1.5 1.5 0 0 0-.67.159l-.448.223a2.5 2.5 0 0 1-2.236 0l-.447-.223A1.5 1.5 0 0 0 5.764 10H5.23a2 2 0 0 0-1.961 1.608l-.09.452a6.3 6.3 0 1 1 9.642-.01Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'user-check-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M12 4a4 4 0 1 1-8 0 4 4 0 0 1 8 0ZM8 9v7a7.99 7.99 0 0 1-6.52-3.363l.213-1.49A2.5 2.5 0 0 1 4.168 9H8ZM15.854 11.854a.5.5 0 0 0-.708-.708L11.5 14.793l-1.646-1.647a.5.5 0 0 0-.708.708l2 2a.5.5 0 0 0 .708 0l4-4Z'/%3e%3c/svg%3e")`,
                'user-check': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 4a4 4 0 1 1-8 0 4 4 0 0 1 8 0Zm-1 0a3 3 0 1 1-6 0 3 3 0 0 1 6 0Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M8 9v1H4.168a1.5 1.5 0 0 0-1.485 1.288l-.154 1.08A6.986 6.986 0 0 0 8 15v1a7.99 7.99 0 0 1-6.52-3.363l.213-1.49A2.5 2.5 0 0 1 4.168 9H8ZM15.854 11.854a.5.5 0 0 0-.708-.708L11.5 14.793l-1.646-1.647a.5.5 0 0 0-.708.708l2 2a.5.5 0 0 0 .708 0l4-4Z'/%3e%3c/svg%3e")`,
                'user': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 4a4 4 0 1 1-8 0 4 4 0 0 1 8 0Zm-1 0a3 3 0 1 1-6 0 3 3 0 0 1 6 0ZM4.168 9H5.5l1.382.691a2.5 2.5 0 0 0 2.236 0L10.5 9h1.332a2.5 2.5 0 0 1 2.475 2.146l.213 1.491A7.99 7.99 0 0 1 8 16a7.99 7.99 0 0 1-6.52-3.363l.213-1.49A2.5 2.5 0 0 1 4.168 9ZM8 15a6.986 6.986 0 0 1-5.47-2.633l.153-1.08A1.5 1.5 0 0 1 4.168 10h1.096l1.17.585a3.5 3.5 0 0 0 3.131 0L10.736 10h1.096a1.5 1.5 0 0 1 1.485 1.288l.154 1.08A6.986 6.986 0 0 1 8 15Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'upload-cloud': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M1 8a5 5 0 0 1 9.829-1.302l.121.452.46-.092a3 3 0 0 1 2.305 5.405.5.5 0 1 0 .571.82 4 4 0 0 0-2.623-7.269A6.002 6.002 0 0 0 0 8a5.996 5.996 0 0 0 2.727 5.03.5.5 0 0 0 .546-.838A4.995 4.995 0 0 1 1 8Z'/%3e%3cpath fill='%230E1011' d='M9 9.707V15.5a.5.5 0 0 1-1 0V9.707l-2.146 2.147a.5.5 0 0 1-.708-.708L8.5 7.793l3.354 3.353a.5.5 0 0 1-.708.708L9 9.707Z'/%3e%3c/svg%3e")`,
                'upload': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8.5 2.914v8.793a.5.5 0 0 1-1 0V2.914L5.354 5.061a.5.5 0 1 1-.708-.707L8 1l3.354 3.354a.5.5 0 0 1-.708.707L8.5 2.914Z'/%3e%3cpath fill='%230E1011' d='M2 10.5a.5.5 0 0 0-1 0v3.25c0 .69.56 1.25 1.25 1.25h11.5c.69 0 1.25-.56 1.25-1.25V10.5a.5.5 0 0 0-1 0v3.25a.25.25 0 0 1-.25.25H2.25a.25.25 0 0 1-.25-.25V10.5Z'/%3e%3c/svg%3e")`,
                'unlock-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 0a4 4 0 0 0-4 4v2a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2H5V4a3 3 0 0 1 6 0v.25a.5.5 0 0 0 1 0V4a4 4 0 0 0-4-4ZM7 10.5a1 1 0 1 1 2 0 1 1 0 0 1-2 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'unlock': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M7 10.5a1 1 0 1 1 2 0 1 1 0 0 1-2 0Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 0a4 4 0 0 0-4 4v2a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2H5V4a3 3 0 0 1 6 0v.25a.5.5 0 0 0 1 0V4a4 4 0 0 0-4-4ZM4 7a1 1 0 0 0-1 1v6a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V8a1 1 0 0 0-1-1H4Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'underline': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M3.25 2a.5.5 0 0 0 0 1h.25v5.5a4.5 4.5 0 1 0 9 0V3h.25a.5.5 0 0 0 0-1h-1.5a.5.5 0 0 0 0 1h.25v5.5a3.5 3.5 0 1 1-7 0V3h.25a.5.5 0 0 0 0-1h-1.5ZM3.5 14a.5.5 0 0 0 0 1h9a.5.5 0 0 0 0-1h-9Z'/%3e%3c/svg%3e")`,
                'undo': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M14.28 10c0 1.726-1.399 3.125-3.125 3.125h-1.5a.375.375 0 0 0 0 .75h1.5a3.875 3.875 0 0 0 0-7.75H2.532l2.74-2.866a.375.375 0 1 0-.543-.518L1.137 6.5l3.592 3.76a.375.375 0 0 0 .542-.52L2.532 6.876h8.623c1.726 0 3.125 1.4 3.125 3.125Z'/%3e%3c/svg%3e")`,
                'umbrella-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.233 9H8v3.5a1.5 1.5 0 0 0 3 0v-.25a.5.5 0 0 1 1 0v.25a2.5 2.5 0 0 1-5 0V9H.767a.5.5 0 0 1-.499-.466 7.75 7.75 0 1 1 15.464 0 .5.5 0 0 1-.499.466ZM4.104 4.118A5.481 5.481 0 0 1 8 2.5a.5.5 0 0 0 0-1 6.481 6.481 0 0 0-4.604 1.912.5.5 0 1 0 .708.706Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'umbrella': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M4.516 4.53A5.606 5.606 0 0 1 8.5 2.874a.375.375 0 1 0 0-.75A6.356 6.356 0 0 0 3.984 4a.375.375 0 1 0 .532.53Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.233 9H8v3.5a1.5 1.5 0 0 0 3 0v-.25a.5.5 0 0 1 1 0v.25a2.5 2.5 0 0 1-5 0V9H.767a.5.5 0 0 1-.499-.466 7.75 7.75 0 1 1 15.464 0 .5.5 0 0 1-.499.466ZM8 1.25A6.75 6.75 0 0 0 1.25 8h13.5A6.75 6.75 0 0 0 8 1.25Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'type': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 3v1.5a.5.5 0 0 1-1 0V2.75A.75.75 0 0 1 3.25 2h9.5a.75.75 0 0 1 .75.75V4.5a.5.5 0 0 1-1 0V3h-4v10h1a.5.5 0 0 1 0 1h-3a.5.5 0 0 1 0-1h1V3h-4Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'twitter-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.576 2.23a3.486 3.486 0 0 1 3.64.724 6.768 6.768 0 0 0 1.663-.856.5.5 0 0 1 .774.527 5.648 5.648 0 0 1-1.342 2.498 3.5 3.5 0 0 1 .022.382v.002c0 4.008-1.926 6.933-4.681 8.4-2.743 1.46-6.257 1.447-9.395-.297a.5.5 0 0 1 .263-.936 7.26 7.26 0 0 0 3.608-.798c-1.122-.637-1.906-1.412-2.436-2.248C1.042 8.602.795 7.512.751 6.53a8.568 8.568 0 0 1 .275-2.502 8.558 8.558 0 0 1 .315-.973 3.72 3.72 0 0 1 .025-.059l.007-.017.002-.005v-.002l.458.202-.457-.203a.5.5 0 0 1 .867-.084 6.607 6.607 0 0 0 5.09 2.802V5.53a3.487 3.487 0 0 1 2.243-3.3ZM2.016 4.2a7.57 7.57 0 0 0-.266 2.284c.038.85.25 1.761.787 2.61.535.844 1.413 1.658 2.833 2.29a.5.5 0 0 1 .077.87 8.26 8.26 0 0 1-2.948 1.25c2.346.765 4.747.55 6.683-.48 2.411-1.284 4.151-3.859 4.151-7.516 0-.155-.015-.309-.044-.46a.5.5 0 0 1 .14-.45c.288-.284.536-.603.74-.948a7.765 7.765 0 0 1-.952.355.5.5 0 0 1-.521-.15A2.486 2.486 0 0 0 8.333 5.52v.673a.5.5 0 0 1-.487.5A7.607 7.607 0 0 1 2.016 4.2Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='m1.994 4.278.021-.078a7.607 7.607 0 0 0 5.831 2.493.5.5 0 0 0 .487-.5V5.52a2.487 2.487 0 0 1 4.363-1.665.5.5 0 0 0 .521.15c.325-.097.643-.216.951-.355a4.645 4.645 0 0 1-.74.947.5.5 0 0 0-.14.45c.03.152.045.306.045.46 0 3.658-1.74 6.233-4.151 7.517-1.936 1.03-4.337 1.245-6.683.48a8.26 8.26 0 0 0 2.948-1.25.5.5 0 0 0-.077-.87c-1.42-.632-2.298-1.446-2.833-2.29-.537-.849-.749-1.76-.788-2.61a7.57 7.57 0 0 1 .245-2.206Z'/%3e%3c/svg%3e")`,
                'twitter': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.576 2.23a3.486 3.486 0 0 1 3.64.724 6.768 6.768 0 0 0 1.663-.856.5.5 0 0 1 .774.527 5.648 5.648 0 0 1-1.342 2.498 3.5 3.5 0 0 1 .022.382v.002c0 4.008-1.926 6.933-4.681 8.4-2.743 1.46-6.257 1.447-9.395-.297a.5.5 0 0 1 .263-.936 7.26 7.26 0 0 0 3.608-.798c-1.122-.637-1.906-1.412-2.436-2.248C1.042 8.602.795 7.512.751 6.53a8.568 8.568 0 0 1 .275-2.502 8.558 8.558 0 0 1 .315-.973 3.72 3.72 0 0 1 .025-.059l.007-.017.002-.005v-.002l.458.202-.457-.203a.5.5 0 0 1 .867-.084 6.607 6.607 0 0 0 5.09 2.802V5.53a3.487 3.487 0 0 1 2.243-3.3ZM2.016 4.2a7.57 7.57 0 0 0-.266 2.284c.038.85.25 1.761.787 2.61.535.844 1.413 1.658 2.833 2.29a.5.5 0 0 1 .077.87 8.26 8.26 0 0 1-2.948 1.25c2.346.765 4.747.55 6.683-.48 2.411-1.284 4.151-3.859 4.151-7.516 0-.155-.015-.309-.044-.46a.5.5 0 0 1 .14-.45c.288-.284.536-.603.74-.948a7.765 7.765 0 0 1-.952.355.5.5 0 0 1-.521-.15A2.486 2.486 0 0 0 8.333 5.52v.673a.5.5 0 0 1-.487.5A7.607 7.607 0 0 1 2.016 4.2Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'tv-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.884.18a.5.5 0 1 0-.768.64L6.932 3H2.25A2.25 2.25 0 0 0 0 5.25v6.5A2.25 2.25 0 0 0 2.25 14h11.5A2.25 2.25 0 0 0 16 11.75v-6.5A2.25 2.25 0 0 0 13.75 3H9.068L10.884.82a.5.5 0 0 0-.768-.64L8 2.719 5.884.179ZM2.625 6.25c0-.345.28-.625.625-.625h1a.375.375 0 1 0 0-.75h-1c-.76 0-1.375.616-1.375 1.375v1a.375.375 0 1 0 .75 0v-1Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'tv': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M2.625 6.25c0-.345.28-.625.625-.625h1a.375.375 0 1 0 0-.75h-1c-.76 0-1.375.616-1.375 1.375v1a.375.375 0 1 0 .75 0v-1Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.884.18a.5.5 0 1 0-.768.64L6.932 3H2.25A2.25 2.25 0 0 0 0 5.25v6.5A2.25 2.25 0 0 0 2.25 14h11.5A2.25 2.25 0 0 0 16 11.75v-6.5A2.25 2.25 0 0 0 13.75 3H9.068L10.884.82a.5.5 0 0 0-.768-.64L8 2.719 5.884.179ZM1 5.25C1 4.56 1.56 4 2.25 4h11.5c.69 0 1.25.56 1.25 1.25v6.5c0 .69-.56 1.25-1.25 1.25H2.25C1.56 13 1 12.44 1 11.75v-6.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'truck-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 2a1 1 0 0 0-1 1v8h10.5V3a1 1 0 0 0-1-1H1Zm0 2.25A.25.25 0 0 1 1.25 4h3.5a.25.25 0 0 1 0 .5h-3.5A.25.25 0 0 1 1 4.25Zm4.75 0A.25.25 0 0 1 6 4h1.25a.25.25 0 0 1 0 .5H6a.25.25 0 0 1-.25-.25Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M12.5 5.5H11V11h5V9a3.5 3.5 0 0 0-3.5-3.5ZM6 12.5a2 2 0 1 1-3.937-.5h3.874c.041.16.063.327.063.5ZM13.5 12.5a2 2 0 1 1-3.937-.5h3.874c.041.16.063.327.063.5Z'/%3e%3c/svg%3e")`,
                'truck': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6 4a.25.25 0 0 0 0 .5h1.25a.25.25 0 0 0 0-.5H6Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 3a1 1 0 0 1 1-1h9a1 1 0 0 1 1 1v2.5h1.5A3.5 3.5 0 0 1 16 9v3h-2.563a2.001 2.001 0 0 1-1.937 2.5A2 2 0 0 1 9.563 12H5.937A2.002 2.002 0 0 1 4 14.5 2 2 0 0 1 2.063 12H1a1 1 0 0 1-1-1V3Zm11 8h4V9a2.5 2.5 0 0 0-2.5-2.5H11V11Zm-.366 1a1 1 0 1 0 1.733 0h-1.733Zm-7.5 0h1.732a1 1 0 1 1-1.733 0ZM10 11H1V4.5h3.75a.25.25 0 0 0 0-.5H1V3h9v8Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'triangle-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6.453 1.921C7.111.68 8.89.68 9.547 1.921l6.093 11.51A1.75 1.75 0 0 1 14.093 16H1.907A1.75 1.75 0 0 1 .36 13.431l6.093-11.51Z'/%3e%3c/svg%3e")`,
                'triangle': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.547.921C8.889-.32 7.11-.32 6.453.921L.36 12.431A1.75 1.75 0 0 0 1.907 15h12.186a1.75 1.75 0 0 0 1.547-2.569L9.547.921Zm5.21 11.978L8.662 1.389a.75.75 0 0 0-1.326 0L1.244 12.9a.75.75 0 0 0 .663 1.1h12.186a.75.75 0 0 0 .663-1.1Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'trending-up-square-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 1A2.5 2.5 0 0 0 1 3.5v9A2.5 2.5 0 0 0 3.5 15h9a2.5 2.5 0 0 0 2.5-2.5v-9A2.5 2.5 0 0 0 12.5 1h-9Zm3 7.207-2.646 2.647a.5.5 0 0 1-.708-.708L5.97 7.323a.75.75 0 0 1 1.06 0l1.47 1.47L11.293 6H9.5a.5.5 0 0 1 0-1H13v3.5a.5.5 0 0 1-1 0V6.707l-2.97 2.97a.75.75 0 0 1-1.06 0L6.5 8.207Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'trending-up-square': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 2h9A1.5 1.5 0 0 1 14 3.5v9a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 2 12.5v-9A1.5 1.5 0 0 1 3.5 2ZM1 3.5A2.5 2.5 0 0 1 3.5 1h9A2.5 2.5 0 0 1 15 3.5v9a2.5 2.5 0 0 1-2.5 2.5h-9A2.5 2.5 0 0 1 1 12.5v-9Zm5.5 4.707-2.646 2.647a.5.5 0 0 1-.708-.708L5.97 7.323a.75.75 0 0 1 1.06 0l1.47 1.47L11.293 6H9.5a.5.5 0 0 1 0-1H13v3.5a.5.5 0 0 1-1 0V6.707l-2.97 2.97a.75.75 0 0 1-1.06 0L6.5 8.207Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'trending-up': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.146 12.854a.5.5 0 0 0 .708 0L6.5 7.207l2.646 2.647a.5.5 0 0 0 .708 0L15 4.707V7.5a.5.5 0 0 0 1 0v-4a.5.5 0 0 0-.5-.5h-4a.5.5 0 0 0 0 1h2.793L9.5 8.793 6.854 6.146a.5.5 0 0 0-.708 0l-6 6a.5.5 0 0 0 0 .708Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'trending-down-square-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 1A2.5 2.5 0 0 0 1 3.5v9A2.5 2.5 0 0 0 3.5 15h9a2.5 2.5 0 0 0 2.5-2.5v-9A2.5 2.5 0 0 0 12.5 1h-9Zm3 6.793L3.854 5.146a.5.5 0 1 0-.708.708L5.97 8.677a.75.75 0 0 0 1.06 0l1.47-1.47L11.293 10H9.5a.5.5 0 0 0 0 1H13V7.5a.5.5 0 0 0-1 0v1.793l-2.97-2.97a.75.75 0 0 0-1.06 0L6.5 7.793Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'trending-down-square': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 2h9A1.5 1.5 0 0 1 14 3.5v9a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 2 12.5v-9A1.5 1.5 0 0 1 3.5 2ZM1 3.5A2.5 2.5 0 0 1 3.5 1h9A2.5 2.5 0 0 1 15 3.5v9a2.5 2.5 0 0 1-2.5 2.5h-9A2.5 2.5 0 0 1 1 12.5v-9Zm5.5 4.293L3.854 5.146a.5.5 0 1 0-.708.708L5.97 8.677a.75.75 0 0 0 1.06 0l1.47-1.47L11.293 10H9.5a.5.5 0 0 0 0 1H13V7.5a.5.5 0 0 0-1 0v1.793l-2.97-2.97a.75.75 0 0 0-1.06 0L6.5 7.793Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'trending-down': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.146 3.146a.5.5 0 0 1 .708 0L6.5 8.793l2.646-2.647a.5.5 0 0 1 .708 0L15 11.293V8.5a.5.5 0 0 1 1 0v4a.5.5 0 0 1-.5.5h-4a.5.5 0 0 1 0-1h2.793L9.5 7.207 6.854 9.854a.5.5 0 0 1-.708 0l-6-6a.5.5 0 0 1 0-.708Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'trello-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 1A2.5 2.5 0 0 0 1 3.5v9A2.5 2.5 0 0 0 3.5 15h9a2.5 2.5 0 0 0 2.5-2.5v-9A2.5 2.5 0 0 0 12.5 1h-9Zm1 3a.5.5 0 0 0-.5.5v7a.5.5 0 0 0 .5.5h2a.5.5 0 0 0 .5-.5v-7a.5.5 0 0 0-.5-.5h-2Zm5 0a.5.5 0 0 0-.5.5v4a.5.5 0 0 0 .5.5h2a.5.5 0 0 0 .5-.5v-4a.5.5 0 0 0-.5-.5h-2Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'trello': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M4.5 4a.5.5 0 0 0-.5.5v7a.5.5 0 0 0 .5.5h2a.5.5 0 0 0 .5-.5v-7a.5.5 0 0 0-.5-.5h-2ZM9.5 4a.5.5 0 0 0-.5.5v4a.5.5 0 0 0 .5.5h2a.5.5 0 0 0 .5-.5v-4a.5.5 0 0 0-.5-.5h-2Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 3.5A2.5 2.5 0 0 1 3.5 1h9A2.5 2.5 0 0 1 15 3.5v9a2.5 2.5 0 0 1-2.5 2.5h-9A2.5 2.5 0 0 1 1 12.5v-9ZM3.5 2h9A1.5 1.5 0 0 1 14 3.5v9a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 2 12.5v-9A1.5 1.5 0 0 1 3.5 2Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'trash-2-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.5 0a1 1 0 0 0-1 1v1h-4a.5.5 0 0 0 0 1H2v5c0 1.573.378 3.687.668 5.08.237 1.14 1.25 1.92 2.394 1.92h5.876c1.145 0 2.157-.78 2.394-1.92.29-1.393.668-3.507.668-5.08V3h.5a.5.5 0 0 0 0-1h-4V1a1 1 0 0 0-1-1h-3Zm3 2h-3V1h3v1ZM7 6.5a.5.5 0 0 0-1 0v4a.5.5 0 0 0 1 0v-4Zm3 0a.5.5 0 0 0-1 0v4a.5.5 0 0 0 1 0v-4Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'trash-2': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M7 6.5a.5.5 0 0 0-1 0v4a.5.5 0 0 0 1 0v-4ZM10 6.5a.5.5 0 0 0-1 0v4a.5.5 0 0 0 1 0v-4Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.5 0a1 1 0 0 0-1 1v1h-4a.5.5 0 0 0 0 1H2v5c0 1.573.378 3.687.668 5.08.237 1.14 1.25 1.92 2.394 1.92h5.876c1.145 0 2.157-.78 2.394-1.92.29-1.393.668-3.507.668-5.08V3h.5a.5.5 0 0 0 0-1h-4V1a1 1 0 0 0-1-1h-3Zm3 2h-3V1h3v1ZM3 3h10v5c0 1.46-.358 3.484-.647 4.876A1.427 1.427 0 0 1 10.938 14H5.062a1.427 1.427 0 0 1-1.415-1.124C3.357 11.484 3 9.46 3 8V3Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'toggle-right-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5 3a5 5 0 0 0 0 10h6a5 5 0 0 0 0-10H5Zm8 5a2 2 0 1 0-4 0 2 2 0 0 0 4 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'toggle-right': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11 6a2 2 0 1 0 0 4 2 2 0 0 0 0-4Zm-1 2a1 1 0 1 1 2 0 1 1 0 0 1-2 0Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5 3a5 5 0 0 0 0 10h6a5 5 0 0 0 0-10H5ZM1 8a4 4 0 0 1 4-4h6a4 4 0 0 1 0 8H5a4 4 0 0 1-4-4Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'toggle-left-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5 3a5 5 0 0 0 0 10h6a5 5 0 0 0 0-10H5Zm2 5a2 2 0 1 0-4 0 2 2 0 0 0 4 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'toggle-left': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5 6.125a1.875 1.875 0 1 0 0 3.75 1.875 1.875 0 0 0 0-3.75ZM3.875 8a1.125 1.125 0 1 1 2.25 0 1.125 1.125 0 0 1-2.25 0Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5 3a5 5 0 0 0 0 10h6a5 5 0 0 0 0-10H5ZM1 8a4 4 0 0 1 4-4h6a4 4 0 0 1 0 8H5a4 4 0 0 1-4-4Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'thumbs-up-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.243.897a1 1 0 0 1 1.601-.26l.308.308a3.5 3.5 0 0 1 .921 3.324L9.64 6h3.761a2.5 2.5 0 0 1 2.352 3.35l-1.567 4.339A3.5 3.5 0 0 1 10.894 16H5.5a1.5 1.5 0 0 1-.5-.085v-8.13A.785.785 0 0 0 4.215 7a3.5 3.5 0 0 1 .155-.357L7.243.897ZM3.5 7c.175 0 .344.03.5.085v8.83a1.497 1.497 0 0 1-.5.085h-2A1.5 1.5 0 0 1 0 14.5v-6A1.5 1.5 0 0 1 1.5 7h2Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'thumbs-up': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.844.637a1 1 0 0 0-1.601.26L4.37 6.643a3.5 3.5 0 0 0-.207.51A1.494 1.494 0 0 0 3.5 7h-2A1.5 1.5 0 0 0 0 8.5v6A1.5 1.5 0 0 0 1.5 16h2c.384 0 .735-.144 1-.382.265.238.616.382 1 .382h5.394a3.5 3.5 0 0 0 3.292-2.311l1.567-4.34A2.5 2.5 0 0 0 13.4 6h-3.76l.432-1.73a3.5 3.5 0 0 0-.92-3.325L8.843.637ZM4 14.5v-6a.5.5 0 0 0-.5-.5h-2a.5.5 0 0 0-.5.5v6a.5.5 0 0 0 .5.5h2a.5.5 0 0 0 .5-.5Zm1 0a.5.5 0 0 0 .5.5h5.394a2.5 2.5 0 0 0 2.351-1.65l1.567-4.34A1.5 1.5 0 0 0 13.402 7H9a.5.5 0 0 1-.485-.621l.588-2.352a2.5 2.5 0 0 0-.658-2.375l-.308-.308L5.264 7.09A2.5 2.5 0 0 0 5 8.208V14.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'thumbs-down-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.243 15.103a1 1 0 0 0 1.601.26l.308-.308a3.5 3.5 0 0 0 .921-3.324L9.64 10h3.761a2.5 2.5 0 0 0 2.352-3.35l-1.567-4.339A3.5 3.5 0 0 0 10.894 0H5.5c-.175 0-.344.03-.5.085v8.13A.785.785 0 0 1 4.215 9a3.5 3.5 0 0 0 .155.357l2.873 5.746ZM3.5 9c.175 0 .344-.03.5-.085V.085A1.498 1.498 0 0 0 3.5 0h-2A1.5 1.5 0 0 0 0 1.5v6A1.5 1.5 0 0 0 1.5 9h2Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'thumbs-down': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.844 15.363a1 1 0 0 1-1.601-.26L4.37 9.357a3.5 3.5 0 0 1-.207-.51c-.2.098-.425.153-.663.153h-2A1.5 1.5 0 0 1 0 7.5v-6A1.5 1.5 0 0 1 1.5 0h2c.384 0 .735.144 1 .382A1.494 1.494 0 0 1 5.5 0h5.394a3.5 3.5 0 0 1 3.292 2.311l1.567 4.34A2.5 2.5 0 0 1 13.4 10h-3.76l.432 1.73a3.5 3.5 0 0 1-.92 3.325l-.309.308ZM4 1.5v6a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-6a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5Zm1 0a.5.5 0 0 1 .5-.5h5.394a2.5 2.5 0 0 1 2.351 1.65l1.567 4.34A1.5 1.5 0 0 1 13.402 9H9a.5.5 0 0 0-.485.621l.588 2.352a2.5 2.5 0 0 1-.658 2.375l-.308.308L5.264 8.91A2.5 2.5 0 0 1 5 7.792V1.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'thermometer-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 2a2 2 0 1 1 4 0v6.535a4 4 0 1 1-4 0V2Zm2.25 2.5a.25.25 0 0 0-.5 0v5.515a2 2 0 1 0 .5 0V4.5Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M10.75 2.375a.375.375 0 0 0 0 .75h1.5a.375.375 0 0 0 0-.75h-1.5ZM10.75 4.375a.375.375 0 0 0 0 .75h1.5a.375.375 0 0 0 0-.75h-1.5ZM10.75 6.375a.375.375 0 0 0 0 .75h1.5a.375.375 0 0 0 0-.75h-1.5Z'/%3e%3c/svg%3e")`,
                'thermometer': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 14a2 2 0 0 0 .25-3.985V4.5a.25.25 0 0 0-.5 0v5.515A2 2 0 0 0 8 14Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 0a2 2 0 0 0-2 2v6.535a4 4 0 1 0 4 0V2a2 2 0 0 0-2-2ZM7 2a1 1 0 0 1 2 0v7.153l.285.135a3 3 0 1 1-2.57 0L7 9.153V2Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M10.75 2.375a.375.375 0 0 0 0 .75h1.5a.375.375 0 0 0 0-.75h-1.5ZM10.75 4.375a.375.375 0 0 0 0 .75h1.5a.375.375 0 0 0 0-.75h-1.5ZM10.75 6.375a.375.375 0 0 0 0 .75h1.5a.375.375 0 0 0 0-.75h-1.5Z'/%3e%3c/svg%3e")`,
                'terminal': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M3.017 2.893a.5.5 0 0 0-.7.714L6.04 7.254l-3.643 3.642a.5.5 0 0 0 .707.708l4-4a.5.5 0 0 0-.004-.711l-4.083-4ZM8 12a.5.5 0 1 0 0 1h5.5a.5.5 0 0 0 0-1H8Z'/%3e%3c/svg%3e")`,
                'target-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 5.444a2.556 2.556 0 1 0 0 5.112 2.556 2.556 0 0 0 0-5.112Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.667 8a4.333 4.333 0 1 1 8.666 0 4.333 4.333 0 0 1-8.666 0Zm1.11 0a3.222 3.222 0 1 1 6.445 0 3.222 3.222 0 0 1-6.444 0Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0ZM8 3a5 5 0 1 0 0 10A5 5 0 0 0 8 3Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'target': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.778 8a3.222 3.222 0 1 1 6.444 0 3.222 3.222 0 0 1-6.444 0ZM8 5.444a2.556 2.556 0 1 0 0 5.112 2.556 2.556 0 0 0 0-5.112Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 3a5 5 0 1 0 0 10A5 5 0 0 0 8 3ZM3.667 8a4.333 4.333 0 1 1 8.666 0 4.333 4.333 0 0 1-8.666 0Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'tag-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 1.5v5.086a1.5 1.5 0 0 1-.44 1.06L8.017 15.19a2.5 2.5 0 0 1-3.535 0L.81 11.518a2.5 2.5 0 0 1 0-3.536L8.353.44A1.5 1.5 0 0 1 9.413 0H14.5A1.5 1.5 0 0 1 16 1.5ZM9 5a2 2 0 1 0 4 0 2 2 0 0 0-4 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'tag': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M13 5a2 2 0 1 0-4 0 2 2 0 0 0 4 0Zm-2-1a1 1 0 1 1 0 2 1 1 0 0 1 0-2Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 6.586V1.5A1.5 1.5 0 0 0 14.5 0H9.414a1.5 1.5 0 0 0-1.06.44L.81 7.981a2.5 2.5 0 0 0 0 3.536l3.671 3.671a2.5 2.5 0 0 0 3.536 0l7.543-7.543A1.5 1.5 0 0 0 16 6.586ZM15 1.5v5.086a.5.5 0 0 1-.146.353L7.31 14.482a1.5 1.5 0 0 1-2.122 0l-3.671-3.671a1.5 1.5 0 0 1 0-2.122L9.06 1.146A.5.5 0 0 1 9.414 1H14.5a.5.5 0 0 1 .5.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'tablet-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.25 0A2.25 2.25 0 0 0 1 2.25v11.5A2.25 2.25 0 0 0 3.25 16h9.5A2.25 2.25 0 0 0 15 13.75V2.25A2.25 2.25 0 0 0 12.75 0h-9.5ZM8 14a1 1 0 1 0 0-2 1 1 0 0 0 0 2Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'tablet': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 12.25a.75.75 0 1 0 0 1.5.75.75 0 0 0 0-1.5Zm-.25.75a.25.25 0 1 1 .5 0 .25.25 0 0 1-.5 0Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H3ZM2 2a1 1 0 0 1 1-1h10a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V2Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'table': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M1.75 4A.25.25 0 0 1 2 3.75h2.5a.25.25 0 0 1 0 .5H2A.25.25 0 0 1 1.75 4ZM6.5 3.75a.25.25 0 0 0 0 .5h3a.25.25 0 0 0 0-.5h-3ZM11.25 4a.25.25 0 0 1 .25-.25H14a.25.25 0 1 1 0 .5h-2.5a.25.25 0 0 1-.25-.25Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 4.5A2.5 2.5 0 0 1 2.5 2h11A2.5 2.5 0 0 1 16 4.5v7a2.5 2.5 0 0 1-2.5 2.5h-11A2.5 2.5 0 0 1 0 11.5v-7ZM2.5 3h11A1.5 1.5 0 0 1 15 4.5v.625H1V4.5A1.5 1.5 0 0 1 2.5 3ZM1 5.875v3.25h4.125v-3.25H1Zm0 4V11.5A1.5 1.5 0 0 0 2.5 13h2.625V9.875H1ZM5.875 13h4.25V9.875h-4.25V13Zm5 0H13.5a1.5 1.5 0 0 0 1.5-1.5V9.875h-4.125V13ZM15 9.125v-3.25h-4.125v3.25H15Zm-9.125 0h4.25v-3.25h-4.25v3.25Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'sunset-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 1a.5.5 0 0 1 .5.5v2.793l1.146-1.147a.5.5 0 0 1 .708.708L8 6.207 5.646 3.854a.5.5 0 1 1 .708-.708L7.5 4.293V1.5A.5.5 0 0 1 8 1ZM2.697 5.197a.5.5 0 0 1 .707 0L4.818 6.61a.5.5 0 0 1-.707.707L2.697 5.904a.5.5 0 0 1 0-.707ZM13.303 5.197a.5.5 0 0 1 0 .707L11.89 7.318a.5.5 0 1 1-.707-.707l1.414-1.414a.5.5 0 0 1 .707 0ZM.5 10.5A.5.5 0 0 1 1 10h2a.5.5 0 0 1 0 1H1a.5.5 0 0 1-.5-.5ZM12.5 10.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5ZM4.5 11v-.25A3.25 3.25 0 0 1 7.75 7.5h.5a3.25 3.25 0 0 1 3.25 3.25V11h-7ZM1 13a.5.5 0 0 0 0 1h14a.5.5 0 0 0 0-1H1Z'/%3e%3c/svg%3e")`,
                'sunset': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 1a.5.5 0 0 1 .5.5v2.793l1.146-1.147a.5.5 0 0 1 .708.708L8 6.207 5.646 3.854a.5.5 0 1 1 .708-.708L7.5 4.293V1.5A.5.5 0 0 1 8 1ZM2.697 5.197a.5.5 0 0 1 .707 0L4.818 6.61a.5.5 0 0 1-.707.707L2.697 5.904a.5.5 0 0 1 0-.707ZM13.303 5.197a.5.5 0 0 1 0 .707L11.89 7.318a.5.5 0 1 1-.707-.707l1.414-1.414a.5.5 0 0 1 .707 0ZM.5 10.5A.5.5 0 0 1 1 10h2a.5.5 0 0 1 0 1H1a.5.5 0 0 1-.5-.5ZM12.5 10.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 10.25A3.25 3.25 0 0 1 7.75 7h.5a3.25 3.25 0 0 1 3.25 3.25V11h-7v-.75ZM5.514 10h4.972A2.25 2.25 0 0 0 8.25 8h-.5a2.25 2.25 0 0 0-2.236 2Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1 13a.5.5 0 0 0 0 1h14a.5.5 0 0 0 0-1H1Z'/%3e%3c/svg%3e")`,
                'sunrise-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='m8 .793 2.354 2.353a.5.5 0 0 1-.708.708L8.5 2.707V5.5a.5.5 0 1 1-1 0V2.707L6.354 3.854a.5.5 0 1 1-.708-.708L8 .793ZM2.697 5.197a.5.5 0 0 1 .707 0L4.818 6.61a.5.5 0 1 1-.707.707L2.697 5.904a.5.5 0 0 1 0-.707ZM13.303 5.197a.5.5 0 0 1 0 .707L11.89 7.318a.5.5 0 1 1-.707-.707l1.414-1.414a.5.5 0 0 1 .707 0ZM.5 10.5A.5.5 0 0 1 1 10h2a.5.5 0 0 1 0 1H1a.5.5 0 0 1-.5-.5ZM12.5 10.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5ZM4.5 11v-.25A3.25 3.25 0 0 1 7.75 7.5h.5a3.25 3.25 0 0 1 3.25 3.25V11h-7ZM1 13a.5.5 0 1 0 0 1h14a.5.5 0 0 0 0-1H1Z'/%3e%3c/svg%3e")`,
                'sunrise': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='m8 .793 2.354 2.353a.5.5 0 0 1-.708.708L8.5 2.707V5.5a.5.5 0 1 1-1 0V2.707L6.354 3.854a.5.5 0 1 1-.708-.708L8 .793ZM2.697 5.197a.5.5 0 0 1 .707 0L4.818 6.61a.5.5 0 1 1-.707.707L2.697 5.904a.5.5 0 0 1 0-.707ZM13.303 5.197a.5.5 0 0 1 0 .707L11.89 7.318a.5.5 0 1 1-.707-.707l1.414-1.414a.5.5 0 0 1 .707 0ZM.5 10.5A.5.5 0 0 1 1 10h2a.5.5 0 0 1 0 1H1a.5.5 0 0 1-.5-.5ZM12.5 10.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 10.25A3.25 3.25 0 0 1 7.75 7h.5a3.25 3.25 0 0 1 3.25 3.25V11h-7v-.75ZM5.514 10h4.972A2.25 2.25 0 0 0 8.25 8h-.5a2.25 2.25 0 0 0-2.236 2Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1 13a.5.5 0 1 0 0 1h14a.5.5 0 0 0 0-1H1Z'/%3e%3c/svg%3e")`,
                'sun-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8.375.75a.375.375 0 1 0-.75 0V3.5a.375.375 0 1 0 .75 0V.75ZM13.392 3.139a.375.375 0 0 0-.53-.53l-1.945 1.944a.375.375 0 0 0 .53.53l1.945-1.944ZM3.139 2.608a.375.375 0 1 0-.53.53l1.944 1.945a.375.375 0 1 0 .53-.53L3.14 2.608ZM.75 7.625a.375.375 0 1 0 0 .75H3.5a.375.375 0 1 0 0-.75H.75ZM12.5 7.625a.375.375 0 0 0 0 .75h2.75a.375.375 0 0 0 0-.75H12.5ZM5.083 11.447a.375.375 0 1 0-.53-.53L2.608 12.86a.375.375 0 1 0 .53.53l1.945-1.944ZM11.447 10.917a.375.375 0 0 0-.53.53l1.944 1.945a.375.375 0 0 0 .53-.53l-1.944-1.945ZM8.375 12.5a.375.375 0 0 0-.75 0v2.75a.375.375 0 0 0 .75 0V12.5ZM8 5a3 3 0 1 0 0 6 3 3 0 0 0 0-6Z'/%3e%3c/svg%3e")`,
                'sun': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8.375.75a.375.375 0 1 0-.75 0V3.5a.375.375 0 1 0 .75 0V.75ZM13.392 3.139a.375.375 0 0 0-.53-.53l-1.945 1.944a.375.375 0 0 0 .53.53l1.945-1.944ZM3.139 2.608a.375.375 0 1 0-.53.53l1.944 1.945a.375.375 0 1 0 .53-.53L3.14 2.608ZM.75 7.625a.375.375 0 1 0 0 .75H3.5a.375.375 0 1 0 0-.75H.75ZM12.5 7.625a.375.375 0 0 0 0 .75h2.75a.375.375 0 0 0 0-.75H12.5ZM5.083 11.447a.375.375 0 1 0-.53-.53L2.608 12.86a.375.375 0 1 0 .53.53l1.945-1.944ZM11.447 10.917a.375.375 0 0 0-.53.53l1.944 1.945a.375.375 0 0 0 .53-.53l-1.944-1.945ZM8.375 12.5a.375.375 0 0 0-.75 0v2.75a.375.375 0 0 0 .75 0V12.5Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 5a3 3 0 1 0 0 6 3 3 0 0 0 0-6ZM6 8a2 2 0 1 1 4 0 2 2 0 0 1-4 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'strike': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M4 5a3 3 0 0 1 3-3h2a3 3 0 0 1 3 3h-1a2 2 0 0 0-2-2H7a2 2 0 0 0-2 2v.08c0 .547.223 1.054.592 1.42H4.358A2.993 2.993 0 0 1 4 5.08V5ZM10.908 9.5h1.234c.23.426.358.912.358 1.42V11a3 3 0 0 1-3 3H7a3 3 0 0 1-3-3h1a2 2 0 0 0 2 2h2.5a2 2 0 0 0 2-2v-.08c0-.547-.223-1.054-.592-1.42ZM2.5 7.5a.5.5 0 0 0 0 1h11a.5.5 0 0 0 0-1h-11Z'/%3e%3c/svg%3e")`,
                'stop-circle-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0ZM5 5.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 .5.5v5a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5v-5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'stop-circle': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5 5.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 .5.5v5a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5v-5ZM6 6v4h4V6H6Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'star-half-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M3.298 15.472 8 12.536V1L5.922 6.14l-5.53.388 4.245 3.565-1.34 5.38Z'/%3e%3c/svg%3e")`,
                'star-half': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m6.615 7.093-3.687.26 2.83 2.375-.892 3.586L7 11.982V6.14l-.385.953Zm-.693-.954-5.53.389 4.245 3.565-1.34 5.38L8 12.535V1L5.922 6.14Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'star-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='m8 1 2.079 5.14 5.53.388-4.246 3.565 1.34 5.38L8 12.535l-4.702 2.936 1.34-5.38L.391 6.529l5.53-.389L8 1Z'/%3e%3c/svg%3e")`,
                'star': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.078 6.14 8.464 2.145a.5.5 0 0 0-.928 0L5.922 6.14l-4.297.302a.5.5 0 0 0-.287.882l3.3 2.77-1.042 4.18a.5.5 0 0 0 .75.544L8 12.536l3.654 2.281a.5.5 0 0 0 .75-.545l-1.041-4.18 3.299-2.77a.5.5 0 0 0-.287-.88l-4.297-.303Zm2.994 1.212-3.687-.259L8 3.667 6.615 7.093l-3.687.26 2.83 2.375-.893 3.586L8 11.357l3.134 1.957-.892-3.586 2.83-2.376Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'square-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 2A1.5 1.5 0 0 0 2 3.5v9A1.5 1.5 0 0 0 3.5 14h9a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 12.5 2h-9ZM1 3.5A2.5 2.5 0 0 1 3.5 1h9A2.5 2.5 0 0 1 15 3.5v9a2.5 2.5 0 0 1-2.5 2.5h-9A2.5 2.5 0 0 1 1 12.5v-9Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M2 3.5A1.5 1.5 0 0 1 3.5 2h9A1.5 1.5 0 0 1 14 3.5v9a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 2 12.5v-9Z'/%3e%3c/svg%3e")`,
                'square': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 2A1.5 1.5 0 0 0 2 3.5v9A1.5 1.5 0 0 0 3.5 14h9a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 12.5 2h-9ZM1 3.5A2.5 2.5 0 0 1 3.5 1h9A2.5 2.5 0 0 1 15 3.5v9a2.5 2.5 0 0 1-2.5 2.5h-9A2.5 2.5 0 0 1 1 12.5v-9Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'speaker-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5.375 10.5a2.625 2.625 0 1 1 5.25 0 2.625 2.625 0 0 1-5.25 0Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 0A2.5 2.5 0 0 0 2 2.5v11A2.5 2.5 0 0 0 4.5 16h7a2.5 2.5 0 0 0 2.5-2.5v-11A2.5 2.5 0 0 0 11.5 0h-7ZM9 4a1 1 0 1 1-2 0 1 1 0 0 1 2 0ZM8 7.125a3.375 3.375 0 1 0 0 6.75 3.375 3.375 0 0 0 0-6.75Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'speaker': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M9 4a1 1 0 1 1-2 0 1 1 0 0 1 2 0Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 7.125a3.375 3.375 0 1 0 0 6.75 3.375 3.375 0 0 0 0-6.75ZM5.375 10.5a2.625 2.625 0 1 1 5.25 0 2.625 2.625 0 0 1-5.25 0Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2 2.5A2.5 2.5 0 0 1 4.5 0h7A2.5 2.5 0 0 1 14 2.5v11a2.5 2.5 0 0 1-2.5 2.5h-7A2.5 2.5 0 0 1 2 13.5v-11ZM4.5 1h7A1.5 1.5 0 0 1 13 2.5v11a1.5 1.5 0 0 1-1.5 1.5h-7A1.5 1.5 0 0 1 3 13.5v-11A1.5 1.5 0 0 1 4.5 1Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'smile-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0ZM5 6.25a1 1 0 1 1 2 0 1 1 0 0 1-2 0Zm4 0a1 1 0 1 1 2 0 1 1 0 0 1-2 0ZM5.354 9.896c.635.635 1.62.979 2.646.979 1.026 0 2.011-.344 2.646-.979a.5.5 0 0 1 .708.708c-.865.865-2.13 1.271-3.354 1.271-1.224 0-2.489-.406-3.354-1.271a.5.5 0 0 1 .708-.708Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'smile': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5 6.25a1 1 0 1 1 2 0 1 1 0 0 1-2 0ZM9 6.25a1 1 0 1 1 2 0 1 1 0 0 1-2 0ZM5.354 9.897c.635.635 1.62.978 2.646.978 1.026 0 2.011-.343 2.646-.978a.5.5 0 0 1 .708.707c-.865.865-2.13 1.271-3.354 1.271-1.224 0-2.489-.406-3.354-1.271a.5.5 0 0 1 .708-.707Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'smartphone-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 0A2.5 2.5 0 0 0 2 2.5v11A2.5 2.5 0 0 0 4.5 16h7a2.5 2.5 0 0 0 2.5-2.5v-11A2.5 2.5 0 0 0 11.5 0h-7ZM5 1h6v.5a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5V1Zm0 12.5c0-.207.168-.375.375-.375h5.25a.375.375 0 0 1 0 .75h-5.25A.375.375 0 0 1 5 13.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'smartphone': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5 13.5c0-.207.168-.375.375-.375h5.25a.375.375 0 0 1 0 .75h-5.25A.375.375 0 0 1 5 13.5Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2 2.5A2.5 2.5 0 0 1 4.5 0h7A2.5 2.5 0 0 1 14 2.5v11a2.5 2.5 0 0 1-2.5 2.5h-7A2.5 2.5 0 0 1 2 13.5v-11ZM11 1h.5A1.5 1.5 0 0 1 13 2.5v11a1.5 1.5 0 0 1-1.5 1.5h-7A1.5 1.5 0 0 1 3 13.5v-11A1.5 1.5 0 0 1 4.5 1H5v.5a.5.5 0 0 0 .5.5h5a.5.5 0 0 0 .5-.5V1Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'sliders-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M10 1.5A3 3 0 0 1 12.959 4h2.291a.5.5 0 0 1 0 1h-2.291A3 3 0 1 1 10 1.5ZM.25 4.5a.5.5 0 0 1 .5-.5H5.5a.5.5 0 0 1 0 1H.75a.5.5 0 0 1-.5-.5ZM6 8.5A3 3 0 0 0 3.041 11H.75a.5.5 0 0 0 0 1h2.291A3 3 0 1 0 6 8.5ZM15.75 11.5a.5.5 0 0 0-.5-.5H10.5a.5.5 0 0 0 0 1h4.75a.5.5 0 0 0 .5-.5Z'/%3e%3c/svg%3e")`,
                'sliders': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10 1.5A3 3 0 0 1 12.959 4h2.291a.5.5 0 0 1 0 1h-2.291A3 3 0 1 1 10 1.5Zm0 1a2 2 0 1 0 0 4 2 2 0 0 0 0-4Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M.25 4.5a.5.5 0 0 1 .5-.5H5.5a.5.5 0 0 1 0 1H.75a.5.5 0 0 1-.5-.5Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 8.5A3 3 0 0 0 3.041 11H.75a.5.5 0 0 0 0 1h2.291A3 3 0 1 0 6 8.5Zm0 1a2 2 0 1 1 0 4 2 2 0 0 1 0-4Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M15.75 11.5a.5.5 0 0 0-.5-.5H10.5a.5.5 0 0 0 0 1h4.75a.5.5 0 0 0 .5-.5Z'/%3e%3c/svg%3e")`,
                'slash': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-3.21 4.792A6.3 6.3 0 0 1 3.203 3.91l8.881 8.88Zm.707-.708-8.88-8.88a6.3 6.3 0 0 1 8.88 8.88Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'slack-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9 2.438C9 2.224 9.192 2 9.5 2s.5.225.5.438v3.124c0 .213-.192.438-.5.438S9 5.775 9 5.562V2.438ZM9.5 1C8.701 1 8 1.613 8 2.438v3.124C8 6.388 8.701 7 9.5 7S11 6.387 11 5.562V2.438C11 1.614 10.299 1 9.5 1ZM13 5.5c0-.277.223-.5.5-.5s.5.223.5.5-.223.5-.5.5H13v-.5Zm.5-1.5c-.83 0-1.5.67-1.5 1.5v1a.5.5 0 0 0 .5.5h1c.83 0 1.5-.67 1.5-1.5S14.33 4 13.5 4Zm-7 6c-.308 0-.5.225-.5.438v3.124c0 .213.192.438.5.438s.5-.225.5-.438v-3.124c0-.213-.192-.438-.5-.438Zm-1.5.438C5 9.613 5.701 9 6.5 9S8 9.613 8 10.438v3.124C8 14.387 7.299 15 6.5 15S5 14.387 5 13.562v-3.124ZM2 10.5c0-.277.223-.5.5-.5H3v.5c0 .277-.223.5-.5.5a.499.499 0 0 1-.5-.5ZM2.5 9C1.67 9 1 9.67 1 10.5S1.67 12 2.5 12 4 11.33 4 10.5v-1a.5.5 0 0 0-.5-.5h-1Zm7.938 0c-.213 0-.438.192-.438.5s.225.5.438.5h3.124c.213 0 .438-.192.438-.5s-.225-.5-.438-.5h-3.124ZM9 9.5c0-.799.613-1.5 1.438-1.5h3.124C14.387 8 15 8.701 15 9.5s-.613 1.5-1.438 1.5h-3.124C9.613 11 9 10.299 9 9.5Zm.5 2.5a.5.5 0 0 0-.5.5v1c0 .83.67 1.5 1.5 1.5s1.5-.67 1.5-1.5-.67-1.5-1.5-1.5h-1Zm.5 1.5V13h.5c.277 0 .5.223.5.5s-.223.5-.5.5a.499.499 0 0 1-.5-.5Zm-9-7C1 5.701 1.613 5 2.438 5h3.124C6.388 5 7 5.701 7 6.5S6.387 8 5.562 8H2.438C1.614 8 1 7.299 1 6.5ZM2.438 6C2.224 6 2 6.192 2 6.5s.225.5.438.5h3.124C5.776 7 6 6.808 6 6.5S5.775 6 5.562 6H2.438ZM5.5 1C4.67 1 4 1.67 4 2.5S4.67 4 5.5 4h1a.5.5 0 0 0 .5-.5v-1C7 1.67 6.33 1 5.5 1ZM5 2.5c0-.277.223-.5.5-.5s.5.223.5.5V3h-.5a.499.499 0 0 1-.5-.5Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M2.438 6C2.224 6 2 6.192 2 6.5s.225.5.438.5h3.124C5.776 7 6 6.808 6 6.5S5.775 6 5.562 6H2.438ZM9 2.438C9 2.224 9.192 2 9.5 2s.5.225.5.438v3.124c0 .213-.192.438-.5.438S9 5.775 9 5.562V2.438ZM5 2.5c0-.277.223-.5.5-.5s.5.223.5.5V3h-.5a.499.499 0 0 1-.5-.5ZM2 10.5c0-.277.223-.5.5-.5H3v.5c0 .277-.223.5-.5.5a.499.499 0 0 1-.5-.5ZM6.5 10c-.308 0-.5.225-.5.438v3.124c0 .213.192.438.5.438s.5-.225.5-.438v-3.124c0-.213-.192-.438-.5-.438ZM10 13.5V13h.5c.277 0 .5.223.5.5s-.223.5-.5.5a.499.499 0 0 1-.5-.5ZM10.438 9c-.213 0-.438.192-.438.5s.225.5.438.5h3.124c.213 0 .438-.192.438-.5s-.225-.5-.438-.5h-3.124ZM13 5.5c0-.277.223-.5.5-.5s.5.223.5.5-.223.5-.5.5H13v-.5Z'/%3e%3c/svg%3e")`,
                'slack': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.5 1C8.701 1 8 1.613 8 2.438v3.124C8 6.388 8.701 7 9.5 7S11 6.387 11 5.562V2.438C11 1.614 10.299 1 9.5 1ZM9 2.438C9 2.224 9.192 2 9.5 2s.5.225.5.438v3.124c0 .213-.192.438-.5.438S9 5.775 9 5.562V2.438ZM13.5 4c-.83 0-1.5.67-1.5 1.5v1a.5.5 0 0 0 .5.5h1c.83 0 1.5-.67 1.5-1.5S14.33 4 13.5 4ZM13 5.5c0-.277.223-.5.5-.5s.5.223.5.5-.223.5-.5.5H13v-.5ZM5 10.438C5 9.613 5.701 9 6.5 9S8 9.613 8 10.438v3.124C8 14.387 7.299 15 6.5 15S5 14.387 5 13.562v-3.124ZM6.5 10c-.308 0-.5.225-.5.438v3.124c0 .213.192.438.5.438s.5-.225.5-.438v-3.124c0-.213-.192-.438-.5-.438ZM2.5 9C1.67 9 1 9.67 1 10.5S1.67 12 2.5 12 4 11.33 4 10.5v-1a.5.5 0 0 0-.5-.5h-1ZM2 10.5c0-.277.223-.5.5-.5H3v.5c0 .277-.223.5-.5.5a.499.499 0 0 1-.5-.5ZM9 9.5c0-.799.613-1.5 1.438-1.5h3.124C14.387 8 15 8.701 15 9.5s-.613 1.5-1.438 1.5h-3.124C9.613 11 9 10.299 9 9.5Zm1.438-.5c-.213 0-.438.192-.438.5s.225.5.438.5h3.124c.213 0 .438-.192.438-.5s-.225-.5-.438-.5h-3.124ZM9.5 12a.5.5 0 0 0-.5.5v1c0 .83.67 1.5 1.5 1.5s1.5-.67 1.5-1.5-.67-1.5-1.5-1.5h-1Zm.5 1.5V13h.5c.277 0 .5.223.5.5s-.223.5-.5.5a.499.499 0 0 1-.5-.5ZM1 6.5C1 5.701 1.613 5 2.438 5h3.124C6.388 5 7 5.701 7 6.5S6.387 8 5.562 8H2.438C1.614 8 1 7.299 1 6.5ZM2.438 6C2.224 6 2 6.192 2 6.5s.225.5.438.5h3.124C5.776 7 6 6.808 6 6.5S5.775 6 5.562 6H2.438ZM5.5 1C4.67 1 4 1.67 4 2.5S4.67 4 5.5 4h1a.5.5 0 0 0 .5-.5v-1C7 1.67 6.33 1 5.5 1ZM5 2.5c0-.277.223-.5.5-.5s.5.223.5.5V3h-.5a.499.499 0 0 1-.5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'skip-forward-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='m2.788 2.557 7.133 5.035a.5.5 0 0 1 0 .817l-7.133 5.034A.5.5 0 0 1 2 13.036V2.965a.5.5 0 0 1 .788-.408ZM14 3a.5.5 0 0 0-1 0v10a.5.5 0 1 0 1 0V3Z'/%3e%3c/svg%3e")`,
                'skip-forward': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.921 7.592 2.788 2.557A.5.5 0 0 0 2 2.964v10.07a.5.5 0 0 0 .788.409l7.133-5.035a.5.5 0 0 0 0-.817ZM8.766 8 3 12.07V3.93L8.766 8Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M14 3a.5.5 0 0 0-1 0v10a.5.5 0 1 0 1 0V3Z'/%3e%3c/svg%3e")`,
                'skip-back-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M13.212 2.557 6.079 7.591a.5.5 0 0 0 0 .817l7.133 5.034a.5.5 0 0 0 .788-.408V2.965a.5.5 0 0 0-.788-.408ZM2 3a.5.5 0 1 1 1 0v10a.5.5 0 1 1-1 0V3Z'/%3e%3c/svg%3e")`,
                'skip-back': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m6.079 7.592 7.133-5.035a.5.5 0 0 1 .788.408v10.07a.5.5 0 0 1-.788.409L6.079 8.409a.5.5 0 0 1 0-.817ZM7.234 8 13 12.07V3.93L7.234 8Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M2 3a.5.5 0 1 1 1 0v10a.5.5 0 1 1-1 0V3Z'/%3e%3c/svg%3e")`,
                'sidebar-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 2A2.5 2.5 0 0 0 0 4.5v7A2.5 2.5 0 0 0 2.5 14h11a2.5 2.5 0 0 0 2.5-2.5v-7A2.5 2.5 0 0 0 13.5 2h-11ZM6 3v10h7.5a1.5 1.5 0 0 0 1.5-1.5v-7A1.5 1.5 0 0 0 13.5 3H6Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'sidebar': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 2A2.5 2.5 0 0 0 0 4.5v7A2.5 2.5 0 0 0 2.5 14h11a2.5 2.5 0 0 0 2.5-2.5v-7A2.5 2.5 0 0 0 13.5 2h-11ZM1 4.5A1.5 1.5 0 0 1 2.5 3h2.625v10H2.5A1.5 1.5 0 0 1 1 11.5v-7ZM5.875 13H13.5a1.5 1.5 0 0 0 1.5-1.5v-7A1.5 1.5 0 0 0 13.5 3H5.875v10Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'shuffle-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 17 16'%3e%3cpath fill='%230E1011' d='M.5 12a.5.5 0 0 1 0-1h1.964a2 2 0 0 0 1.415-.586l1.267-1.268a.5.5 0 1 1 .708.708L4.586 11.12A3 3 0 0 1 2.464 12H.5ZM8.854 6.854a.5.5 0 1 1-.708-.708L9.414 4.88A3 3 0 0 1 11.536 4h2.757l-1.147-1.146a.5.5 0 0 1 .708-.708L16.207 4.5l-2.353 2.354a.5.5 0 0 1-.708-.708L14.293 5h-2.757a2 2 0 0 0-1.415.586L8.854 6.854Z'/%3e%3cpath fill='%230E1011' d='M.5 4a.5.5 0 0 0 0 1h1.964a2 2 0 0 1 1.415.586l5.535 5.535a3 3 0 0 0 2.122.879h2.757l-1.147 1.146a.5.5 0 0 0 .708.708l2.353-2.354-2.353-2.354a.5.5 0 0 0-.708.708L14.293 11h-2.757a2 2 0 0 1-1.415-.586L4.586 4.88A3 3 0 0 0 2.464 4H.5Z'/%3e%3c/svg%3e")`,
                'shuffle': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 17 16'%3e%3cpath fill='%230E1011' d='M.5 12a.5.5 0 0 1 0-1h1.964a2 2 0 0 0 1.415-.586l1.267-1.268a.5.5 0 1 1 .708.708L4.586 11.12A3 3 0 0 1 2.464 12H.5ZM8.854 6.854a.5.5 0 1 1-.708-.708L9.414 4.88A3 3 0 0 1 11.536 4h2.757l-1.147-1.146a.5.5 0 0 1 .708-.708L16.207 4.5l-2.353 2.354a.5.5 0 0 1-.708-.708L14.293 5h-2.757a2 2 0 0 0-1.415.586L8.854 6.854Z'/%3e%3cpath fill='%230E1011' d='M.5 4a.5.5 0 0 0 0 1h1.964a2 2 0 0 1 1.415.586l5.535 5.535a3 3 0 0 0 2.122.879h2.757l-1.147 1.146a.5.5 0 0 0 .708.708l2.353-2.354-2.353-2.354a.5.5 0 0 0-.708.708L14.293 11h-2.757a2 2 0 0 1-1.415-.586L4.586 4.88A3 3 0 0 0 2.464 4H.5Z'/%3e%3c/svg%3e")`,
                'shopping-cart-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M.5 1a.5.5 0 0 0 0 1h1.61l2.026 8.106A2.5 2.5 0 0 0 6.562 12h6.244a2.5 2.5 0 0 0 2.466-2.089l.527-3.164A1.5 1.5 0 0 0 14.32 5H3.89l-.81-3.243A1 1 0 0 0 2.11 1H.5Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.5 13a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3ZM6 14.5a.5.5 0 1 1 1 0 .5.5 0 0 1-1 0ZM12.5 13a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3Zm-.5 1.5a.5.5 0 1 1 1 0 .5.5 0 0 1-1 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'shopping-cart': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.5 1a.5.5 0 0 0 0 1h1.61l2.026 8.106A2.5 2.5 0 0 0 6.562 12h6.244a2.5 2.5 0 0 0 2.466-2.089l.527-3.164A1.5 1.5 0 0 0 14.32 5H3.89l-.81-3.243A1 1 0 0 0 2.11 1H.5Zm4.606 8.864L4.14 6h10.18a.5.5 0 0 1 .493.582l-.528 3.165A1.5 1.5 0 0 1 12.805 11H6.563a1.5 1.5 0 0 1-1.456-1.136ZM6.5 13a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3ZM6 14.5a.5.5 0 1 1 1 0 .5.5 0 0 1-1 0ZM12.5 13a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3Zm-.5 1.5a.5.5 0 1 1 1 0 .5.5 0 0 1-1 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'shopping-bag-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.707 0A1 1 0 0 0 3 .293l-2 2V12.5A3.5 3.5 0 0 0 4.5 16h7a3.5 3.5 0 0 0 3.5-3.5V2.293l-2-2A1 1 0 0 0 12.293 0H3.707Zm0 1h8.586l1 1H2.707l1-1ZM9.5 7A2.5 2.5 0 0 0 12 4.5v-2h-1v2A1.5 1.5 0 0 1 9.5 6h-3A1.5 1.5 0 0 1 5 4.5v-2H4v2A2.5 2.5 0 0 0 6.5 7h3Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'shopping-bag': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 .293A1 1 0 0 1 3.707 0h8.586A1 1 0 0 1 13 .293l2 2V12.5a3.5 3.5 0 0 1-3.5 3.5h-7A3.5 3.5 0 0 1 1 12.5V2.293l2-2ZM12.293 1H3.707l-1 1h10.586l-1-1ZM14 3h-2v1.5A2.5 2.5 0 0 1 9.5 7h-3A2.5 2.5 0 0 1 4 4.5V3H2v9.5A2.5 2.5 0 0 0 4.5 15h7a2.5 2.5 0 0 0 2.5-2.5V3ZM5 3v1.5A1.5 1.5 0 0 0 6.5 6h3A1.5 1.5 0 0 0 11 4.5V3H5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'shield-off-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 18'%3e%3cpath fill='%230E1011' d='m8 .973 5.97 1.974A1.5 1.5 0 0 1 15 4.37v3.007a9.496 9.496 0 0 1-1.13 4.493L4.223 2.222 8 .973ZM12.303 14.01l2.593 2.594a.5.5 0 0 0 .708-.708l-14.5-14.5a.5.5 0 1 0-.708.708L1.524 3.23A1.5 1.5 0 0 0 1 4.371v3.007a9.5 9.5 0 0 0 4.293 7.946L8 17.098l2.707-1.774a9.502 9.502 0 0 0 1.596-1.314Z'/%3e%3c/svg%3e")`,
                'shield-off': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.843.025a.5.5 0 0 1 .314 0l5.814 1.922A1.5 1.5 0 0 1 15 3.37v3.007a9.495 9.495 0 0 1-1.055 4.351l-.89-.458A8.495 8.495 0 0 0 14 6.378V3.371a.5.5 0 0 0-.343-.475L8 1.026 4.775 2.094l-.314-.95L7.843.025ZM1.524 2.231.146.854.854.146l15 15-.708.708-2.843-2.844a9.502 9.502 0 0 1-1.596 1.314l-2.433 1.594a.5.5 0 0 1-.548 0l-2.433-1.594A9.5 9.5 0 0 1 1 6.378V3.371c0-.448.199-.86.524-1.14Zm.714.714A.5.5 0 0 0 2 3.371v3.007a8.5 8.5 0 0 0 3.841 7.11L8 14.902l2.159-1.414a8.495 8.495 0 0 0 1.436-1.185L2.238 2.944Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'shield-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 18'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m8 .973 5.97 1.974A1.5 1.5 0 0 1 15 4.37v3.007a9.5 9.5 0 0 1-4.293 7.946L8 17.098l-2.707-1.774A9.5 9.5 0 0 1 1 7.378V4.371a1.5 1.5 0 0 1 1.03-1.424L8 .973Zm0 1.054-5.657 1.87A.5.5 0 0 0 2 4.37v3.007a8.5 8.5 0 0 0 3.841 7.11L8 15.902l2.159-1.414A8.5 8.5 0 0 0 14 7.378V4.371a.5.5 0 0 0-.343-.475L8 2.026Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M2.343 3.896 8 2.026l5.657 1.87a.5.5 0 0 1 .343.475v3.007a8.5 8.5 0 0 1-3.841 7.11L8 15.902l-2.159-1.414A8.5 8.5 0 0 1 2 7.378V4.371a.5.5 0 0 1 .343-.475Z'/%3e%3c/svg%3e")`,
                'shield': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 18'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m8 .973 5.97 1.974A1.5 1.5 0 0 1 15 4.37v3.007a9.5 9.5 0 0 1-4.293 7.946L8 17.098l-2.707-1.774A9.5 9.5 0 0 1 1 7.378V4.371a1.5 1.5 0 0 1 1.03-1.424L8 .973Zm0 1.054-5.657 1.87A.5.5 0 0 0 2 4.37v3.007a8.5 8.5 0 0 0 3.841 7.11L8 15.902l2.159-1.414A8.5 8.5 0 0 0 14 7.378V4.371a.5.5 0 0 0-.343-.475L8 2.026Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'share-2-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11.2.543a3 3 0 1 1-.416 4.564L6.99 7.767a3.041 3.041 0 0 1 .006.379l3.792 2.742a3 3 0 1 1-.576.818L6.75 9.201a3 3 0 1 1-.03-2.467l3.49-2.446A3 3 0 0 1 11.2.543Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'share-2': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11.2.543a3 3 0 1 1-.416 4.564L6.99 7.767a3.041 3.041 0 0 1 .006.379l3.792 2.742a3 3 0 1 1-.576.818L6.75 9.201a3 3 0 1 1-.03-2.467l3.49-2.446A3 3 0 0 1 11.2.543Zm3.359 1.31a2 2 0 1 0-3.277 2.294 2 2 0 0 0 3.277-2.294Zm0 12.294a2 2 0 1 1-3.277-2.294 2 2 0 0 1 3.277 2.294ZM2 8a2 2 0 1 1 4 0 2 2 0 0 1-4 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'share': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.25 14C3.56 14 3 13.44 3 12.75v-5c0-.69.56-1.25 1.25-1.25h.25a.5.5 0 1 0 0-1h-.25A2.25 2.25 0 0 0 2 7.75v5A2.25 2.25 0 0 0 4.25 15h7.5A2.25 2.25 0 0 0 14 12.75v-5a2.25 2.25 0 0 0-2.25-2.25h-.25a.5.5 0 0 0 0 1h.25c.69 0 1.25.56 1.25 1.25v5c0 .69-.56 1.25-1.25 1.25h-7.5ZM8 11a.5.5 0 0 0 .5-.5V2.207l2.146 2.147a.5.5 0 0 0 .708-.708L8 .293 4.646 3.646a.5.5 0 1 0 .708.708L7.5 2.207V10.5a.5.5 0 0 0 .5.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'settings-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m2.485 11.203-.182.254c-.241.337-.254.791.005 1.114.332.413.708.789 1.12 1.12.323.26.778.247 1.115.006l.254-.182a1 1 0 0 1 1.568.65l.051.309c.068.408.38.739.792.784a7.404 7.404 0 0 0 1.584 0c.412-.045.724-.376.792-.784l.05-.31a1 1 0 0 1 1.569-.649l.254.182c.337.24.792.254 1.114-.005a7.339 7.339 0 0 0 1.12-1.12c.26-.323.247-.778.006-1.115l-.182-.254a1 1 0 0 1 .65-1.568l.309-.051c.408-.068.74-.38.784-.792a7.4 7.4 0 0 0 0-1.584c-.045-.412-.376-.724-.784-.792l-.31-.051a1 1 0 0 1-.649-1.568l.182-.254c.24-.337.254-.792-.005-1.114a7.346 7.346 0 0 0-1.12-1.121c-.323-.26-.778-.246-1.115-.005l-.254.182a1 1 0 0 1-1.568-.65l-.051-.309c-.068-.408-.38-.74-.792-.784a7.382 7.382 0 0 0-1.584 0c-.412.045-.724.376-.792.784l-.051.309a1 1 0 0 1-1.568.65l-.254-.182c-.337-.24-.792-.254-1.114.005a7.344 7.344 0 0 0-1.121 1.12c-.26.323-.246.778-.005 1.115l.182.254a1 1 0 0 1-.65 1.568l-.309.051c-.408.068-.74.38-.784.792a7.382 7.382 0 0 0 0 1.584c.045.412.376.724.784.792l.309.05a1 1 0 0 1 .65 1.569ZM10 8a2 2 0 1 1-4 0 2 2 0 0 1 4 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'settings': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11 8a3 3 0 1 1-6 0 3 3 0 0 1 6 0Zm-1 0a2 2 0 1 1-4 0 2 2 0 0 1 4 0Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m2.303 11.457.182-.254a1 1 0 0 0-.65-1.568l-.309-.051c-.408-.068-.74-.38-.784-.792a7.382 7.382 0 0 1 0-1.584c.045-.412.376-.724.784-.792l.309-.051a1 1 0 0 0 .65-1.568l-.182-.254c-.241-.337-.254-.792.005-1.114a7.344 7.344 0 0 1 1.12-1.12c.323-.26.778-.247 1.115-.006l.254.182a1 1 0 0 0 1.568-.65l.051-.309c.068-.408.38-.74.792-.784a7.382 7.382 0 0 1 1.584 0c.412.045.724.376.792.784l.05.309a1 1 0 0 0 1.569.65l.254-.182c.337-.241.791-.254 1.114.005.413.332.789.708 1.12 1.12.26.323.247.778.006 1.115l-.182.254a1 1 0 0 0 .65 1.568l.309.051c.408.068.739.38.784.792a7.404 7.404 0 0 1 0 1.584c-.045.412-.376.724-.784.792l-.31.05a1 1 0 0 0-.649 1.569l.182.254c.24.337.254.792-.005 1.114a7.339 7.339 0 0 1-1.12 1.12c-.323.26-.778.247-1.115.006l-.254-.182a1 1 0 0 0-1.568.65l-.051.309c-.068.408-.38.74-.792.784a7.374 7.374 0 0 1-1.584 0c-.412-.045-.724-.376-.792-.784l-.051-.31a1 1 0 0 0-1.568-.649l-.254.182c-.337.24-.792.254-1.114-.005a7.346 7.346 0 0 1-1.121-1.12c-.26-.323-.246-.778-.005-1.115Zm.836-7.465c.256-.31.542-.597.853-.853l.223.159a2 2 0 0 0 3.136-1.299l.045-.27a6.389 6.389 0 0 1 1.207 0l.045.27a2 2 0 0 0 3.136 1.299l.223-.16c.311.257.597.543.854.854l-.16.223a2 2 0 0 0 1.3 3.136l.27.045a6.398 6.398 0 0 1 0 1.207l-.27.045a2 2 0 0 0-1.3 3.136l.16.224c-.257.31-.543.597-.854.853l-.223-.16a2 2 0 0 0-3.136 1.3l-.045.27a6.395 6.395 0 0 1-1.207 0l-.045-.27a2 2 0 0 0-3.136-1.3l-.223.16a6.348 6.348 0 0 1-.853-.854l.159-.223a2 2 0 0 0-1.299-3.136l-.27-.045a6.389 6.389 0 0 1 0-1.207l.27-.045a2 2 0 0 0 1.299-3.136l-.16-.223Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'server-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 3a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v2a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3Zm2 1V3h1v1H2Zm2 0V3h1v1H4ZM0 11a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v2a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2v-2Zm2 1v-1h1v1H2Zm2 0v-1h1v1H4Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'server': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M2 3v1h1V3H2ZM4 3v1h1V3H4Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 3a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v2a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3Zm2-1a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H2Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M2 11v1h1v-1H2ZM4 11v1h1v-1H4Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2 9a2 2 0 0 0-2 2v2a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-2a2 2 0 0 0-2-2H2Zm-1 2a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1v-2Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'send-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.225 1.407a.5.5 0 0 0-.649-.626l-13.747 5a.5.5 0 0 0-.015.933l6.051 2.42 2.42 6.052a.5.5 0 0 0 .935-.015l4.999-13.747a.527.527 0 0 0 .006-.017Zm-1.121 1.197a.5.5 0 0 0-.708-.707l-6.25 6.25a.5.5 0 1 0 .708.707l6.25-6.25Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'send': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.225 1.407a.5.5 0 0 0-.649-.626l-13.747 5a.5.5 0 0 0-.015.933l6.051 2.42 2.42 6.052a.5.5 0 0 0 .935-.015l4.999-13.747a.527.527 0 0 0 .006-.017ZM7.837 8.87l1.89 4.728 3.783-10.4L7.837 8.87Zm-.707-.707 5.673-5.673L2.402 6.272 7.13 8.163Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'search': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6 2.625A3.375 3.375 0 0 0 2.625 6h.75A2.625 2.625 0 0 1 6 3.375v-.75Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 6.5a6.5 6.5 0 1 1 11.399 4.273.5.5 0 0 1 .205.123L15 14.293a.5.5 0 1 1-.707.707l-3.397-3.396a.5.5 0 0 1-.123-.205A6.5 6.5 0 0 1 0 6.5ZM6.5 1a5.5 5.5 0 1 0 0 11 5.5 5.5 0 0 0 0-11Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'screwdriver-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 2.5v1.293l3.484 3.484A1.99 1.99 0 0 1 9 7h.233a2 2 0 0 1 1.337.513l3.768 3.391A2 2 0 0 1 15 12.391V13a2 2 0 0 1-2 2h-.61a2 2 0 0 1-1.486-.662l-3.39-3.768A2 2 0 0 1 7 9.233V9c0-.37.101-.718.277-1.016L3.793 4.5H2.5L1 2l1-1 2.5 1.5Zm4.788 6.212a.3.3 0 1 1 .424-.424l3.207 3.207a1.3 1.3 0 0 1 .381.92v.085a.3.3 0 1 1-.6 0v-.086a.7.7 0 0 0-.205-.495L9.288 8.712Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'screwdriver': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M9.288 8.712a.3.3 0 1 1 .424-.424l3.207 3.207a1.3 1.3 0 0 1 .381.92v.085a.3.3 0 1 1-.6 0v-.086a.7.7 0 0 0-.205-.495L9.288 8.712Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 2.5v1.293l3.354 3.353a.498.498 0 0 1 .138.267 2.311 2.311 0 0 1 2.854.17l3.315 2.947A2.5 2.5 0 0 1 15 12.398v.102a2.5 2.5 0 0 1-2.5 2.5h-.102a2.5 2.5 0 0 1-1.868-.84l-2.946-3.313a2.311 2.311 0 0 1-.171-2.855.498.498 0 0 1-.267-.138L3.793 4.5H2.5L1 2l1-1 2.5 1.5ZM8 9.311a1.311 1.311 0 0 1 2.182-.98l3.314 2.946A1.5 1.5 0 0 1 14 12.398v.102a1.5 1.5 0 0 1-1.5 1.5h-.102a1.5 1.5 0 0 1-1.121-.504l-2.946-3.314A1.311 1.311 0 0 1 8 9.313Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'scissors': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.268 1.732a2.5 2.5 0 1 0-.39 3.854L7.294 8l-2.414 2.414a2.5 2.5 0 1 0 .707.707l8.268-8.267a.5.5 0 0 0-.708-.708L8 7.293 5.586 4.879a2.5 2.5 0 0 0-.318-3.147Zm-2.829.707a1.5 1.5 0 1 1 2.122 2.122 1.5 1.5 0 0 1-2.122-2.122Zm0 9a1.5 1.5 0 1 1 2.122 2.122 1.5 1.5 0 0 1-2.122-2.122Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M10.854 10.146a.5.5 0 0 0-.708.708l3 3a.5.5 0 0 0 .708-.708l-3-3Z'/%3e%3c/svg%3e")`,
                'scan': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16' %3e%3cpath fill='%230E1011' d='M3 2a1 1 0 0 0-1 1v2a.5.5 0 0 1-1 0V3a2 2 0 0 1 2-2h2a.5.5 0 0 1 0 1H3ZM10.5 1.5A.5.5 0 0 1 11 1h2a2 2 0 0 1 2 2v2a.5.5 0 0 1-1 0V3a1 1 0 0 0-1-1h-2a.5.5 0 0 1-.5-.5ZM1.5 10.5a.5.5 0 0 1 .5.5v2a1 1 0 0 0 1 1h2a.5.5 0 0 1 0 1H3a2 2 0 0 1-2-2v-2a.5.5 0 0 1 .5-.5ZM14.5 10.5a.5.5 0 0 1 .5.5v2a2 2 0 0 1-2 2h-2a.5.5 0 0 1 0-1h2a1 1 0 0 0 1-1v-2a.5.5 0 0 1 .5-.5ZM3 8a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9A.5.5 0 0 1 3 8ZM5 5.25A.25.25 0 0 1 5.25 5h5.5a.25.25 0 0 1 .25.25V6a.5.5 0 0 0 1 0v-.75C12 4.56 11.44 4 10.75 4h-5.5C4.56 4 4 4.56 4 5.25V6a.5.5 0 0 0 1 0v-.75ZM5 10a.5.5 0 0 0-1 0v.75c0 .69.56 1.25 1.25 1.25h5.5c.69 0 1.25-.56 1.25-1.25V10a.5.5 0 0 0-1 0v.75a.25.25 0 0 1-.25.25h-5.5a.25.25 0 0 1-.25-.25V10Z'/%3e%3c/svg%3e")`,
                'scan-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16' %3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 1a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V3a2 2 0 0 0-2-2H3Zm0 2.25A.25.25 0 0 1 3.25 3H5a.5.5 0 0 0 0-1H3.25C2.56 2 2 2.56 2 3.25V5a.5.5 0 0 0 1 0V3.25ZM11 2a.5.5 0 0 0 0 1h1.75a.25.25 0 0 1 .25.25V5a.5.5 0 0 0 1 0V3.25C14 2.56 13.44 2 12.75 2H11Zm-8 9a.5.5 0 0 0-1 0v1.75c0 .69.56 1.25 1.25 1.25H5a.5.5 0 0 0 0-1H3.25a.25.25 0 0 1-.25-.25V11Zm11 0a.5.5 0 0 0-1 0v1.75a.25.25 0 0 1-.25.25H11a.5.5 0 0 0 0 1h1.75c.69 0 1.25-.56 1.25-1.25V11ZM3.5 7.5a.5.5 0 0 0 0 1h9a.5.5 0 0 0 0-1h-9ZM6.05 6a.05.05 0 0 0-.05.05v.45a.5.5 0 0 1-1 0v-.45C5 5.47 5.47 5 6.05 5h3.9c.58 0 1.05.47 1.05 1.05v.45a.5.5 0 0 1-1 0v-.45A.05.05 0 0 0 9.95 6h-3.9ZM5.5 9a.5.5 0 0 1 .5.5v.45c0 .028.022.05.05.05h3.9a.05.05 0 0 0 .05-.05V9.5a.5.5 0 0 1 1 0v.45c0 .58-.47 1.05-1.05 1.05h-3.9C5.47 11 5 10.53 5 9.95V9.5a.5.5 0 0 1 .5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'save-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M9 5V3h1v2H9Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 1a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V3.293L12.707 1H3Zm2.75 5A.75.75 0 0 1 5 5.25V2h6v3.25a.75.75 0 0 1-.75.75h-4.5Zm-1 2a.75.75 0 0 0-.75.75V14h8V8.75a.75.75 0 0 0-.75-.75h-6.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'save': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M9.125 3v2h.75V3h-.75Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 1a2 2 0 0 0-2 2v10.5A1.5 1.5 0 0 0 2.5 15h11a1.5 1.5 0 0 0 1.5-1.5V3.293L12.707 1H3ZM2 3a1 1 0 0 1 1-1h1.125v3.5c0 .76.616 1.375 1.375 1.375h5c.76 0 1.375-.616 1.375-1.375V2h.418L14 3.707V13.5a.5.5 0 0 1-.5.5h-.625V9.5c0-.76-.616-1.375-1.375-1.375h-7c-.76 0-1.375.616-1.375 1.375V14H2.5a.5.5 0 0 1-.5-.5V3Zm9.125-1h-6.25v3.5c0 .345.28.625.625.625h5c.345 0 .625-.28.625-.625V2Zm1 7.5V14h-8.25V9.5c0-.345.28-.625.625-.625h7c.345 0 .625.28.625.625Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'rss-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M2 3a1 1 0 0 1 1-1 11 11 0 0 1 11 11 1 1 0 1 1-2 0 9 9 0 0 0-9-9 1 1 0 0 1-1-1Z'/%3e%3cpath fill='%230E1011' d='M2 8a1 1 0 0 1 1-1 6 6 0 0 1 6 6 1 1 0 1 1-2 0 4 4 0 0 0-4-4 1 1 0 0 1-1-1ZM3 14a1 1 0 1 0 0-2 1 1 0 0 0 0 2Z'/%3e%3c/svg%3e")`,
                'rss': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M2.5 2.5A.5.5 0 0 1 3 2a11 11 0 0 1 11 11 .5.5 0 0 1-1 0A10 10 0 0 0 3 3a.5.5 0 0 1-.5-.5ZM2.5 7.5A.5.5 0 0 1 3 7a6 6 0 0 1 6 6 .5.5 0 0 1-1 0 5 5 0 0 0-5-5 .5.5 0 0 1-.5-.5ZM3 14a1 1 0 1 0 0-2 1 1 0 0 0 0 2Z'/%3e%3c/svg%3e")`,
                'rows-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M1.5 5.5v-3a1 1 0 0 1 1-1h11a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1h-11a1 1 0 0 1-1-1ZM1.5 13.5v-3a1 1 0 0 1 1-1h11a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1h-11a1 1 0 0 1-1-1Z'/%3e%3c/svg%3e")`,
                'rows': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 2a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h11a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5h-11ZM1 2.5A1.5 1.5 0 0 1 2.5 1h11A1.5 1.5 0 0 1 15 2.5v3A1.5 1.5 0 0 1 13.5 7h-11A1.5 1.5 0 0 1 1 5.5v-3ZM2.5 10a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h11a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5h-11Zm-1.5.5A1.5 1.5 0 0 1 2.5 9h11a1.5 1.5 0 0 1 1.5 1.5v3a1.5 1.5 0 0 1-1.5 1.5h-11A1.5 1.5 0 0 1 1 13.5v-3Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'rotate-cw': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.95 2.853a.5.5 0 0 0 0-.707l-2-2a.5.5 0 0 0-.707.707L9.389 2H8.096a7 7 0 1 0 5.9 3.23.5.5 0 0 0-.842.54A6 6 0 1 1 8.096 3H9.39L8.243 4.146a.5.5 0 1 0 .707.708l2-2Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'rotate-ccw': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.146 2.853a.5.5 0 0 1 0-.707l2-2a.5.5 0 0 1 .708.707L6.707 2H8a7 7 0 1 1-5.9 3.23.5.5 0 1 1 .842.54A6 6 0 1 0 8 3H6.707l1.147 1.146a.5.5 0 1 1-.708.708l-2-2Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'rewind-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M13.367 11.9 8.7 8.4a.5.5 0 0 1 0-.8l4.667-3.5a.5.5 0 0 1 .8.4v7a.5.5 0 0 1-.8.4ZM6.367 11.9 1.7 8.4a.5.5 0 0 1 0-.8l4.667-3.5a.5.5 0 0 1 .8.4v7a.5.5 0 0 1-.8.4Z'/%3e%3c/svg%3e")`,
                'rewind': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 3.5a.5.5 0 0 0-.785-.411l-6.5 4.5a.5.5 0 0 0 0 .822l6.5 4.5A.5.5 0 0 0 8 12.5V8.608l6.215 4.303A.5.5 0 0 0 15 12.5v-9a.5.5 0 0 0-.785-.411L8 7.392V3.5Zm-1 8.046L1.878 8 7 4.454v7.092Zm7 0L8.878 8 14 4.454v7.092Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'repeat': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.146.146a.5.5 0 0 1 .708 0L14.207 3.5l-3.353 3.354a.5.5 0 1 1-.707-.708L12.293 4H5.5A2.5 2.5 0 0 0 3 6.5v1a.5.5 0 1 1-1 0v-1A3.5 3.5 0 0 1 5.5 3h6.793L10.147.854a.5.5 0 0 1 0-.708ZM13 9.5v-1a.5.5 0 0 1 1 0v1a3.5 3.5 0 0 1-3.5 3.5H3.707l2.147 2.146a.5.5 0 0 1-.708.708L1.793 12.5l3.353-3.354a.5.5 0 1 1 .708.708L3.707 12H10.5A2.5 2.5 0 0 0 13 9.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'refresh-cw': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8.854.854a.5.5 0 1 0-.708-.708L5.793 2.5l2.353 2.354a.5.5 0 1 0 .708-.708L7.707 3H8a5 5 0 0 1 2.939 9.045.5.5 0 0 0 .588.81A6 6 0 0 0 8 2h-.293L8.854.854ZM8 13a5 5 0 0 1-2.939-9.045.5.5 0 0 0-.588-.81A6 6 0 0 0 8 14h.293l-1.147 1.146a.5.5 0 0 0 .708.708l2.353-2.354-2.353-2.354a.5.5 0 0 0-.708.708L8.293 13H8Z'/%3e%3c/svg%3e")`,
                'refresh-ccw': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M7.146.854a.5.5 0 1 1 .708-.708L10.207 2.5 7.854 4.854a.5.5 0 1 1-.708-.708L8.293 3H8a5 5 0 0 0-2.939 9.045.5.5 0 1 1-.588.81A6 6 0 0 1 8 2h.293L7.146.854ZM8 13a5 5 0 0 0 2.939-9.045.5.5 0 0 1 .588-.81A6 6 0 0 1 8 14h-.293l1.147 1.146a.5.5 0 0 1-.708.708L5.793 13.5l2.353-2.354a.5.5 0 0 1 .708.708L7.707 13H8Z'/%3e%3c/svg%3e")`,
                'radio': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M3.886 1.69a.5.5 0 0 1-.099.7 7 7 0 0 0 .198 11.325.5.5 0 0 1-.574.819 8 8 0 0 1-.226-12.942.5.5 0 0 1 .7.098ZM12.114 1.69a.5.5 0 0 0 .099.7 7 7 0 0 1-.198 11.325.5.5 0 0 0 .574.819 8 8 0 0 0 .226-12.942.5.5 0 0 0-.7.098Z'/%3e%3cpath fill='%230E1011' d='M5.593 4.805a.5.5 0 1 0-.602-.798 5 5 0 0 0 .141 8.089.5.5 0 0 0 .574-.82 4 4 0 0 1-.113-6.47ZM10.309 4.105a.5.5 0 0 0 .098.7 4 4 0 0 1-.113 6.472.5.5 0 0 0 .574.819 5 5 0 0 0 .141-8.09.5.5 0 0 0-.7.1Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10 8a2 2 0 1 1-4 0 2 2 0 0 1 4 0ZM9 8a1 1 0 1 1-2 0 1 1 0 0 1 2 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'quote-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M3 6c0-1-.5-2-2-3 3.5 0 6 2.5 6 6.5a3.5 3.5 0 1 1-4-3.465V6ZM12 6c0-1-.5-2-2-3 3.5 0 6 2.5 6 6.5a3.5 3.5 0 1 1-4-3.465V6Z'/%3e%3c/svg%3e")`,
                'quote': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 9.5a3.5 3.5 0 0 1 3-3.465V6a2.743 2.743 0 0 0-.167-.95c-.11-.301-.28-.602-.523-.903C2.001 3.765 1.574 3.382 1 3c.66 0 1.284.089 1.863.26C5.353 3.996 7 6.254 7 9.5a3.5 3.5 0 1 1-7 0ZM4 6c0-.42-.065-.827-.2-1.221.288.189.55.41.785.658C5.444 6.345 6 7.71 6 9.5a2.5 2.5 0 1 1-2.858-2.475A1 1 0 0 0 4 6.028V6ZM9 9.5a3.5 3.5 0 0 1 3-3.465V6a2.743 2.743 0 0 0-.167-.95c-.11-.301-.28-.602-.523-.903-.309-.382-.736-.765-1.31-1.147.66 0 1.284.089 1.863.26C14.353 3.996 16 6.254 16 9.5a3.5 3.5 0 1 1-7 0ZM13 6c0-.42-.065-.827-.2-1.221.288.189.55.41.785.658C14.444 6.345 15 7.71 15 9.5a2.5 2.5 0 1 1-2.858-2.475A1 1 0 0 0 13 6.03V6Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'printer-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 2a.5.5 0 0 0-.5.5V6h8V2.5a.5.5 0 0 0-.5-.5h-7ZM13 6V2.5A1.5 1.5 0 0 0 11.5 1h-7A1.5 1.5 0 0 0 3 2.5V6H2a2 2 0 0 0-2 2v3a2 2 0 0 0 2 2h1v1.5A1.5 1.5 0 0 0 4.5 16h7a1.5 1.5 0 0 0 1.5-1.5V13h1a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2h-1Zm-8.5 5a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h7a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5h-7Zm7-3a.5.5 0 0 0 0 1h1a.5.5 0 0 0 0-1h-1Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'printer': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 2a.5.5 0 0 0-.5.5V6h8V2.5a.5.5 0 0 0-.5-.5h-7ZM13 6V2.5A1.5 1.5 0 0 0 11.5 1h-7A1.5 1.5 0 0 0 3 2.5V6H2a2 2 0 0 0-2 2v3a2 2 0 0 0 2 2h1v1.5A1.5 1.5 0 0 0 4.5 16h7a1.5 1.5 0 0 0 1.5-1.5V13h1a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2h-1Zm0 6h1a1 1 0 0 0 1-1V8a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v3a1 1 0 0 0 1 1h1v-.5A1.5 1.5 0 0 1 4.5 10h7a1.5 1.5 0 0 1 1.5 1.5v.5Zm-2-3.5a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5ZM4.5 11a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h7a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5h-7Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'power': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 0a.5.5 0 0 1 .5.5v5.77a.5.5 0 0 1-1 0V.5A.5.5 0 0 1 8 0ZM5.539 2.075a.5.5 0 0 1-.249.662C3.05 3.754 1.5 5.989 1.5 8.577 1.5 12.119 4.405 15 8 15s6.5-2.88 6.5-6.423c0-2.588-1.55-4.823-3.79-5.84a.5.5 0 0 1 .413-.91c2.58 1.17 4.377 3.75 4.377 6.75C15.5 12.682 12.137 16 8 16 3.863 16 .5 12.682.5 8.577c0-3 1.797-5.58 4.377-6.75a.5.5 0 0 1 .662.248Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'pocket-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 1.5v7A6.5 6.5 0 0 0 7.5 15h1A6.5 6.5 0 0 0 15 8.5v-7a.5.5 0 0 0-.5-.5h-13a.5.5 0 0 0-.5.5Zm4 5V7a3 3 0 0 0 6 0v-.5h-1V7a2 2 0 1 1-4 0v-.5H5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'pocket': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 2a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1v6A7 7 0 1 1 1 8V2Zm13 0H2v6a6 6 0 0 0 12 0V2ZM5 7v-.5h1V7a2 2 0 1 0 4 0v-.5h1V7a3 3 0 0 1-6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'plus-square-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 1A2.5 2.5 0 0 0 1 3.5v9A2.5 2.5 0 0 0 3.5 15h9a2.5 2.5 0 0 0 2.5-2.5v-9A2.5 2.5 0 0 0 12.5 1h-9Zm5 4a.5.5 0 0 0-1 0v2.5H5a.5.5 0 0 0 0 1h2.5V11a.5.5 0 0 0 1 0V8.5H11a.5.5 0 0 0 0-1H8.5V5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'plus-square': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8.375 5a.375.375 0 1 0-.75 0v2.625H5a.375.375 0 1 0 0 .75h2.625V11a.375.375 0 0 0 .75 0V8.375H11a.375.375 0 0 0 0-.75H8.375V5Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 1A2.5 2.5 0 0 0 1 3.5v9A2.5 2.5 0 0 0 3.5 15h9a2.5 2.5 0 0 0 2.5-2.5v-9A2.5 2.5 0 0 0 12.5 1h-9ZM2 3.5A1.5 1.5 0 0 1 3.5 2h9A1.5 1.5 0 0 1 14 3.5v9a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 2 12.5v-9Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'plus-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 2a1 1 0 0 1 1 1v4h4a1 1 0 1 1 0 2H9v4a1 1 0 1 1-2 0V9H3a1 1 0 0 1 0-2h4V3a1 1 0 0 1 1-1Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'plus-circle-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0ZM8 4.5a.5.5 0 0 1 .5.5v2.5H11a.5.5 0 0 1 0 1H8.5V11a.5.5 0 0 1-1 0V8.5H5a.5.5 0 0 1 0-1h2.5V5a.5.5 0 0 1 .5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'plus-circle': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 4.5a.5.5 0 0 1 .5.5v2.5H11a.5.5 0 0 1 0 1H8.5V11a.5.5 0 0 1-1 0V8.5H5a.5.5 0 0 1 0-1h2.5V5a.5.5 0 0 1 .5-.5Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'plus': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 2.5a.5.5 0 0 1 .5.5v4.5H13a.5.5 0 0 1 0 1H8.5V13a.5.5 0 0 1-1 0V8.5H3a.5.5 0 0 1 0-1h4.5V3a.5.5 0 0 1 .5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'play-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M4 12.705v-9.41a1 1 0 0 1 1.526-.85l7.6 4.705a1 1 0 0 1 0 1.7l-7.6 4.705A1 1 0 0 1 4 12.705Z'/%3e%3c/svg%3e")`,
                'play-circle-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-9.03-3.44a.5.5 0 0 1 .513.024l4.5 3a.5.5 0 0 1 0 .832l-4.5 3A.5.5 0 0 1 6 11V5a.5.5 0 0 1 .264-.44Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'play-circle': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.264 4.56a.5.5 0 0 1 .513.024l4.5 3a.5.5 0 0 1 0 .832l-4.5 3A.5.5 0 0 1 6 11V5a.5.5 0 0 1 .264-.44ZM7 10.065 10.099 8 7 5.934v4.132Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'play': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.267 1.058a.5.5 0 0 1 .515.03l9.5 6.5a.5.5 0 0 1 0 .825l-9.5 6.5A.5.5 0 0 1 3 14.5v-13a.5.5 0 0 1 .267-.442ZM4 2.448v11.104L12.114 8 4 2.448Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'pinterest-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M15.294 8a7.3 7.3 0 0 1-9.357 7.005c.276-.44.572-.998.725-1.555.091-.33.522-2.04.522-2.04.258.492 1.011.926 1.813.926C11.382 12.336 13 10.16 13 7.25 13 5.05 11.136 3 8.303 3 4.777 3 3 5.527 3 7.635c0 1.276.483 2.412 1.52 2.835.17.07.322.002.37-.186l.073-.285c.03-.119.06-.24.08-.31.05-.187.03-.252-.107-.414-.3-.353-.49-.809-.49-1.455 0-1.875 1.403-3.554 3.653-3.554 1.993 0 3.087 1.218 3.087 2.843 0 2.14-.947 3.946-2.352 3.946-.776 0-1.357-.643-1.171-1.43.08-.34.189-.69.294-1.03.185-.6.36-1.17.36-1.603 0-.607-.325-1.114-1-1.114-.793 0-1.43.821-1.43 1.921 0 .7.236 1.174.236 1.174l-.954 4.043c-.13.547-.15 1.15-.132 1.66A7.301 7.301 0 0 1 7.995.7 7.3 7.3 0 0 1 15.295 8Z'/%3e%3c/svg%3e")`,
                'pinterest': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-1 0a6.3 6.3 0 0 1-7.87 6.102c.095-.212.178-.432.238-.652.091-.33.522-2.04.522-2.04.258.492 1.011.926 1.813.926C11.382 12.336 13 10.16 13 7.25 13 5.05 11.136 3 8.303 3 4.777 3 3 5.527 3 7.635c0 1.276.483 2.412 1.52 2.835.17.07.322.002.37-.186l.073-.285c.03-.119.06-.24.08-.31.05-.187.03-.252-.107-.414-.3-.353-.49-.809-.49-1.455 0-1.875 1.403-3.554 3.653-3.554 1.993 0 3.087 1.218 3.087 2.843 0 2.14-.947 3.946-2.352 3.946-.776 0-1.357-.643-1.171-1.43.08-.34.189-.69.294-1.03.185-.6.36-1.17.36-1.603 0-.607-.325-1.114-1-1.114-.793 0-1.43.821-1.43 1.921 0 .7.236 1.174.236 1.174l-.954 4.043a4.803 4.803 0 0 0-.097.566A6.3 6.3 0 1 1 14.294 8Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'pie-chart-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M16 7.5c0 .168-.005.335-.016.5H8V.016A7.5 7.5 0 0 1 16 7.5Z'/%3e%3cpath fill='%230E1011' d='M0 8.5a7.5 7.5 0 0 1 7-7.484V9h7.984A7.5 7.5 0 0 1 0 8.5Z'/%3e%3c/svg%3e")`,
                'pie-chart': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 7.5c0 .168-.005.335-.016.5H8V.016a7.612 7.612 0 0 1 1 0A7.501 7.501 0 0 1 16 7.5ZM14.981 7H9V1.019A6.501 6.501 0 0 1 14.981 7Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M14.984 9H7V1.016A7.503 7.503 0 0 0 0 8.5a7.5 7.5 0 0 0 14.984.5ZM6 9a1 1 0 0 0 1 1h6.826A6.5 6.5 0 1 1 6 2.174V9Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'phone-outgoing-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11.5 0a.5.5 0 0 0 0 1h2.793l-4.147 4.146a.5.5 0 0 0 .707.708L15 1.707V4.5a.5.5 0 0 0 1 0V0h-4.5Z'/%3e%3cpath fill='%230E1011' d='M15 13c0 1.105-.9 2.015-1.994 1.86a13.908 13.908 0 0 1-5.047-1.757 14.07 14.07 0 0 1-4.965-4.898A13.91 13.91 0 0 1 1.14 2.993C.986 1.9 1.896 1 3 1h2c.552 0 .994.45 1.054.998.097.876.32 1.715.65 2.497L5.089 6.11a.486.486 0 0 0-.083.584 11.554 11.554 0 0 0 4.475 4.397c.19.104.424.066.577-.087l1.632-1.632a8.944 8.944 0 0 0 2.312.573c.549.06.998.503.998 1.055v2Z'/%3e%3c/svg%3e")`,
                'phone-outgoing': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11.5 0a.5.5 0 0 0 0 1h2.793l-4.146 4.146a.5.5 0 1 0 .707.708L15 1.707V4.5a.5.5 0 0 0 1 0V0h-4.5Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.27 9.297c-1.1-1.61-1.849-4.03-2.138-6.303C.993 1.898 1.895 1 3 1h2.6c.552 0 1 .448 1.049.998.085.972.28 2.113.568 2.885.074.2.038.43-.113.581l-.856.856a.483.483 0 0 0-.073.6A9.382 9.382 0 0 0 9.24 9.922c.19.116.434.08.591-.078l.877-.877a.549.549 0 0 1 .57-.118c.73.253 1.805.425 2.724.503.55.046.998.495.998 1.047V13c0 1.105-.898 2.007-1.994 1.868-2.216-.28-4.579-.993-6.157-2.04a13.138 13.138 0 0 1-3.578-3.531Zm2.27-3.684a1.483 1.483 0 0 0-.21 1.841 10.382 10.382 0 0 0 3.392 3.325c.605.366 1.35.24 1.816-.226l.673-.674c.815.244 1.85.398 2.706.47.03.003.055.016.071.033.008.008.01.013.011.015L14 10.4V13c0 .587-.451.929-.869.876-2.127-.268-4.324-.949-5.729-1.882a12.139 12.139 0 0 1-3.305-3.261C3.116 7.298 2.4 5.048 2.124 2.868 2.071 2.451 2.413 2 3 2h2.603c.002.001.008.004.015.012a.119.119 0 0 1 .034.074c.08.912.256 2.015.535 2.88l-.646.647Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'phone-off-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M14.896.396a.5.5 0 0 1 .708.708L7.229 9.478a11.53 11.53 0 0 0 2.252 1.614c.19.103.424.065.577-.088l1.633-1.632a8.944 8.944 0 0 0 2.311.573c.549.06.998.503.998 1.055v2c0 1.105-.9 2.015-1.993 1.86a13.908 13.908 0 0 1-5.048-1.757 14.052 14.052 0 0 1-2.499-1.856l-4.356 4.357a.5.5 0 0 1-.708-.708l14.5-14.5ZM2.994 8.205c.224.372.464.733.72 1.08l1.793-1.792a11.503 11.503 0 0 1-.5-.799.486.486 0 0 1 .083-.584l1.614-1.615a8.941 8.941 0 0 1-.65-2.497C5.995 1.449 5.553 1 5 1H3c-1.105 0-2.015.9-1.86 1.993a13.91 13.91 0 0 0 1.854 5.212Z'/%3e%3c/svg%3e")`,
                'phone-off': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.604.396a.5.5 0 0 1 0 .708L8.016 8.69c.545.4 1.25.741 1.619.908l1.025-.683a1 1 0 0 1 .83-.13l2.785.796a1 1 0 0 1 .725.962V13c0 1.087-.896 2.044-2.055 1.911a13.454 13.454 0 0 1-7.63-3.518l-4.211 4.21a.5.5 0 0 1-.708-.707l6.175-6.174.001-.002h.001l.001-.001L14.896.396a.5.5 0 0 1 .708 0ZM7.279 9.428c-.001 0 0 0 0 0a.05.05 0 0 1 .016-.002.1.1 0 0 1 .06.02c.773.585 1.818 1.046 2.073 1.155.2.085.42.057.59-.055l1.197-.798 2.785.796V13c0 .57-.453.974-.94.918a12.453 12.453 0 0 1-7.038-3.233L7.277 9.43l-.353-.354.355.352ZM3 2c-.57 0-.974.453-.918.94a12.434 12.434 0 0 0 2.459 6.115.5.5 0 1 1-.797.605A13.434 13.434 0 0 1 1.09 3.054C.956 1.896 1.913 1 3 1h2.456a1 1 0 0 1 .962.725l.796 2.786a1 1 0 0 1-.13.83l-.683 1.024c.072.16.178.386.31.636a.5.5 0 1 1-.887.464 13.102 13.102 0 0 1-.425-.893.621.621 0 0 1 .055-.59l.798-1.197L5.456 2H3Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'phone-missed-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11.853.146a.5.5 0 1 0-.707.708L12.792 2.5l-1.646 1.646a.5.5 0 1 0 .707.708L13.5 3.207l1.646 1.647a.5.5 0 1 0 .707-.708L14.207 2.5 15.853.854a.5.5 0 1 0-.707-.708L13.5 1.793 11.853.146ZM15 13c0 1.105-.9 2.015-1.994 1.86a13.908 13.908 0 0 1-5.047-1.757 14.07 14.07 0 0 1-4.965-4.898A13.91 13.91 0 0 1 1.14 2.993C.986 1.9 1.896 1 3 1h2c.552 0 .994.45 1.054.998.097.876.32 1.715.65 2.497L5.089 6.11a.486.486 0 0 0-.083.584 11.554 11.554 0 0 0 4.475 4.397c.19.104.424.066.577-.087l1.632-1.632a8.944 8.944 0 0 0 2.312.573c.549.06.998.503.998 1.055v2Z'/%3e%3c/svg%3e")`,
                'phone-missed': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11.854.146a.5.5 0 1 0-.707.708L12.793 2.5l-1.646 1.646a.5.5 0 1 0 .707.708L13.5 3.207l1.646 1.647a.5.5 0 1 0 .708-.708L14.207 2.5 15.854.854a.5.5 0 1 0-.707-.708L13.5 1.793 11.854.146Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.27 9.297c-1.1-1.61-1.849-4.03-2.138-6.303C.993 1.898 1.895 1 3 1h2.6c.552 0 1 .448 1.049.998.085.972.28 2.113.568 2.885.074.2.038.43-.113.581l-.856.856a.483.483 0 0 0-.073.6A9.382 9.382 0 0 0 9.24 9.922c.19.116.434.08.591-.078l.877-.877a.549.549 0 0 1 .57-.118c.73.253 1.805.425 2.724.503.55.046.998.495.998 1.047V13c0 1.105-.898 2.007-1.994 1.868-2.216-.28-4.579-.993-6.157-2.04a13.138 13.138 0 0 1-3.578-3.531Zm2.27-3.684a1.483 1.483 0 0 0-.21 1.841 10.382 10.382 0 0 0 3.392 3.325c.605.366 1.35.24 1.816-.226l.673-.674c.815.244 1.85.398 2.706.47.03.003.055.016.071.033.008.008.01.013.011.015L14 10.4V13c0 .587-.451.929-.869.876-2.127-.268-4.324-.949-5.729-1.882a12.139 12.139 0 0 1-3.305-3.261C3.116 7.298 2.4 5.048 2.124 2.868 2.071 2.451 2.413 2 3 2h2.603c.002.001.008.004.015.012a.119.119 0 0 1 .034.074c.08.912.256 2.015.535 2.88l-.646.647Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'phone-incoming-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M15.853.854a.5.5 0 1 0-.707-.708L11 4.293V1.5a.5.5 0 0 0-1 0V6h4.5a.5.5 0 0 0 0-1h-2.793L15.853.854Z'/%3e%3cpath fill='%230E1011' d='M15 13c0 1.105-.9 2.015-1.994 1.86a13.908 13.908 0 0 1-5.047-1.757 14.07 14.07 0 0 1-4.965-4.898A13.91 13.91 0 0 1 1.14 2.993C.986 1.9 1.896 1 3 1h2c.552 0 .994.45 1.054.998.097.876.32 1.715.65 2.497L5.089 6.11a.486.486 0 0 0-.083.584 11.554 11.554 0 0 0 4.475 4.397c.19.104.424.066.577-.087l1.632-1.632a8.944 8.944 0 0 0 2.312.573c.549.06.998.503.998 1.055v2Z'/%3e%3c/svg%3e")`,
                'phone-incoming': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M15.854.854a.5.5 0 1 0-.707-.708L11 4.293V1.5a.5.5 0 1 0-1 0V6h4.5a.5.5 0 1 0 0-1h-2.793L15.854.854Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.27 9.297c-1.1-1.61-1.849-4.03-2.138-6.303C.993 1.898 1.895 1 3 1h2.6c.552 0 1 .448 1.049.998.085.972.28 2.113.568 2.885.074.2.038.43-.113.581l-.856.856a.483.483 0 0 0-.073.6A9.382 9.382 0 0 0 9.24 9.922c.19.116.434.08.591-.078l.877-.877a.549.549 0 0 1 .57-.118c.73.253 1.805.425 2.724.503.55.046.998.495.998 1.047V13c0 1.105-.898 2.007-1.994 1.868-2.216-.28-4.579-.993-6.157-2.04a13.138 13.138 0 0 1-3.578-3.531Zm2.27-3.684a1.483 1.483 0 0 0-.21 1.841 10.382 10.382 0 0 0 3.392 3.325c.605.366 1.35.24 1.816-.226l.673-.674c.815.244 1.85.398 2.706.47.03.003.055.016.071.033.008.008.01.013.011.015L14 10.4V13c0 .587-.451.929-.869.876-2.127-.268-4.324-.949-5.729-1.882a12.139 12.139 0 0 1-3.305-3.261C3.116 7.298 2.4 5.048 2.124 2.868 2.071 2.451 2.413 2 3 2h2.603c.002.001.008.004.015.012a.119.119 0 0 1 .034.074c.08.912.256 2.015.535 2.88l-.646.647Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'phone-forwarded-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M12.353.146a.5.5 0 1 0-.707.708L13.792 3H9a.5.5 0 0 0 0 1h4.793l-2.147 2.146a.5.5 0 1 0 .707.708L15.707 3.5 12.353.146ZM15 13c0 1.105-.9 2.015-1.994 1.86a13.908 13.908 0 0 1-5.047-1.757 14.07 14.07 0 0 1-4.965-4.898A13.91 13.91 0 0 1 1.14 2.993C.986 1.9 1.896 1 3 1h2c.552 0 .994.45 1.054.998.097.876.32 1.715.65 2.497L5.089 6.11a.486.486 0 0 0-.083.584 11.554 11.554 0 0 0 4.475 4.397c.19.104.424.066.577-.087l1.632-1.632a8.944 8.944 0 0 0 2.312.573c.549.06.998.503.998 1.055v2Z'/%3e%3c/svg%3e")`,
                'phone-forwarded': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 17 16'%3e%3cpath fill='%230E1011' d='M12.854.146a.5.5 0 1 0-.707.708L14.293 3H9.5a.5.5 0 0 0 0 1h4.793l-2.146 2.146a.5.5 0 1 0 .707.708L16.207 3.5 12.854.146Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.27 9.297c-1.1-1.61-1.849-4.03-2.138-6.303C.993 1.898 1.895 1 3 1h2.6c.552 0 1 .448 1.049.998.085.972.28 2.113.568 2.885.074.2.038.43-.113.581l-.856.856a.483.483 0 0 0-.073.6A9.382 9.382 0 0 0 9.24 9.922c.19.116.434.08.591-.078l.877-.877a.549.549 0 0 1 .57-.118c.73.253 1.805.425 2.724.503.55.046.998.495.998 1.047V13c0 1.105-.898 2.007-1.994 1.868-2.216-.28-4.579-.993-6.157-2.04a13.138 13.138 0 0 1-3.578-3.531Zm2.27-3.684a1.483 1.483 0 0 0-.21 1.841 10.382 10.382 0 0 0 3.392 3.325c.605.366 1.35.24 1.816-.226l.673-.674c.815.244 1.85.398 2.706.47.03.003.055.016.071.033.008.008.01.013.011.015L14 10.4V13c0 .587-.451.929-.869.876-2.127-.268-4.324-.949-5.729-1.882a12.139 12.139 0 0 1-3.305-3.261C3.116 7.298 2.4 5.048 2.124 2.868 2.071 2.451 2.413 2 3 2h2.603c.002.001.008.004.015.012a.119.119 0 0 1 .034.074c.08.912.256 2.015.535 2.88l-.646.647Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'phone-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M13.007 14.86C14.1 15.014 15 14.104 15 13v-2c0-.552-.45-.994-.998-1.055a8.943 8.943 0 0 1-2.312-.573l-1.632 1.632a.486.486 0 0 1-.577.088 11.554 11.554 0 0 1-4.475-4.398.486.486 0 0 1 .084-.584l1.614-1.615a8.941 8.941 0 0 1-.65-2.497C5.995 1.449 5.553 1 5 1H3c-1.105 0-2.015.9-1.86 1.993a13.91 13.91 0 0 0 1.854 5.212 14.07 14.07 0 0 0 4.965 4.898 13.908 13.908 0 0 0 5.048 1.756Z'/%3e%3c/svg%3e")`,
                'phone-call-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M9.897.253a.5.5 0 1 0-.11.994 5.5 5.5 0 0 1 4.858 4.852.5.5 0 1 0 .994-.111A6.5 6.5 0 0 0 9.897.253ZM9.938 2.926a.5.5 0 1 0-.192.981 2.833 2.833 0 0 1 2.238 2.239.5.5 0 0 0 .982-.192 3.833 3.833 0 0 0-3.028-3.028ZM15 13c0 1.105-.9 2.015-1.994 1.86a13.908 13.908 0 0 1-5.047-1.757 14.07 14.07 0 0 1-4.965-4.898A13.91 13.91 0 0 1 1.14 2.993C.986 1.9 1.896 1 3 1h2c.552 0 .994.45 1.054.998.097.877.32 1.715.65 2.497L5.089 6.11a.486.486 0 0 0-.083.584 11.555 11.555 0 0 0 4.475 4.398c.19.104.424.065.577-.088l1.632-1.632a8.943 8.943 0 0 0 2.312.573c.549.06.998.503.998 1.055v2Z'/%3e%3c/svg%3e")`,
                'phone-call': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M9.897.253a.5.5 0 0 0-.11.994 5.5 5.5 0 0 1 4.858 4.852.5.5 0 0 0 .994-.111A6.5 6.5 0 0 0 9.897.253ZM9.938 2.926a.5.5 0 1 0-.192.981 2.834 2.834 0 0 1 2.239 2.239.5.5 0 1 0 .981-.192 3.834 3.834 0 0 0-3.028-3.028Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.27 9.297c-1.1-1.61-1.849-4.03-2.138-6.303C.993 1.898 1.895 1 3 1h2.6c.552 0 1 .448 1.049.998.085.972.28 2.113.568 2.885.074.2.038.43-.113.581l-.856.856a.483.483 0 0 0-.073.6A9.382 9.382 0 0 0 9.24 9.922c.19.116.434.08.591-.077l.877-.878a.549.549 0 0 1 .57-.118c.73.253 1.805.425 2.724.503.55.046.998.495.998 1.047V13c0 1.105-.898 2.007-1.994 1.868-2.216-.279-4.579-.993-6.157-2.04a13.14 13.14 0 0 1-3.578-3.531Zm2.27-3.684a1.483 1.483 0 0 0-.21 1.841 10.381 10.381 0 0 0 3.392 3.325c.605.366 1.35.24 1.816-.226l.673-.674c.815.244 1.85.398 2.706.47.03.003.055.016.071.033.008.008.01.013.011.015L14 10.4V13c0 .587-.451.929-.869.876-2.127-.268-4.324-.949-5.729-1.882a12.138 12.138 0 0 1-3.305-3.261C3.116 7.298 2.4 5.048 2.124 2.868 2.071 2.451 2.413 2 3 2h2.603c.002.001.008.004.015.012a.119.119 0 0 1 .034.074c.08.912.256 2.015.535 2.88l-.646.647Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'phone': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.33 7.454a1.483 1.483 0 0 1 .21-1.841l.647-.647c-.28-.865-.455-1.968-.535-2.88a.119.119 0 0 0-.034-.074A.055.055 0 0 0 5.603 2L5.6 2H3c-.588 0-.929.451-.876.868.277 2.18.992 4.43 1.972 5.865a12.139 12.139 0 0 0 3.306 3.261c1.405.933 3.602 1.614 5.729 1.882.418.053.869-.289.869-.876v-2.603a.055.055 0 0 0-.012-.015.113.113 0 0 0-.07-.033c-.857-.072-1.892-.226-2.707-.47l-.673.674a1.483 1.483 0 0 1-1.816.226A10.382 10.382 0 0 1 5.33 7.454Zm-4.198-4.46c.289 2.273 1.038 4.693 2.139 6.303a13.138 13.138 0 0 0 3.578 3.53c1.578 1.048 3.94 1.762 6.157 2.041C14.102 15.007 15 14.105 15 13v-2.6c0-.552-.448-1-.998-1.047-.919-.078-1.995-.25-2.725-.503a.549.549 0 0 0-.569.118l-.877.877a.483.483 0 0 1-.591.078A9.382 9.382 0 0 1 6.175 6.92a.483.483 0 0 1 .073-.6l.856-.855a.549.549 0 0 0 .113-.58c-.288-.773-.483-1.914-.568-2.886C6.6 1.448 6.152 1 5.6 1H3c-1.105 0-2.007.898-1.868 1.994Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'percent': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M13.854 2.396a.5.5 0 0 1 0 .708l-11 11a.5.5 0 0 1-.708-.708l11-11a.5.5 0 0 1 .708 0Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2 4.25a2 2 0 1 1 4 0 2 2 0 0 1-4 0Zm2-1a1 1 0 1 0 0 2 1 1 0 0 0 0-2ZM12 10.25a2 2 0 1 0 0 4 2 2 0 0 0 0-4Zm-1 2a1 1 0 1 1 2 0 1 1 0 0 1-2 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'pen-tool-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6.204 6.204a1.354 1.354 0 1 0 1.914 1.914 1.354 1.354 0 0 0-1.914-1.914Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.18.18A.5.5 0 0 1 .666.053L11.63 3.017a.5.5 0 0 1 .351.351l1.351 4.954c.373-.05.764.068 1.05.355l.94.94a1.25 1.25 0 0 1 0 1.767l-3.94 3.94a1.25 1.25 0 0 1-1.767 0l-.94-.94a1.248 1.248 0 0 1-.354-1.05l-4.954-1.352a.5.5 0 0 1-.35-.351L.051.665A.5.5 0 0 1 .18.18ZM.27.27a.375.375 0 0 1 .53 0l5.163 5.163a2.104 2.104 0 1 1-.53.53L.269.799a.375.375 0 0 1 0-.53Zm12.746 8.216a.375.375 0 0 1 0 .53l-4 4a.375.375 0 1 1-.53-.53l4-4a.375.375 0 0 1 .53 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'pen-tool': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.18.18A.5.5 0 0 1 .666.053L11.63 3.017a.5.5 0 0 1 .351.351l1.351 4.954c.373-.05.764.068 1.05.355l.94.94a1.25 1.25 0 0 1 0 1.767l-3.94 3.94a1.25 1.25 0 0 1-1.767 0l-.94-.94a1.248 1.248 0 0 1-.354-1.05l-4.954-1.352a.5.5 0 0 1-.35-.351L.051.665A.5.5 0 0 1 .18.18Zm8.672 12.261 3.59-3.59-1.349-4.943L1.971 1.44l3.991 3.99a2.104 2.104 0 1 1-.53.531L1.44 1.972l2.467 9.121 4.944 1.348Zm.532.882a.25.25 0 0 0 0 .354l.94.94a.25.25 0 0 0 .353 0l3.94-3.94a.25.25 0 0 0 0-.354l-.94-.94a.25.25 0 0 0-.354 0l-3.94 3.94Zm-3.18-7.12a1.354 1.354 0 1 0 1.914 1.915 1.354 1.354 0 0 0-1.914-1.914Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'pause-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 3.25C3 2.56 3.56 2 4.25 2h1.5C6.44 2 7 2.56 7 3.25v9.5C7 13.44 6.44 14 5.75 14h-1.5C3.56 14 3 13.44 3 12.75v-9.5ZM4.25 3a.25.25 0 0 0-.25.25v9.5c0 .138.112.25.25.25h1.5a.25.25 0 0 0 .25-.25v-9.5A.25.25 0 0 0 5.75 3h-1.5Zm6 0a.25.25 0 0 0-.25.25v9.5c0 .138.112.25.25.25h1.5a.25.25 0 0 0 .25-.25v-9.5a.25.25 0 0 0-.25-.25h-1.5ZM9 3.25C9 2.56 9.56 2 10.25 2h1.5c.69 0 1.25.56 1.25 1.25v9.5c0 .69-.56 1.25-1.25 1.25h-1.5C9.56 14 9 13.44 9 12.75v-9.5Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M4 3.25A.25.25 0 0 1 4.25 3h1.5a.25.25 0 0 1 .25.25v9.5a.25.25 0 0 1-.25.25h-1.5a.25.25 0 0 1-.25-.25v-9.5ZM10 3.25a.25.25 0 0 1 .25-.25h1.5a.25.25 0 0 1 .25.25v9.5a.25.25 0 0 1-.25.25h-1.5a.25.25 0 0 1-.25-.25v-9.5Z'/%3e%3c/svg%3e")`,
                'pause-circle-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0ZM6.5 5.5A.5.5 0 0 1 7 6v4a.5.5 0 0 1-1 0V6a.5.5 0 0 1 .5-.5Zm3 0a.5.5 0 0 1 .5.5v4a.5.5 0 0 1-1 0V6a.5.5 0 0 1 .5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'pause-circle': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6.5 5.5A.5.5 0 0 1 7 6v4a.5.5 0 0 1-1 0V6a.5.5 0 0 1 .5-.5ZM9.5 5.5a.5.5 0 0 1 .5.5v4a.5.5 0 0 1-1 0V6a.5.5 0 0 1 .5-.5Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'pause': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 3.25C3 2.56 3.56 2 4.25 2h1.5C6.44 2 7 2.56 7 3.25v9.5C7 13.44 6.44 14 5.75 14h-1.5C3.56 14 3 13.44 3 12.75v-9.5ZM4.25 3a.25.25 0 0 0-.25.25v9.5c0 .138.112.25.25.25h1.5a.25.25 0 0 0 .25-.25v-9.5A.25.25 0 0 0 5.75 3h-1.5Zm6 0a.25.25 0 0 0-.25.25v9.5c0 .138.112.25.25.25h1.5a.25.25 0 0 0 .25-.25v-9.5a.25.25 0 0 0-.25-.25h-1.5ZM9 3.25C9 2.56 9.56 2 10.25 2h1.5c.69 0 1.25.56 1.25 1.25v9.5c0 .69-.56 1.25-1.25 1.25h-1.5C9.56 14 9 13.44 9 12.75v-9.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'paperclip': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 17'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M13.268 1.732a2.5 2.5 0 0 0-3.536 0l-7.05 7.05a3.5 3.5 0 0 0 0 4.95l.343.343a3.5 3.5 0 0 0 4.95 0l5.429-5.429.707.708-5.429 5.429a4.5 4.5 0 0 1-6.364 0l-.343-.344a4.5 4.5 0 0 1 0-6.364l7.05-7.05a3.5 3.5 0 0 1 4.95 4.95l-6.749 6.748a2.354 2.354 0 1 1-3.328-3.328L9.404 3.89l.707.707-5.506 5.506a1.354 1.354 0 1 0 1.914 1.914l6.749-6.748a2.5 2.5 0 0 0 0-3.536Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'package-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M4.023 2.15 1.117 3.354a.999.999 0 0 0-.275.17.498.498 0 0 1 .366.02l6.785 3.108 2.378-1.159-6.095-3.047a.498.498 0 0 1-.253-.298ZM5.058 1.72l6.458 3.229 3.287-1.409a.498.498 0 0 1 .355-.014.998.998 0 0 0-.275-.171L8.383.659a1 1 0 0 0-.766 0L5.058 1.72ZM15.487 4.115a.5.5 0 0 1-.29.344l-3.489 1.496L8.5 7.518V15a.5.5 0 0 1-.215.41c.033-.009.066-.02.098-.034l6.5-2.696a1 1 0 0 0 .617-.924V4.278c0-.055-.005-.11-.013-.163ZM7.715 15.41A.5.5 0 0 1 7.5 15V7.527L.792 4.455a.5.5 0 0 1-.279-.34 1.001 1.001 0 0 0-.013.163v7.478a1 1 0 0 0 .617.924l6.5 2.696c.032.013.065.025.098.035Z'/%3e%3c/svg%3e")`,
                'package': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.575.197a1.5 1.5 0 0 0-1.15 0l-6.5 2.696A1.5 1.5 0 0 0 0 4.278v7.478a1.5 1.5 0 0 0 .925 1.386l6.5 2.696a1.5 1.5 0 0 0 1.15 0l6.5-2.696A1.5 1.5 0 0 0 16 11.756V4.278a1.5 1.5 0 0 0-.925-1.385L8.575.197Zm-.767.924a.5.5 0 0 1 .384 0l5.88 2.439-2.565 1.1-5.812-2.663 2.113-.876ZM4.435 2.52 1.928 3.56 8 6.162l2.266-.971L4.435 2.52ZM1 4.25 1 4.278v7.478a.5.5 0 0 0 .308.462L7.5 14.786v-7.75L1 4.25ZM8.5 14.786l6.192-2.568a.5.5 0 0 0 .308-.462V4.25L8.5 7.036v7.75Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'octagon-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.541.146A.5.5 0 0 1 4.895 0h6.21a.5.5 0 0 1 .354.146l4.395 4.395a.5.5 0 0 1 .146.354v6.21a.5.5 0 0 1-.146.354l-4.395 4.395a.5.5 0 0 1-.354.146h-6.21a.5.5 0 0 1-.354-.146L.146 11.459A.5.5 0 0 1 0 11.105v-6.21a.5.5 0 0 1 .146-.354L4.541.146ZM5.102 1 1 5.102v5.796L5.102 15h5.796L15 10.898V5.102L10.898 1H5.102Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1 5.102 5.102 1h5.796L15 5.102v5.796L10.898 15H5.102L1 10.898V5.102Z'/%3e%3c/svg%3e")`,
                'octagon': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.541.146A.5.5 0 0 1 4.895 0h6.21a.5.5 0 0 1 .354.146l4.395 4.395a.5.5 0 0 1 .146.354v6.21a.5.5 0 0 1-.146.354l-4.395 4.395a.5.5 0 0 1-.354.146h-6.21a.5.5 0 0 1-.354-.146L.146 11.459A.5.5 0 0 1 0 11.105v-6.21a.5.5 0 0 1 .146-.354L4.541.146ZM5.102 1 1 5.102v5.796L5.102 15h5.796L15 10.898V5.102L10.898 1H5.102Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'navigation-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M14.854 1.146a.5.5 0 0 1 .1.564l-6 13a.5.5 0 0 1-.947-.128l-.941-5.648-5.648-.94a.5.5 0 0 1-.128-.948l13-6a.5.5 0 0 1 .564.1ZM3.184 7.274l4.398.733a.5.5 0 0 1 .411.41l.733 4.4 4.751-10.294-10.293 4.75Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='m7.582 8.007-4.398-.733 10.293-4.751-4.75 10.293-.734-4.398a.5.5 0 0 0-.41-.411Z'/%3e%3c/svg%3e")`,
                'navigation-2-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.167 1a.5.5 0 0 1 .469.327l4.667 12.667a.5.5 0 0 1-.718.607l-4.418-2.525L3.748 14.6a.5.5 0 0 1-.717-.607L7.698 1.327A.5.5 0 0 1 8.167 1ZM4.444 13.052l3.475-1.986a.5.5 0 0 1 .496 0l3.475 1.986L8.167 2.946 4.444 13.052Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='m7.919 11.066-3.475 1.986L8.167 2.946l3.723 10.106-3.475-1.986a.5.5 0 0 0-.496 0Z'/%3e%3c/svg%3e")`,
                'navigation-2': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.167 1a.5.5 0 0 1 .469.327l4.667 12.667a.5.5 0 0 1-.718.607l-4.418-2.525L3.748 14.6a.5.5 0 0 1-.717-.607L7.697 1.327A.5.5 0 0 1 8.167 1ZM4.444 13.052l3.475-1.986a.5.5 0 0 1 .496 0l3.475 1.986L8.167 2.946 4.444 13.052Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'navigation': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M14.854 1.146a.5.5 0 0 1 .1.564l-6 13a.5.5 0 0 1-.947-.128l-.941-5.648-5.648-.94a.5.5 0 0 1-.128-.948l13-6a.5.5 0 0 1 .564.1ZM3.184 7.274l4.398.733a.5.5 0 0 1 .411.41l.733 4.4 4.751-10.294-10.294 4.75Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'music-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M14 .837V11a2 2 0 0 1-2 2h-1a2 2 0 1 1 0-4h2V2.163l-5.637 1.61A.5.5 0 0 0 7 4.255V13a2 2 0 0 1-2 2H4a2 2 0 1 1 0-4h2V4.254a1.5 1.5 0 0 1 1.088-1.442L14 .837ZM6 12H4a1 1 0 1 0 0 2h1a1 1 0 0 0 1-1v-1Zm7-2h-2a1 1 0 1 0 0 2h1a1 1 0 0 0 1-1v-1Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M4 12h2v1a1 1 0 0 1-1 1H4a1 1 0 1 1 0-2ZM11 10h2v1a1 1 0 0 1-1 1h-1a1 1 0 1 1 0-2Z'/%3e%3c/svg%3e")`,
                'music': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M14 .837V11a2 2 0 0 1-2 2h-1a2 2 0 1 1 0-4h2V2.163l-5.637 1.61A.5.5 0 0 0 7 4.255V13a2 2 0 0 1-2 2H4a2 2 0 1 1 0-4h2V4.254a1.5 1.5 0 0 1 1.088-1.442L14 .837ZM6 12H4a1 1 0 1 0 0 2h1a1 1 0 0 0 1-1v-1Zm7-2h-2a1 1 0 1 0 0 2h1a1 1 0 0 0 1-1v-1Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'move': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m8 .293 2.354 2.353a.5.5 0 0 1-.708.708L8.5 2.207V7.5h5.293l-1.147-1.146a.5.5 0 0 1 .708-.708L15.707 8l-2.353 2.354a.5.5 0 0 1-.708-.708L13.793 8.5H8.5v5.293l1.146-1.147a.5.5 0 1 1 .708.707L8 15.707l-2.354-2.354a.5.5 0 1 1 .708-.707L7.5 13.793V8.5H2.207l1.147 1.146a.5.5 0 0 1-.708.707L.293 8l2.353-2.354a.5.5 0 1 1 .708.708L2.207 7.5H7.5V2.207L6.354 3.354a.5.5 0 1 1-.708-.708L8 .293Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'mouse-pointer-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M1.692 1.038a.5.5 0 0 0-.654.654l5.417 13a.5.5 0 0 0 .934-.031l1.527-4.495 3.575 3.575a.884.884 0 1 0 1.25-1.25l-3.575-3.575 4.495-1.527a.5.5 0 0 0 .031-.934l-13-5.417Z'/%3e%3c/svg%3e")`,
                'mouse-pointer': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.146 1.146a.5.5 0 0 1 .546-.108l13 5.417a.5.5 0 0 1-.031.934l-3.967 1.348 2.9 2.9a1.384 1.384 0 1 1-1.957 1.958l-2.9-2.901-1.348 3.967a.5.5 0 0 1-.935.031l-5.416-13a.5.5 0 0 1 .108-.546Zm1.282 1.282 4.44 10.658 1.18-3.475a.5.5 0 0 1 .827-.193l3.47 3.47a.384.384 0 1 0 .542-.543l-3.469-3.47a.5.5 0 0 1 .193-.827l3.474-1.18-10.657-4.44Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'more-vertical': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6.5 2a1.5 1.5 0 1 0 3 0 1.5 1.5 0 0 0-3 0ZM8 9.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3ZM8 15.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3Z'/%3e%3c/svg%3e")`,
                'more-horizontal': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M2 9.5a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3ZM9.5 8a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0ZM15.5 8a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0Z'/%3e%3c/svg%3e")`,
                'more-cirle-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 0 .695 8a7.3 7.3 0 0 0 14.6 0ZM5.25 8a1.25 1.25 0 1 1-2.5 0 1.25 1.25 0 0 1 2.5 0ZM8 9.25a1.25 1.25 0 1 0 0-2.5 1.25 1.25 0 0 0 0 2.5ZM13.25 8a1.25 1.25 0 1 1-2.5 0 1.25 1.25 0 0 1 2.5 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'more-cirle': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5.25 8a1.25 1.25 0 1 1-2.5 0 1.25 1.25 0 0 1 2.5 0ZM8 9.25a1.25 1.25 0 1 0 0-2.5 1.25 1.25 0 0 0 0 2.5ZM13.25 8a1.25 1.25 0 1 1-2.5 0 1.25 1.25 0 0 1 2.5 0Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 0 .695 8a7.3 7.3 0 0 0 14.6 0Zm-1 0A6.3 6.3 0 1 0 1.695 8a6.3 6.3 0 0 0 12.6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'moon-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.85 1.255a.5.5 0 0 1-.034.542 4.566 4.566 0 0 0 6.387 6.387.5.5 0 0 1 .795.448 7.014 7.014 0 1 1-7.63-7.63.5.5 0 0 1 .482.253Zm-1.418.93a6.014 6.014 0 1 0 7.384 7.383 5.565 5.565 0 0 1-7.384-7.384Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M4.335 3.229a6.014 6.014 0 0 1 2.097-1.045 5.566 5.566 0 0 0 7.384 7.384 6.015 6.015 0 1 1-9.48-6.34Z'/%3e%3c/svg%3e")`,
                'moon': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.85 1.255a.5.5 0 0 1-.034.542 4.566 4.566 0 0 0 6.387 6.387.5.5 0 0 1 .795.448 7.014 7.014 0 1 1-7.63-7.63.5.5 0 0 1 .482.253Zm-1.418.93a6.014 6.014 0 1 0 7.384 7.383 5.565 5.565 0 0 1-7.384-7.384Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'monitor-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 4.25C1 3.56 1.56 3 2.25 3h11.5c.69 0 1.25.56 1.25 1.25v6.5c0 .69-.56 1.25-1.25 1.25H2.25C1.56 12 1 11.44 1 10.75v-6.5ZM8.5 13h5.25A2.25 2.25 0 0 0 16 10.75v-6.5A2.25 2.25 0 0 0 13.75 2H2.25A2.25 2.25 0 0 0 0 4.25v6.5A2.25 2.25 0 0 0 2.25 13H7.5v1h-2a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-2v-1Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M2.25 3C1.56 3 1 3.56 1 4.25v6.5c0 .69.56 1.25 1.25 1.25h11.5c.69 0 1.25-.56 1.25-1.25v-6.5C15 3.56 14.44 3 13.75 3H2.25Z'/%3e%3c/svg%3e")`,
                'monitor': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.5 13h5.25A2.25 2.25 0 0 0 16 10.75v-6.5A2.25 2.25 0 0 0 13.75 2H2.25A2.25 2.25 0 0 0 0 4.25v6.5A2.25 2.25 0 0 0 2.25 13H7.5v1h-2a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-2v-1ZM1 4.25C1 3.56 1.56 3 2.25 3h11.5c.69 0 1.25.56 1.25 1.25v6.5c0 .69-.56 1.25-1.25 1.25H2.25C1.56 12 1 11.44 1 10.75v-6.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'minus-square-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 1A2.5 2.5 0 0 0 1 3.5v9A2.5 2.5 0 0 0 3.5 15h9a2.5 2.5 0 0 0 2.5-2.5v-9A2.5 2.5 0 0 0 12.5 1h-9ZM5 8a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5A.5.5 0 0 1 5 8Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'minus-square': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5 8a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5A.5.5 0 0 1 5 8Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 3.5A2.5 2.5 0 0 1 3.5 1h9A2.5 2.5 0 0 1 15 3.5v9a2.5 2.5 0 0 1-2.5 2.5h-9A2.5 2.5 0 0 1 1 12.5v-9ZM3.5 2h9A1.5 1.5 0 0 1 14 3.5v9a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 2 12.5v-9A1.5 1.5 0 0 1 3.5 2Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'minus-circle-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0ZM5 8a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5A.5.5 0 0 1 5 8Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'minus-circle': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5 8a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5A.5.5 0 0 1 5 8Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'minus': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.55 8A.45.45 0 0 1 3 7.55h10a.45.45 0 0 1 0 .9H3A.45.45 0 0 1 2.55 8Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'minimize-2': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M13.5 7a.5.5 0 0 0 0-1h-2.793l3.897-3.896a.5.5 0 0 0-.708-.708L10 5.293V2.5a.5.5 0 0 0-1 0V7h4.5ZM2.5 9a.5.5 0 0 0 0 1h2.793l-3.897 3.896a.5.5 0 0 0 .708.708L6 10.707V13.5a.5.5 0 0 0 1 0V9H2.5Z'/%3e%3c/svg%3e")`,
                'minimize': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6 2a.5.5 0 0 0-1 0v2a1 1 0 0 1-1 1H2a.5.5 0 0 0 0 1h2a2 2 0 0 0 2-2V2ZM6 14a.5.5 0 0 1-1 0v-2a1 1 0 0 0-1-1H2a.5.5 0 0 1 0-1h2a2 2 0 0 1 2 2v2ZM10.5 1.5a.5.5 0 0 0-.5.5v2a2 2 0 0 0 2 2h2a.5.5 0 0 0 0-1h-2a1 1 0 0 1-1-1V2a.5.5 0 0 0-.5-.5ZM10 14a.5.5 0 0 0 1 0v-2a1 1 0 0 1 1-1h2a.5.5 0 0 0 0-1h-2a2 2 0 0 0-2 2v2Z'/%3e%3c/svg%3e")`,
                'mic-off-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 0C6.64 0 5.439.679 4.716 1.716l6.93 6.93C11.874 8.144 12 7.586 12 7V4a4 4 0 0 0-4-4ZM4 4.707V7a4 4 0 0 0 5.844 3.55l1 1A3.982 3.982 0 0 1 9 12H7a4 4 0 0 1-4-4v-.25a.5.5 0 0 0-1 0V8a5 5 0 0 0 5 5h.5v2H6a.5.5 0 0 0 0 1h4a.5.5 0 0 0 0-1H8.5v-2H9c.943 0 1.825-.261 2.578-.715l3.318 3.319a.5.5 0 0 0 .708-.708L1.104.396a.5.5 0 1 0-.708.708L4 4.707ZM14 8c0 .866-.22 1.681-.608 2.392l-.745-.746C12.873 9.144 13 8.586 13 8v-.25a.5.5 0 0 1 1 0V8Z'/%3e%3c/svg%3e")`,
                'mic-off': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4 4.707.396 1.104a.5.5 0 1 1 .708-.708l14.5 14.5a.5.5 0 0 1-.708.708l-3.318-3.319A4.977 4.977 0 0 1 9 13h-.5v2H10a.5.5 0 0 1 0 1H6a.5.5 0 0 1 0-1h1.5v-2H7a5 5 0 0 1-5-5v-.25a.5.5 0 0 1 1 0V8a4 4 0 0 0 4 4h2c.665 0 1.292-.162 1.844-.45l-1-1A4 4 0 0 1 4 7V4.707Zm5.09 5.09A3 3 0 0 1 5 7V5.706l4.09 4.09Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='m11.646 8.646-.775-.775A3 3 0 0 0 11 7V4a3 3 0 0 0-5.562-1.562l-.722-.722A4 4 0 0 1 12 4v3c0 .587-.126 1.144-.354 1.646ZM12.646 9.646l.746.746C13.78 9.682 14 8.866 14 8v-.25a.5.5 0 0 0-1 0V8c0 .587-.126 1.144-.354 1.646Z'/%3e%3c/svg%3e")`,
                'mic-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 0a4 4 0 0 0-4 4v3a4 4 0 1 0 8 0V4a4 4 0 0 0-4-4Z'/%3e%3cpath fill='%230E1011' d='M3 7.75a.5.5 0 0 0-1 0V8a5 5 0 0 0 5 5h.5v2H6a.5.5 0 0 0 0 1h4a.5.5 0 0 0 0-1H8.5v-2H9a5 5 0 0 0 5-5v-.25a.5.5 0 0 0-1 0V8a4 4 0 0 1-4 4H7a4 4 0 0 1-4-4v-.25Z'/%3e%3c/svg%3e")`,
                'mic': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 0a4 4 0 0 0-4 4v3a4 4 0 1 0 8 0V4a4 4 0 0 0-4-4ZM5 4a3 3 0 0 1 6 0v3a3 3 0 0 1-6 0V4Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M3 7.75a.5.5 0 0 0-1 0V8a5 5 0 0 0 5 5h.5v2H6a.5.5 0 0 0 0 1h4a.5.5 0 0 0 0-1H8.5v-2H9a5 5 0 0 0 5-5v-.25a.5.5 0 0 0-1 0V8a4 4 0 0 1-4 4H7a4 4 0 0 1-4-4v-.25Z'/%3e%3c/svg%3e")`,
                'message-square-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 3A1.5 1.5 0 0 0 1 4.5v8.793l1.146-1.147A.5.5 0 0 1 2.5 12h11a1.5 1.5 0 0 0 1.5-1.5v-6A1.5 1.5 0 0 0 13.5 3h-11ZM0 4.5A2.5 2.5 0 0 1 2.5 2h11A2.5 2.5 0 0 1 16 4.5v6a2.5 2.5 0 0 1-2.5 2.5H2.707L0 15.707V4.5Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1 4.5A1.5 1.5 0 0 1 2.5 3h11A1.5 1.5 0 0 1 15 4.5v6a1.5 1.5 0 0 1-1.5 1.5h-11a.5.5 0 0 0-.354.146L1 13.293V4.5Z'/%3e%3c/svg%3e")`,
                'message-square': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 3A1.5 1.5 0 0 0 1 4.5v8.793l1.146-1.147A.5.5 0 0 1 2.5 12h11a1.5 1.5 0 0 0 1.5-1.5v-6A1.5 1.5 0 0 0 13.5 3h-11ZM0 4.5A2.5 2.5 0 0 1 2.5 2h11A2.5 2.5 0 0 1 16 4.5v6a2.5 2.5 0 0 1-2.5 2.5H2.707L0 15.707V4.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'message-circle-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 6.5A5.5 5.5 0 0 1 5.5 1h5A5.5 5.5 0 0 1 16 6.5v1a5.5 5.5 0 0 1-5.5 5.5h-5c-.252 0-.5-.017-.743-.05L2 15.707v-3.964A5.49 5.49 0 0 1 0 7.5v-1ZM5.5 2A4.5 4.5 0 0 0 1 6.5v1c0 1.472.706 2.779 1.8 3.6l.2.15v2.043l1.416-1.416.259.048c.267.05.543.075.825.075h5A4.5 4.5 0 0 0 15 7.5v-1A4.5 4.5 0 0 0 10.5 2h-5Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1 6.5A4.5 4.5 0 0 1 5.5 2h5A4.5 4.5 0 0 1 15 6.5v1a4.5 4.5 0 0 1-4.5 4.5h-5c-.282 0-.558-.026-.825-.075l-.259-.048L3 13.293V11.25l-.2-.15A4.493 4.493 0 0 1 1 7.5v-1Z'/%3e%3c/svg%3e")`,
                'message-circle': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 6.5A5.5 5.5 0 0 1 5.5 1h5A5.5 5.5 0 0 1 16 6.5v1a5.5 5.5 0 0 1-5.5 5.5h-5c-.252 0-.5-.017-.743-.05L2 15.707v-3.964A5.49 5.49 0 0 1 0 7.5v-1ZM5.5 2A4.5 4.5 0 0 0 1 6.5v1c0 1.472.706 2.779 1.8 3.6l.2.15v2.043l1.416-1.416.259.048c.267.05.543.075.825.075h5A4.5 4.5 0 0 0 15 7.5v-1A4.5 4.5 0 0 0 10.5 2h-5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'menu': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.5 3.5A.5.5 0 0 1 1 3h14a.5.5 0 0 1 0 1H1a.5.5 0 0 1-.5-.5Zm0 3A.5.5 0 0 1 1 6h14a.5.5 0 0 1 0 1H1a.5.5 0 0 1-.5-.5Zm0 3A.5.5 0 0 1 1 9h14a.5.5 0 0 1 0 1H1a.5.5 0 0 1-.5-.5Zm0 3A.5.5 0 0 1 1 12h9a.5.5 0 0 1 0 1H1a.5.5 0 0 1-.5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'meh-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0ZM5 6a1 1 0 1 1 2 0 1 1 0 0 1-2 0Zm4 0a1 1 0 1 1 2 0 1 1 0 0 1-2 0Zm-4 4.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'meh': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5 6a1 1 0 1 1 2 0 1 1 0 0 1-2 0ZM9 6a1 1 0 1 1 2 0 1 1 0 0 1-2 0ZM5 10.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'maximize-2': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10 1.5a.5.5 0 0 1 .5-.5H15v4.5a.5.5 0 0 1-1 0V2.707L9.854 6.854a.5.5 0 1 1-.708-.708L13.293 2H10.5a.5.5 0 0 1-.5-.5ZM6.854 9.146a.5.5 0 0 1 0 .708L2.707 14H5.5a.5.5 0 0 1 0 1H1v-4.5a.5.5 0 0 1 1 0v2.793l4.146-4.147a.5.5 0 0 1 .708 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'maximize': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 2a.5.5 0 0 0-.5.5v3H1v-3A1.5 1.5 0 0 1 2.5 1h3v1h-3Zm11 0h-3V1h3A1.5 1.5 0 0 1 15 2.5v3h-1v-3a.5.5 0 0 0-.5-.5ZM2 10.5v3a.5.5 0 0 0 .5.5h3v1h-3A1.5 1.5 0 0 1 1 13.5v-3h1Zm12 3v-3h1v3a1.5 1.5 0 0 1-1.5 1.5h-3v-1h3a.5.5 0 0 0 .5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'map-pin-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2 6c0 5 6 10 6 10s6-5 6-10A6 6 0 1 0 2 6Zm6 2a2 2 0 1 0 0-4 2 2 0 0 0 0 4Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'map-pin': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 16S2 11 2 6a6 6 0 1 1 12 0c0 5-6 10-6 10Zm-.24-1.576c.085.082.165.16.24.23.075-.07.155-.148.24-.23a23.929 23.929 0 0 0 1.98-2.174C11.69 10.412 13 8.142 13 6A5 5 0 1 0 3 6c0 2.142 1.31 4.412 2.78 6.25a23.935 23.935 0 0 0 1.98 2.174ZM11 6a3 3 0 1 1-6 0 3 3 0 0 1 6 0Zm-1 0a2 2 0 1 1-4 0 2 2 0 0 1 4 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'map-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 1.5a.5.5 0 0 0-.686-.464L10.5 2.96 5.686 1.036a.5.5 0 0 0-.372 0l-5 2A.5.5 0 0 0 0 3.5v11.167a.5.5 0 0 0 .699.459L5.5 13.045l4.801 2.08a.5.5 0 0 0 .398 0l5-2.166A.5.5 0 0 0 16 12.5v-11Zm-10.5.625c.207 0 .375.168.375.375v9a.375.375 0 0 1-.75 0v-9c0-.207.168-.375.375-.375Zm5 2c.207 0 .375.168.375.375v9a.375.375 0 0 1-.75 0v-9c0-.207.168-.375.375-.375Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'map': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.78 1.086A.5.5 0 0 1 16 1.5v11a.5.5 0 0 1-.301.459l-5 2.167a.5.5 0 0 1-.398 0L5.5 13.045l-4.801 2.08A.5.5 0 0 1 0 14.668V3.5a.5.5 0 0 1 .314-.464l5-2a.5.5 0 0 1 .372 0L10.5 2.96l4.814-1.925a.5.5 0 0 1 .466.05ZM1 3.839v10.066l4.125-1.787v-9.93L1 3.839Zm9.125 10.12-4.25-1.841v-9.93l4.25 1.7V13.96Zm.75 0L15 12.172V2.239l-4.125 1.65v10.07Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'maintenance-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='m14.87 3.986-.72.721a1 1 0 0 1-.707.293H12a1 1 0 0 1-1-1V2.557a1 1 0 0 1 .293-.707l.72-.72A4 4 0 0 0 7.002 4.88l2.22 2.22C9.47 7.035 9.732 7 10 7h.39a3 3 0 0 1 1.953.722l.78.669a3.997 3.997 0 0 0 1.748-4.405Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m1.518 11.982 4.171-4.171 1.412 1.411a3.004 3.004 0 0 0-.102.778v.39a3 3 0 0 0 .156.955l-3.137 3.137a1.767 1.767 0 1 1-2.5-2.5Zm1.628.164 1-1a.5.5 0 0 1 .708.708l-1 1a.5.5 0 0 1-.708-.708Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 3.793V2.5L2 1 1 2l1.5 2.5h1.293l4.484 4.484A1.99 1.99 0 0 0 8 10v.248a2 2 0 0 0 .495 1.318l2.407 2.751a2 2 0 0 0 1.506.683H13a2 2 0 0 0 2-2v-.592a2 2 0 0 0-.683-1.506l-2.752-2.407A2 2 0 0 0 10.25 8H10c-.37 0-.718.101-1.016.277L4.5 3.793Zm6.288 6.42 1.707 1.706a.7.7 0 0 1 .205.495v.086a.3.3 0 1 0 .6 0v-.086a1.3 1.3 0 0 0-.38-.919l-1.708-1.707a.3.3 0 1 0-.424.424Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'maintenance': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11.166 2.005a1 1 0 0 0-.166.552V4a1 1 0 0 0 1 1h1.443a1 1 0 0 0 .707-.293l.72-.72a4.008 4.008 0 0 1-1.747 4.404l-.781-.67-.029-.023a3.01 3.01 0 0 0 1.53-1.739 2 2 0 0 1-.4.041H12a2 2 0 0 1-2-2V2.557a2 2 0 0 1 .04-.4 3.001 3.001 0 0 0-1.881 3.81l.036.107L7.002 4.88a4 4 0 0 1 5.011-3.75l-.72.72a.997.997 0 0 0-.127.155ZM7 10.39a3 3 0 0 0 .155.955l-3.137 3.137a1.767 1.767 0 1 1-2.5-2.5l4.171-4.171.708.707-4.172 4.171a.768.768 0 0 0 1.086 1.086L7 10.086v.304ZM10.788 9.788a.3.3 0 0 0 0 .424l1.707 1.707a.7.7 0 0 1 .205.495v.086a.3.3 0 1 0 .6 0v-.086a1.3 1.3 0 0 0-.38-.919l-1.708-1.707a.3.3 0 0 0-.424 0Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 3.793V2.5L2 1 1 2l1.5 2.5h1.293l4.573 4.573a2.325 2.325 0 0 0 .194 2.765l1.962 2.289A2.5 2.5 0 0 0 12.42 15h.08a2.5 2.5 0 0 0 2.5-2.5v-.08a2.5 2.5 0 0 0-.873-1.898L11.838 8.56a2.325 2.325 0 0 0-2.765-.194L4.5 3.793ZM10.325 9a1.325 1.325 0 0 0-1.006 2.187l1.962 2.29A1.5 1.5 0 0 0 12.42 14h.08a1.5 1.5 0 0 0 1.5-1.5v-.08a1.5 1.5 0 0 0-.524-1.139l-2.289-1.962A1.325 1.325 0 0 0 10.325 9Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'mail-open-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.588.747a1.25 1.25 0 0 0-1.176 0L1.324 3.994A2.5 2.5 0 0 0 0 6.2v6.3A2.5 2.5 0 0 0 2.5 15h11a2.5 2.5 0 0 0 2.5-2.5V6.2a2.5 2.5 0 0 0-1.323-2.206L8.588.747Zm-5.82 5.831a.5.5 0 1 0-.536.844l5.772 3.673 5.616-3.677a.5.5 0 1 0-.548-.836L7.996 9.905 2.768 6.578Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'mail-open': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M2.768 6.578a.5.5 0 1 0-.536.844l5.772 3.673 5.616-3.677a.5.5 0 1 0-.548-.836L7.996 9.905 2.768 6.578Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.588.747a1.25 1.25 0 0 0-1.176 0L1.324 3.994A2.5 2.5 0 0 0 0 6.2v6.3A2.5 2.5 0 0 0 2.5 15h11a2.5 2.5 0 0 0 2.5-2.5V6.2a2.5 2.5 0 0 0-1.323-2.206L8.588.747Zm-.706.882a.25.25 0 0 1 .236 0l6.088 3.247c.489.261.794.77.794 1.324v6.3a1.5 1.5 0 0 1-1.5 1.5h-11A1.5 1.5 0 0 1 1 12.5V6.2a1.5 1.5 0 0 1 .794-1.324L7.882 1.63Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'mail-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 2A2.5 2.5 0 0 0 0 4.5v7A2.5 2.5 0 0 0 2.5 14h11a2.5 2.5 0 0 0 2.5-2.5v-7A2.5 2.5 0 0 0 13.5 2h-11Zm-.422 3.232a.5.5 0 0 1 .69-.154l5.228 3.327 5.076-3.323a.5.5 0 0 1 .548.836L8.004 9.595 2.232 5.922a.5.5 0 0 1-.154-.69Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'mail': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M2.078 5.232a.5.5 0 0 1 .69-.154l5.228 3.327 5.076-3.323a.5.5 0 0 1 .548.836L8.004 9.595 2.232 5.922a.5.5 0 0 1-.154-.69Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 4.5A2.5 2.5 0 0 1 2.5 2h11A2.5 2.5 0 0 1 16 4.5v7a2.5 2.5 0 0 1-2.5 2.5h-11A2.5 2.5 0 0 1 0 11.5v-7ZM2.5 3h11A1.5 1.5 0 0 1 15 4.5v7a1.5 1.5 0 0 1-1.5 1.5h-11A1.5 1.5 0 0 1 1 11.5v-7A1.5 1.5 0 0 1 2.5 3Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'log-out': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2 13a1 1 0 0 0 1 1h2.5a.5.5 0 0 1 0 1H3a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h2.5a.5.5 0 0 1 0 1H3a1 1 0 0 0-1 1v10Zm1.5-5a.5.5 0 0 1 .5-.5h9.793l-2.147-2.146a.5.5 0 0 1 .708-.708L15.707 8l-3.353 3.354a.5.5 0 0 1-.708-.708L13.793 8.5H4a.5.5 0 0 1-.5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'log-in': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.5 8a.5.5 0 0 1 .5-.5h9.793L8.646 5.354a.5.5 0 1 1 .708-.708L12.707 8l-3.353 3.354a.5.5 0 0 1-.708-.708L10.793 8.5H1A.5.5 0 0 1 .5 8Zm9.5 6.5a.5.5 0 0 1 .5-.5H13a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1h-2.5a.5.5 0 0 1 0-1H13a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2h-2.5a.5.5 0 0 1-.5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'lock-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 0a4 4 0 0 0-4 4v2a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2V4a4 4 0 0 0-4-4Zm3 6V4a3 3 0 0 0-6 0v2h6Zm-4 4.5a1 1 0 1 1 2 0 1 1 0 0 1-2 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'lock': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M7 10.5a1 1 0 1 1 2 0 1 1 0 0 1-2 0Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 0a4 4 0 0 0-4 4v2a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2V4a4 4 0 0 0-4-4Zm3 6V4a3 3 0 0 0-6 0v2h6ZM4 7a1 1 0 0 0-1 1v6a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V8a1 1 0 0 0-1-1H4Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'list-ordered': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M1 2.1a.4.4 0 1 0 0 .8h.1v1.2H1a.4.4 0 1 0 0 .8h1a.4.4 0 0 0 0-.8h-.1v-2H1ZM4.5 3.1a.4.4 0 1 0 0 .8h9a.4.4 0 0 0 0-.8h-9ZM4.5 7.6a.4.4 0 1 0 0 .8h11a.4.4 0 0 0 0-.8h-11ZM4.5 12.1a.4.4 0 0 0 0 .8h6a.4.4 0 0 0 0-.8h-6ZM.5 6.6a.4.4 0 1 0 0 .8h1.252L.24 8.696A.4.4 0 0 0 .5 9.4h2a.4.4 0 0 0 0-.8h-.919l.86-.736a.6.6 0 0 0 .21-.456V7.2a.6.6 0 0 0-.6-.6H.5ZM.1 11.5c0-.22.18-.4.4-.4h1.8a.6.6 0 0 1 .6.6v.177a.6.6 0 0 1-.332.536l-.173.087.173.087a.6.6 0 0 1 .332.537v.176a.6.6 0 0 1-.6.6H.5a.4.4 0 0 1 0-.8h1.306l-.485-.242a.4.4 0 0 1 0-.716l.485-.242H.5a.4.4 0 0 1-.4-.4Z'/%3e%3c/svg%3e")`,
                'list': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 3.5A.5.5 0 0 1 .5 3h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5Zm4 0a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5ZM0 8a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1A.5.5 0 0 1 0 8Zm4 0a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11A.5.5 0 0 1 4 8Zm-4 4.5a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5Zm4 0a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'linkedin-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 2.75a1.75 1.75 0 1 1 3.5 0 1.75 1.75 0 0 1-3.5 0Zm5 7a4.25 4.25 0 0 1 8.5 0V15H11V9.75a.75.75 0 0 0-1.5 0V15H6V9.75ZM1 7a1 1 0 0 1 1-1h1.5a1 1 0 0 1 1 1v7a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V7Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'linkedin': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 2a1 1 0 1 0 0 2 1 1 0 0 0 0-2ZM1 3a2 2 0 1 1 4 0 2 2 0 0 1-4 0Zm5 6.5a4.5 4.5 0 0 1 9 0V15h-4V9.5a.5.5 0 0 0-1 0V15H6V9.5ZM10.5 6A3.5 3.5 0 0 0 7 9.5V14h2V9.5a1.5 1.5 0 1 1 3 0V14h2V9.5A3.5 3.5 0 0 0 10.5 6ZM1 7a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v7a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V7Zm1 0v7h2V7H2Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'link-2': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 8a4.5 4.5 0 0 1 4.5-4.5h1a.5.5 0 0 1 0 1h-1a3.5 3.5 0 1 0 0 7h1a.5.5 0 0 1 0 1h-1A4.5 4.5 0 0 1 0 8Zm9-4a.5.5 0 0 1 .5-.5h2a4.5 4.5 0 1 1 0 9h-2a.5.5 0 0 1 0-1h2a3.5 3.5 0 1 0 0-7h-2A.5.5 0 0 1 9 4ZM5 8a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5A.5.5 0 0 1 5 8Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'link': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.308 1.984A3.361 3.361 0 0 1 10.685 1h.143A4.172 4.172 0 0 1 15 5.172c0 .863-.343 1.69-.953 2.3l-2.072 2.073a3.5 3.5 0 0 1-4.95 0l-.879-.879a.5.5 0 1 1 .708-.707l.878.879a2.5 2.5 0 0 0 3.536 0l2.072-2.072c.422-.423.66-.996.66-1.594A3.172 3.172 0 0 0 10.828 2h-.143c-.626 0-1.227.249-1.67.692L7.855 3.854a.5.5 0 1 1-.708-.708l1.162-1.162Zm-.04 4.99a2.5 2.5 0 0 0-3.536 0l-2.04 2.042A2.361 2.361 0 0 0 2 10.686 3.315 3.315 0 0 0 5.315 14c.626 0 1.227-.249 1.67-.692l1.161-1.162a.5.5 0 0 1 .708.708l-1.162 1.162A3.36 3.36 0 0 1 5.315 15 4.315 4.315 0 0 1 1 10.685c0-.891.354-1.746.984-2.377l2.041-2.04a3.5 3.5 0 0 1 4.95 0l.879.878a.5.5 0 0 1-.708.708l-.878-.88Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'life-buoy-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-3.62-1.585 2.034-2.112a6.837 6.837 0 0 0-2.011-2.011L9.585 4.326a4.015 4.015 0 0 1 2.089 2.09Zm-7.348 0L2.292 4.303a6.836 6.836 0 0 1 2.011-2.011l2.112 2.034a4.014 4.014 0 0 0-2.089 2.09Zm2.09 5.259-2.113 2.034a6.837 6.837 0 0 1-2.011-2.011l2.034-2.112a4.014 4.014 0 0 0 2.09 2.089Zm7.292.023a6.836 6.836 0 0 1-2.011 2.011l-2.112-2.034a4.014 4.014 0 0 0 2.089-2.089l2.034 2.112ZM11 8a3 3 0 1 1-6 0 3 3 0 0 1 6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'life-buoy': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-4.369 5.578a6.272 6.272 0 0 1-2.93.722c-1.056 0-2.05-.26-2.924-.719l2.165-2.164a3.513 3.513 0 0 0 1.528 0l2.162 2.16Zm.66-.401c.62-.431 1.16-.971 1.59-1.592L11.14 9.549c-.34.69-.901 1.25-1.59 1.591l2.036 2.037Zm1.99-2.252A6.272 6.272 0 0 0 14.296 8c0-1.055-.26-2.05-.719-2.924l-2.16 2.16a3.513 3.513 0 0 1 0 1.53l2.16 2.159Zm-.4-6.51a6.334 6.334 0 0 0-1.59-1.591L9.55 4.86c.69.34 1.25.901 1.59 1.59l2.037-2.035Zm-2.249-1.992L8.765 4.584a3.512 3.512 0 0 0-1.53 0L5.07 2.42a6.272 6.272 0 0 1 2.925-.718c1.058 0 2.056.26 2.931.722Zm-6.516.396c-.621.43-1.16.97-1.592 1.59L4.86 6.453c.34-.69.902-1.25 1.591-1.591L4.41 2.819ZM2.417 5.07A6.272 6.272 0 0 0 1.695 8c0 1.058.261 2.056.722 2.931l2.167-2.166a3.512 3.512 0 0 1 0-1.529L2.417 5.069Zm.401 6.522c.432.62.972 1.16 1.592 1.59l2.042-2.041A3.515 3.515 0 0 1 4.86 9.55L2.817 11.59ZM8 5.501a2.5 2.5 0 1 0 0 5 2.5 2.5 0 0 0 0-5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'layout-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.25 2A2.25 2.25 0 0 0 0 4.25v7.5A2.25 2.25 0 0 0 2.25 14h11.5A2.25 2.25 0 0 0 16 11.75v-7.5A2.25 2.25 0 0 0 13.75 2H2.25ZM.5 6.875h4.625V13.5h.75V6.875H15.5v-.75H.5v.75Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'layout': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.5 2A1.5 1.5 0 0 0 0 3.5v9A1.5 1.5 0 0 0 1.5 14h13a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 14.5 2h-13ZM1 3.5a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 .5.5v2.625H1V3.5Zm0 3.375V12.5a.5.5 0 0 0 .5.5h3.625V6.875H1ZM5.875 13H14.5a.5.5 0 0 0 .5-.5V6.875H5.875V13Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'layers-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M7.776.886a.5.5 0 0 1 .447 0L14.89 4.22a.5.5 0 0 1 0 .895L8.223 8.447a.5.5 0 0 1-.447 0L1.11 5.114a.5.5 0 0 1 0-.895L7.776.886ZM.886 11.11a.5.5 0 0 1 .67-.224L8 14.108l6.443-3.222a.5.5 0 0 1 .447.895l-6.667 3.333a.5.5 0 0 1-.447 0L1.11 11.78a.5.5 0 0 1-.224-.671Z'/%3e%3cpath fill='%230E1011' d='M1.557 7.553a.5.5 0 1 0-.447.894l6.666 3.334a.5.5 0 0 0 .447 0l6.667-3.334a.5.5 0 0 0-.447-.894L8 10.774 1.557 7.553Z'/%3e%3c/svg%3e")`,
                'layers': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.776.886a.5.5 0 0 1 .447 0l6.667 3.333a.5.5 0 0 1 0 .895L8.223 8.447a.5.5 0 0 1-.447 0L1.11 5.114a.5.5 0 0 1 0-.895L7.776.886Zm-5.325 3.78L8 7.442l5.548-2.774L8 1.892 2.45 4.667Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M.886 11.11a.5.5 0 0 1 .67-.224L8 14.108l6.443-3.222a.5.5 0 0 1 .447.895l-6.667 3.333a.5.5 0 0 1-.447 0L1.11 11.78a.5.5 0 0 1-.224-.67Z'/%3e%3cpath fill='%230E1011' d='M1.557 7.553a.5.5 0 1 0-.447.894l6.666 3.334a.5.5 0 0 0 .447 0l6.667-3.334a.5.5 0 0 0-.447-.894L8 10.774 1.557 7.553Z'/%3e%3c/svg%3e")`,
                'key-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.5 5.25a4.75 4.75 0 0 1-6.957 4.207L7 11v1a.5.5 0 0 1-.5.5h-1v1a.5.5 0 0 1-.5.5H4v1a.5.5 0 0 1-.5.5h-3v-3l5.744-5.744A4.75 4.75 0 1 1 15.5 5.25Zm-4 .25a1 1 0 1 0 0-2 1 1 0 0 0 0 2Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'key': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11.5 5.5a1 1 0 1 0 0-2 1 1 0 0 0 0 2Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.75 0a5.25 5.25 0 0 0-5.071 6.614L0 12.293V16h3.5a1 1 0 0 0 1-1v-.5H5a1 1 0 0 0 1-1V13h.5a1 1 0 0 0 1-1v-.793l1.146-1.146A5.25 5.25 0 1 0 10.75 0ZM6.5 5.25a4.25 4.25 0 1 1 2.276 3.765l-.326-.172-1.95 1.95V12H5v1.5H3.5V15H1v-2.293l5.816-5.816-.098-.293A4.245 4.245 0 0 1 6.5 5.25Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'italic': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M10.012 2h2.238a.5.5 0 0 1 0 1h-1.9L6.714 13H8.75a.5.5 0 0 1 0 1H6.012a.45.45 0 0 1-.024 0H3.75a.5.5 0 1 1 0-1h1.9L9.286 3H7.25a.5.5 0 1 1 0-1h2.762Z'/%3e%3c/svg%3e")`,
                'instagram-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 1A3.5 3.5 0 0 0 1 4.5v7A3.5 3.5 0 0 0 4.5 15h7a3.5 3.5 0 0 0 3.5-3.5v-7A3.5 3.5 0 0 0 11.5 1h-7Zm8 3.25a.75.75 0 1 1-1.5 0 .75.75 0 0 1 1.5 0ZM11 8a3 3 0 1 1-6 0 3 3 0 0 1 6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'instagram': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 11a3 3 0 1 0 0-6 3 3 0 0 0 0 6Zm0-.75a2.25 2.25 0 1 0 0-4.5 2.25 2.25 0 0 0 0 4.5Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M11.75 5a.75.75 0 1 0 0-1.5.75.75 0 0 0 0 1.5Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 1A3.5 3.5 0 0 0 1 4.5v7A3.5 3.5 0 0 0 4.5 15h7a3.5 3.5 0 0 0 3.5-3.5v-7A3.5 3.5 0 0 0 11.5 1h-7Zm7 1h-7A2.5 2.5 0 0 0 2 4.5v7A2.5 2.5 0 0 0 4.5 14h7a2.5 2.5 0 0 0 2.5-2.5v-7A2.5 2.5 0 0 0 11.5 2Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'info-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0ZM8 6.5a.5.5 0 0 0 .5-.5v-.5a.5.5 0 0 0-1 0V6a.5.5 0 0 0 .5.5Zm0 5a.5.5 0 0 0 .5-.5V8a.5.5 0 0 0-1 0v3a.5.5 0 0 0 .5.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'info': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 6.5a.5.5 0 0 0 .5-.5v-.5a.5.5 0 0 0-1 0V6a.5.5 0 0 0 .5.5ZM8 11.5a.5.5 0 0 0 .5-.5V8a.5.5 0 0 0-1 0v3a.5.5 0 0 0 .5.5Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'inbox-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 8.736a1.5 1.5 0 0 1 .158-.67l2.48-4.96A2 2 0 0 1 4.428 2h7.145a2 2 0 0 1 1.789 1.106l2.48 4.96a1.5 1.5 0 0 1 .158.67v3.014A2.25 2.25 0 0 1 13.75 14H2.25A2.25 2.25 0 0 1 0 11.75V8.736Zm3.533-5.183A1 1 0 0 1 4.427 3h7.146a1 1 0 0 1 .894.553l2.349 4.697H10V9a2 2 0 1 1-4 0v-.75H1.184l2.349-4.697Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'inbox': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.427 2a2 2 0 0 0-1.789 1.106l-2.48 4.96a1.5 1.5 0 0 0-.158.67V11.5A2.5 2.5 0 0 0 2.5 14h11a2.5 2.5 0 0 0 2.5-2.5V8.736a1.5 1.5 0 0 0-.158-.67l-2.48-4.96A2 2 0 0 0 11.572 2H4.428Zm-.894 1.553A1 1 0 0 1 4.427 3h7.146a1 1 0 0 1 .894.553l2.412 4.822h-4.754V9a2.125 2.125 0 0 1-4.25 0v-.625H1.122l2.41-4.822ZM1 9.125V11.5A1.5 1.5 0 0 0 2.5 13h11a1.5 1.5 0 0 0 1.5-1.5V9.125h-4.128a2.875 2.875 0 0 1-5.744 0H1Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'image-plus-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M3.5 6.25a.75.75 0 1 0 0-1.5.75.75 0 0 0 0 1.5Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 2A2.5 2.5 0 0 0 0 4.5v7A2.5 2.5 0 0 0 2.5 14h5.756a4.5 4.5 0 0 1 4.214-6L10.5 6.03l-5 5-2-2-2.235 2.235a.375.375 0 0 1-.53-.53L3.5 7.97l2 2 5-5 3.19 3.189c.921.252 1.725.79 2.31 1.512V4.5A2.5 2.5 0 0 0 13.5 2h-11Zm1 5a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 12.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0Zm-3.5-2a.5.5 0 0 1 .5.5v1h1a.5.5 0 0 1 0 1h-1v1a.5.5 0 0 1-1 0v-1h-1a.5.5 0 0 1 0-1h1v-1a.5.5 0 0 1 .5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'image-plus-circle-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M3.5 6.25a.75.75 0 1 0 0-1.5.75.75 0 0 0 0 1.5Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 2A2.5 2.5 0 0 0 0 4.5v7A2.5 2.5 0 0 0 2.5 14h5.756a4.5 4.5 0 0 1 4.214-6L10.5 6.03l-5 5-2-2-2.235 2.235a.375.375 0 0 1-.53-.53L3.5 7.97l2 2 5-5 3.19 3.189c.921.252 1.725.79 2.31 1.512V4.5A2.5 2.5 0 0 0 13.5 2h-11Zm1 5a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 12.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0Zm-3.5-2a.5.5 0 0 1 .5.5v1h1a.5.5 0 0 1 0 1h-1v1a.5.5 0 0 1-1 0v-1h-1a.5.5 0 0 1 0-1h1v-1a.5.5 0 0 1 .5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'image-plus-circle': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M2.5 2A2.5 2.5 0 0 0 0 4.5v7A2.5 2.5 0 0 0 2.5 14h5a.5.5 0 0 0 0-1h-5A1.5 1.5 0 0 1 1 11.53l2.5-2.5 2 2 5-5 1.735 1.735a.375.375 0 0 0 .53-.53L10.5 4.97l-5 5-2-2-2.5 2.5V4.5A1.5 1.5 0 0 1 2.5 3h11A1.5 1.5 0 0 1 15 4.5v3a.5.5 0 0 0 1 0v-3A2.5 2.5 0 0 0 13.5 2h-11Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 7a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3Zm0-.75a.75.75 0 1 0 0-1.5.75.75 0 0 0 0 1.5ZM16 12.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0Zm-3.5-2a.5.5 0 0 1 .5.5v1h1a.5.5 0 0 1 0 1h-1v1a.5.5 0 0 1-1 0v-1h-1a.5.5 0 0 1 0-1h1v-1a.5.5 0 0 1 .5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'image-plus': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M2.5 2A2.5 2.5 0 0 0 0 4.5v7A2.5 2.5 0 0 0 2.5 14h7a.5.5 0 0 0 0-1h-7A1.5 1.5 0 0 1 1 11.53l2.5-2.5 2 2 5-5 3.235 3.235a.375.375 0 0 0 .53-.53L10.5 4.97l-5 5-2-2-2.5 2.5V4.5A1.5 1.5 0 0 1 2.5 3h11A1.5 1.5 0 0 1 15 4.5v5a.5.5 0 0 0 1 0v-5A2.5 2.5 0 0 0 13.5 2h-11Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 7a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3Zm0-.75a.75.75 0 1 0 0-1.5.75.75 0 0 0 0 1.5Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M14 11.5a.5.5 0 0 0-1 0V13h-1.5a.5.5 0 0 0 0 1H13v1.5a.5.5 0 0 0 1 0V14h1.5a.5.5 0 0 0 0-1H14v-1.5Z'/%3e%3c/svg%3e")`,
                'image-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M3.5 6.25a.75.75 0 1 0 0-1.5.75.75 0 0 0 0 1.5Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 2A2.5 2.5 0 0 0 0 4.5v7A2.5 2.5 0 0 0 2.5 14h11a2.5 2.5 0 0 0 2.5-2.5v-7A2.5 2.5 0 0 0 13.5 2h-11Zm1 5a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3Zm7-2.03 4.765 4.765a.375.375 0 0 1-.53.53L10.5 6.03l-5 5-2-2-2.235 2.235a.375.375 0 0 1-.53-.53L3.5 7.97l2 2 5-5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'image': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5 5.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0Zm-.75 0a.75.75 0 1 1-1.5 0 .75.75 0 0 1 1.5 0Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 2A2.5 2.5 0 0 0 0 4.5v7A2.5 2.5 0 0 0 2.5 14h11a2.5 2.5 0 0 0 2.5-2.5v-7A2.5 2.5 0 0 0 13.5 2h-11Zm11 1h-11A1.5 1.5 0 0 0 1 4.5v5.97l2.5-2.5 2 2 5-5 4.5 4.5V4.5A1.5 1.5 0 0 0 13.5 3Zm-11 10A1.5 1.5 0 0 1 1 11.53l2.5-2.5 2 2 5-5 4.5 4.5v.97a1.5 1.5 0 0 1-1.5 1.5h-11Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'home-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.34.133a.5.5 0 0 0-.68 0l-6.5 6A.5.5 0 0 0 1 6.5v8A1.5 1.5 0 0 0 2.5 16h11a1.5 1.5 0 0 0 1.5-1.5v-8a.5.5 0 0 0-.16-.367l-6.5-6ZM6 9.5V15h4V9.5a.5.5 0 0 0-.5-.5h-3a.5.5 0 0 0-.5.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'home': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.66.133a.5.5 0 0 1 .68 0l6.5 6A.5.5 0 0 1 15 6.5v7a2.5 2.5 0 0 1-2.5 2.5h-9A2.5 2.5 0 0 1 1 13.5v-7a.5.5 0 0 1 .16-.367l6.5-6ZM2 6.719V13.5A1.5 1.5 0 0 0 3.5 15H6v-4.5a.5.5 0 0 1 .5-.5h3.028a.5.5 0 0 1 .5.5V15H12.5a1.5 1.5 0 0 0 1.5-1.5V6.719L8 1.18 2 6.72ZM9.028 15v-4H7v4h2.028Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'help-circle-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0ZM6.5 5.75c0-.69.56-1.25 1.25-1.25h.5c.69 0 1.25.56 1.25 1.25v.422a1.5 1.5 0 0 1-.44 1.06l-.828.829A2.5 2.5 0 0 0 7.5 9.828V10a.5.5 0 0 0 1 0v-.172c0-.397.158-.779.44-1.06l.828-.829a2.5 2.5 0 0 0 .732-1.767V5.75A2.25 2.25 0 0 0 8.25 3.5h-.5A2.25 2.25 0 0 0 5.5 5.75V6a.5.5 0 0 0 1 0v-.25ZM8.6 12a.6.6 0 1 1-1.2 0 .6.6 0 0 1 1.2 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'help-circle': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6.5 5.75c0-.69.56-1.25 1.25-1.25h.5c.69 0 1.25.56 1.25 1.25v.422a1.5 1.5 0 0 1-.44 1.06l-.828.829A2.5 2.5 0 0 0 7.5 9.828V10a.5.5 0 0 0 1 0v-.172c0-.397.158-.779.44-1.06l.828-.829a2.5 2.5 0 0 0 .732-1.767V5.75A2.25 2.25 0 0 0 8.25 3.5h-.5A2.25 2.25 0 0 0 5.5 5.75V6a.5.5 0 0 0 1 0v-.25ZM8.6 12a.6.6 0 1 1-1.2 0 .6.6 0 0 1 1.2 0Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'heart-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 15.5C5.5 13.498 0 9 0 5a5 5 0 0 1 8-4 5 5 0 0 1 8 4c0 4-5.5 8.499-8 10.5Z'/%3e%3c/svg%3e")`,
                'heart': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.002 15.497C10.504 13.497 16 8.998 16 5a5 5 0 0 0-8-4 5 5 0 0 0-8 4c0 4 5.5 8.499 8 10.5l.002-.003ZM8 14.215c-1.217-.99-2.819-2.356-4.195-3.885C2.135 8.473 1 6.596 1 5a4 4 0 0 1 6.4-3.2l.6.45.6-.45A4 4 0 0 1 15 5c0 1.596-1.134 3.473-2.806 5.33-1.376 1.53-2.977 2.895-4.194 3.885Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'headphones-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 7.5A6.5 6.5 0 0 1 7.5 1h1A6.5 6.5 0 0 1 15 7.5v5.78a1.5 1.5 0 0 1-1.026 1.422l-.585.195a2.002 2.002 0 0 1-.632.103H12.5a1.5 1.5 0 0 1-1.5-1.5v-3A1.5 1.5 0 0 1 12.5 9h.257a2 2 0 0 1 .632.103l.611.203V7.5A5.5 5.5 0 0 0 8.5 2h-1A5.5 5.5 0 0 0 2 7.5v1.806l.611-.203A2 2 0 0 1 3.243 9H3.5A1.5 1.5 0 0 1 5 10.5v3A1.5 1.5 0 0 1 3.5 15h-.257c-.215 0-.428-.035-.632-.103l-.585-.195A1.5 1.5 0 0 1 1 13.28V7.5Zm1 3.75h1.5v-.5H2v.5Zm10.5 0H14v-.5h-1.5v.5Zm-10.5 1h1.5v-.5H2v.5Zm10.5 0H14v-.5h-1.5v.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'headphones': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.5 1A6.5 6.5 0 0 0 1 7.5v5.78a1.5 1.5 0 0 0 1.026 1.422l.585.195c.204.068.417.103.632.103H3.5A1.5 1.5 0 0 0 5 13.5v-3A1.5 1.5 0 0 0 3.5 9h-.257a2 2 0 0 0-.632.103L2 9.306V7.5A5.5 5.5 0 0 1 7.5 2h1A5.5 5.5 0 0 1 14 7.5v1.806l-.611-.203A2 2 0 0 0 12.757 9H12.5a1.5 1.5 0 0 0-1.5 1.5v3a1.5 1.5 0 0 0 1.5 1.5h.257c.215 0 .428-.035.632-.103l.585-.195A1.5 1.5 0 0 0 15 13.28V7.5A6.5 6.5 0 0 0 8.5 1h-1ZM2 10.75v-.39l.927-.309A1 1 0 0 1 3.243 10H3.5a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-.5.5h-.257a1 1 0 0 1-.316-.051l-.585-.195A.5.5 0 0 1 2 13.279V12.25h1.5v-.5H2v-.5h1.5v-.5H2Zm11.073-.699.927.31v.389h-1.5v.5H14v.5h-1.5v.5H14v1.03a.5.5 0 0 1-.342.474l-.585.195a1 1 0 0 1-.316.051H12.5a.5.5 0 0 1-.5-.5v-3a.5.5 0 0 1 .5-.5h.257a1 1 0 0 1 .316.051Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'hash': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.576 1.006a.5.5 0 0 1 .418.57L6.467 5h4.989l.55-3.576a.5.5 0 0 1 .988.152L12.467 5H15a.5.5 0 0 1 0 1h-2.686l-.616 4H14a.5.5 0 1 1 0 1h-2.456l-.55 3.576a.5.5 0 0 1-.988-.152L10.533 11H5.544l-.55 3.576a.5.5 0 0 1-.988-.152L4.533 11H1.5a.5.5 0 0 1 0-1h3.186l.616-4H2.5a.5.5 0 0 1 0-1h2.956l.55-3.576a.5.5 0 0 1 .57-.418ZM10.686 10l.616-4H6.314l-.616 4h4.988Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'hard-drive-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M3.427 3a2 2 0 0 0-1.789 1.106L.37 6.643a3.5 3.5 0 0 0-.139.314A2.737 2.737 0 0 1 1.75 6.5h12.5c.561 0 1.084.168 1.519.457a3.494 3.494 0 0 0-.139-.314l-1.268-2.537A2 2 0 0 0 12.572 3H3.428Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 9.25a1.75 1.75 0 0 0-1.75-1.75H1.75A1.75 1.75 0 0 0 0 9.25V11a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V9.25Zm-5 .25a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'hard-drive': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11.5 9a.5.5 0 0 0 0 1h2a.5.5 0 0 0 0-1h-2Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.427 3a2 2 0 0 0-1.789 1.106L.37 6.643A3.5 3.5 0 0 0 0 8.208V11a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V8.208a3.5 3.5 0 0 0-.37-1.565l-1.268-2.537A2 2 0 0 0 12.572 3H3.428Zm-.894 1.553A1 1 0 0 1 3.427 4h9.146a1 1 0 0 1 .894.553l1.27 2.537c.037.076.07.153.1.232A1.867 1.867 0 0 0 14 7.125H2c-.301 0-.586.071-.838.197a2.5 2.5 0 0 1 .102-.232l1.269-2.537ZM1 8.484V11a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V8.484a1.125 1.125 0 0 0-1-.609H2c-.435 0-.813.247-1 .61Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'grid-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 2a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5h-3ZM1 2.5A1.5 1.5 0 0 1 2.5 1h3A1.5 1.5 0 0 1 7 2.5v3A1.5 1.5 0 0 1 5.5 7h-3A1.5 1.5 0 0 1 1 5.5v-3Zm8 0A1.5 1.5 0 0 1 10.5 1h3A1.5 1.5 0 0 1 15 2.5v3A1.5 1.5 0 0 1 13.5 7h-3A1.5 1.5 0 0 1 9 5.5v-3Zm1.5-.5a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5h-3Zm-8 8a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5h-3Zm-1.5.5A1.5 1.5 0 0 1 2.5 9h3A1.5 1.5 0 0 1 7 10.5v3A1.5 1.5 0 0 1 5.5 15h-3A1.5 1.5 0 0 1 1 13.5v-3Zm9.5-.5a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5h-3Zm-1.5.5A1.5 1.5 0 0 1 10.5 9h3a1.5 1.5 0 0 1 1.5 1.5v3a1.5 1.5 0 0 1-1.5 1.5h-3A1.5 1.5 0 0 1 9 13.5v-3Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M2 2.5a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5v-3ZM2 10.5a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5v-3ZM10 10.5a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5v-3ZM10 2.5a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5v-3Z'/%3e%3c/svg%3e")`,
                'grid': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.5 2a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5h-3ZM1 2.5A1.5 1.5 0 0 1 2.5 1h3A1.5 1.5 0 0 1 7 2.5v3A1.5 1.5 0 0 1 5.5 7h-3A1.5 1.5 0 0 1 1 5.5v-3Zm8 0A1.5 1.5 0 0 1 10.5 1h3A1.5 1.5 0 0 1 15 2.5v3A1.5 1.5 0 0 1 13.5 7h-3A1.5 1.5 0 0 1 9 5.5v-3Zm1.5-.5a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5h-3Zm-8 8a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5h-3Zm-1.5.5A1.5 1.5 0 0 1 2.5 9h3A1.5 1.5 0 0 1 7 10.5v3A1.5 1.5 0 0 1 5.5 15h-3A1.5 1.5 0 0 1 1 13.5v-3Zm9.5-.5a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5h-3Zm-1.5.5A1.5 1.5 0 0 1 10.5 9h3a1.5 1.5 0 0 1 1.5 1.5v3a1.5 1.5 0 0 1-1.5 1.5h-3A1.5 1.5 0 0 1 9 13.5v-3Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'globe-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.3 8A7.3 7.3 0 1 1 .7 8a7.3 7.3 0 0 1 14.6 0Zm-5.822 5.592.264.151c.106-.032.21-.067.314-.105v-.046l-.087-.193-.058-.165-.057-.138v-.192l.057-.11.145-.166.202-.33v-.523l.058-.303.982-.716.318-.33-.029-.799.145-.192.173-.11.116-.11v-.276l-.116-.083-.491-.137-.289-.138-.347-.22-.26-.303-.144-.22-.203-.166-.52-.165-.404-.22-.26-.083-.376-.055-.636.028-.202-.028-.116-.11-.115-.248-.26-.055-.145-.027-.144-.083.058-.358.028-.082-.028-.083h-.145l-.144.028h-.116l-.26.055h-.174l-.057-.166.029-.22.144-.303.26-.22.29-.027h.317l.289.11.289.192h.058l.115-.055.03-.082.028-.523.607-.44.376-.359.318-.248.202-.11.462-.055.202-.055.03-.055v-.11l-.03-.083-.057-.082v-.083l.057-.055h.203l.173.028.173-.055.116-.193.058-.138-.231-.11v-.067a5.959 5.959 0 0 0-1.052-.403l-.046.03-.318.192-.376.138-.347.055-.202-.055-.116-.248.058-.248.078-.074a5.972 5.972 0 0 0-3.69 1.01v.028l-.116.358c-.067.11-.202.336-.202.358 0 .022-.038.358-.058.523v.385l.058.248.03.248.086.248.086.275.03.138h.317l.231.082.087.193.26.468.087.165.375.055.29.055.23.11.29.193.26.276a.74.74 0 0 0 .144.11c.046.022.193.009.26 0 .068.037.203.115.203.137 0 .014.028.062.057.11.03.049.058.097.058.11 0 .008.002.02.005.032.006.038.016.093-.005.134-.015.03-.08.074-.136.113-.05.035-.095.067-.095.08v.192l.116.413.115.22v.276a.173.173 0 0 1-.012.053c-.013.04-.027.083.012.14.03.044.053.095.072.138.017.038.03.07.044.082a.397.397 0 0 0 .115.083c.022.01.043.016.066.023.04.012.082.025.137.06.16.09.24.123.29.143.04.016.06.024.085.049.039.037.039.037.052.057l.035.053c.023.033.042.04.056.045.02.007.03.01.03.093v1.046l.26.606.203.66.058.634.26.275Zm2.055-10.443a6.006 6.006 0 0 0-.339-.229l-.04.154.173.056.174.027.032-.008Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'globe': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-1 0a6.3 6.3 0 1 1-9.679-5.317l.037.061v.303l-.116.358c-.067.11-.202.336-.202.358 0 .022-.038.358-.058.523v.386l.058.247.03.248.086.248.086.275.03.138h.317l.231.083.087.192.26.468.087.166.376.055.288.055.232.11.289.193.26.275a.74.74 0 0 0 .144.11c.046.022.193.01.26 0 .068.037.203.116.203.138 0 .013.028.062.057.11a.502.502 0 0 1 .058.11c0 .007.002.018.005.032.006.037.016.093-.005.133a.553.553 0 0 1-.136.114c-.05.035-.095.066-.095.079v.193l.116.413.115.22v.275c0 .018-.006.035-.012.053-.013.04-.027.084.012.14.03.044.053.096.072.138.017.038.03.07.044.082a.397.397 0 0 0 .181.106.491.491 0 0 1 .137.06c.16.09.24.123.29.143.04.016.06.024.085.05.039.036.039.036.052.056l.035.053c.023.034.042.04.056.045.02.007.03.01.03.093v1.046l.26.606.203.66.058.634.26.275.289.165.144.056.145-.056v-.165l-.087-.193-.058-.165-.057-.137v-.193l.057-.11.145-.165.202-.33v-.524l.058-.303.982-.716.318-.33-.029-.798.145-.193.173-.11.116-.11v-.276l-.116-.082-.491-.138-.289-.138-.347-.22-.26-.303-.144-.22-.203-.165-.52-.165-.404-.22-.26-.083-.376-.055-.636.027-.202-.027-.116-.11-.115-.248-.26-.055-.145-.028-.144-.083.058-.357.028-.083-.028-.083h-.145l-.144.028h-.116l-.26.055h-.173l-.058-.165.029-.22.144-.303.26-.22.29-.028h.317l.289.11.289.193h.058l.115-.055.03-.083.028-.523.607-.44.376-.359.318-.247.202-.11.462-.056.202-.055.03-.055v-.11l-.03-.082-.057-.083v-.083l.057-.055h.203l.173.028.173-.055.116-.193.058-.138-.231-.11v-.248l-.058-.11h-.174l-.115-.055-.202-.082-.145-.138-.144.028-.26.165-.318.192-.376.138-.347.055-.202-.055-.116-.248.058-.247.116-.11.347-.138.168-.072a6.26 6.26 0 0 1 2.425.885l-.108.205-.058.22.173.056.174.027.347-.082.063-.01A6.288 6.288 0 0 1 14.294 8Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'gitlab-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.502.5a.5.5 0 0 1 .468.33L5.85 6h4.3L12.03.83a.5.5 0 0 1 .938-.006l2.873 7.66a1 1 0 0 1-.312 1.133l-7.06 5.648a.75.75 0 0 1-.938 0L.471 9.617a1 1 0 0 1-.312-1.132L3.032.825A.5.5 0 0 1 3.502.5Zm-.01 1.943L1.096 8.836 8 14.36l6.905-5.524-2.398-6.393-1.537 4.228A.5.5 0 0 1 10.5 7h-5a.5.5 0 0 1-.47-.33L3.493 2.444Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='m1.095 8.836 2.398-6.393L5.03 6.671A.5.5 0 0 0 5.5 7h5a.5.5 0 0 0 .47-.33l1.537-4.227 2.398 6.393L8 14.36 1.095 8.836Z'/%3e%3c/svg%3e")`,
                'gitlab': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.503.5a.5.5 0 0 1 .467.33L5.85 6h4.3L12.03.83a.5.5 0 0 1 .938-.006l2.873 7.66a1 1 0 0 1-.312 1.133l-7.06 5.648a.75.75 0 0 1-.938 0L.471 9.617a1 1 0 0 1-.312-1.132L3.032.825A.5.5 0 0 1 3.502.5Zm-.01 1.943L1.095 8.836 8 14.36l6.905-5.524-2.398-6.393-1.537 4.228A.5.5 0 0 1 10.5 7h-5a.5.5 0 0 1-.47-.33L3.493 2.444Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'github': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.553.276a.5.5 0 0 1 .67-.223l.928.463a1 1 0 0 1 .26.188l.443.443C5.221 1.051 5.604 1 6 1h4c.395 0 .78.051 1.146.147l.443-.443a.999.999 0 0 1 .26-.188l.927-.463a.5.5 0 0 1 .671.223l.17.339a2.5 2.5 0 0 1 .189 1.724l-.139.553c.524.736.833 1.636.833 2.608v1a5.502 5.502 0 0 1-4.173 5.339c.114.276.173.573.173.868V15.5a.5.5 0 0 1-1 0v-2.793c0-.328-.132-.657-.354-.878a.5.5 0 0 1 .305-.851A4.5 4.5 0 0 0 13.5 6.5v-1c0-.827-.286-1.586-.766-2.185a.5.5 0 0 1-.095-.434l.197-.785a1.5 1.5 0 0 0-.064-.923l-.476.238-.654.654a.5.5 0 0 1-.515.12A3.496 3.496 0 0 0 10 2H6c-.395 0-.774.065-1.127.185a.5.5 0 0 1-.515-.12l-.654-.654-.476-.238a1.5 1.5 0 0 0-.063.923l.196.785a.5.5 0 0 1-.095.434A3.483 3.483 0 0 0 2.5 5.5v1c0 2.2 1.58 4.033 3.667 4.423a.5.5 0 0 1 .262.845.921.921 0 0 0-.217.378.632.632 0 0 0-.014.367l.172.517c.086.258.13.527.13.799V15.5a.5.5 0 0 1-1 0V14H5c-.96 0-1.593-.635-2.06-1.103l-.044-.043C2.368 12.324 2.01 12 1.5 12H1a.5.5 0 0 1 0-1h.5c.96 0 1.593.635 2.06 1.103l.044.043c.528.53.886.854 1.396.854h.306l-.057-.171a1.621 1.621 0 0 1 .005-.968c.013-.044.028-.087.044-.13A5.502 5.502 0 0 1 1.5 6.5v-1c0-.972.308-1.872.833-2.608l-.139-.553a2.5 2.5 0 0 1 .19-1.724l.169-.339Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'git-pull-request': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 1a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3ZM1 2.5a2.5 2.5 0 1 1 3 2.45v8.135a1.5 1.5 0 1 1-1 0V4.95A2.5 2.5 0 0 1 1 2.5ZM9.854.146a.5.5 0 0 1 0 .708L8.707 2H10.5A2.5 2.5 0 0 1 13 4.5v6.55a2.5 2.5 0 1 1-1 0V4.5A1.5 1.5 0 0 0 10.5 3H8.707l1.147 1.146a.5.5 0 0 1-.708.708L6.793 2.5 9.146.146a.5.5 0 0 1 .708 0ZM12.5 12a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3Zm-9 2a.5.5 0 1 0 0 1 .5.5 0 0 0 0-1Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'git-merge': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 1a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3ZM2 2.5a2.5 2.5 0 1 1 3 2.45v.673l5.187 1.482A2.5 2.5 0 0 1 12 9.509v1.541a2.5 2.5 0 1 1-1 0V9.509a1.5 1.5 0 0 0-1.088-1.443L5 6.663V10.5a.5.5 0 0 1-1 0V4.95A2.5 2.5 0 0 1 2 2.5Zm9.5 9.5a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3Zm-7 0a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-1 0v-3a.5.5 0 0 1 .5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'git-commit': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.535 7H.5a.5.5 0 0 0 0 1h4.035a3.5 3.5 0 0 0 6.93 0H15.5a.5.5 0 0 0 0-1h-4.035a3.5 3.5 0 0 0-6.93 0Zm.965.5a2.5 2.5 0 1 1 5 0 2.5 2.5 0 0 1-5 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'git-branch': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.5 1a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3ZM2 2.5a2.5 2.5 0 1 1 3 2.45v4.887l3.824-1.092A3 3 0 0 0 11 5.86v-.91a2.5 2.5 0 1 1 1 0v.91a4 4 0 0 1-2.901 3.846L5 10.877v2.208a1.5 1.5 0 1 1-1 0V4.95A2.5 2.5 0 0 1 2 2.5ZM11.5 1a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3Zm-7 13a.5.5 0 1 0 0 1 .5.5 0 0 0 0-1Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'gift-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.15 3.531a1.923 1.923 0 0 1 3.649-1.216L8 2.919l.201-.604A1.923 1.923 0 0 1 11.85 3.53l-.148.443a2.035 2.035 0 0 1-.008.026H15a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1v4.75A2.25 2.25 0 0 1 12.75 15h-9.5A2.25 2.25 0 0 1 1 12.75V8a1 1 0 0 1-1-1V5a1 1 0 0 1 1-1h3.307a1.549 1.549 0 0 1-.01-.026l-.147-.443Zm6.604.127a.5.5 0 0 1-.475.342H8.694l.456-1.369a.923.923 0 0 1 1.751.584l-.147.443ZM6.85 2.631 7.306 4H5.721a.5.5 0 0 1-.475-.342L5.1 3.215A.923.923 0 1 1 6.85 2.63ZM8 5a.5.5 0 0 1 .5.5V7h5.25a.5.5 0 0 1 0 1H8.5v5.5a.5.5 0 0 1-1 0V8H2.25a.5.5 0 0 1 0-1H7.5V5.5A.5.5 0 0 1 8 5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'gift': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.15 3.531a1.923 1.923 0 0 1 3.649-1.216L8 2.919l.201-.604A1.923 1.923 0 0 1 11.85 3.53l-.148.443a2.035 2.035 0 0 1-.008.026H14.5A1.5 1.5 0 0 1 16 5.5v1a1.5 1.5 0 0 1-1 1.415V13a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V7.915A1.5 1.5 0 0 1 0 6.5v-1A1.5 1.5 0 0 1 1.5 4h2.807a1.549 1.549 0 0 1-.01-.026l-.147-.443ZM5.72 4h1.586L6.85 2.631a.923.923 0 0 0-1.751.584l.147.443A.5.5 0 0 0 5.721 4ZM7.5 5v2h-6a.5.5 0 0 1-.5-.5v-1a.5.5 0 0 1 .5-.5h6Zm1 2V5h6a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-6Zm-1 1H2v5a1 1 0 0 0 1 1h4.5V8Zm1 6V8H14v5a1 1 0 0 1-1 1H8.5Zm1.78-10a.5.5 0 0 0 .474-.342l.147-.443A.923.923 0 1 0 9.15 2.63L8.694 4h1.585Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'frown-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0ZM5 6a1 1 0 1 1 2 0 1 1 0 0 1-2 0Zm4 0a1 1 0 1 1 2 0 1 1 0 0 1-2 0Zm-3.646 5.729c.635-.635 1.62-.979 2.646-.979 1.026 0 2.011.344 2.646.979a.5.5 0 0 0 .708-.708C10.489 10.156 9.224 9.75 8 9.75c-1.224 0-2.489.406-3.354 1.271a.5.5 0 0 0 .708.708Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'frown': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6 5a1 1 0 1 0 0 2 1 1 0 0 0 0-2ZM5.505 9.837C6.075 9.427 6.925 9 8 9c1.075 0 1.925.427 2.495.837a4.933 4.933 0 0 1 .833.761l.048.059.005.006.009.011.004.006.002.002v.001a.508.508 0 0 1-.102.715.518.518 0 0 1-.72-.101l-.005-.007-.03-.036a3.921 3.921 0 0 0-.65-.592c-.456-.328-1.098-.642-1.889-.642-.791 0-1.433.314-1.89.643a3.922 3.922 0 0 0-.65.591 1.53 1.53 0 0 0-.029.036l-.005.007a.517.517 0 0 1-.72.101.507.507 0 0 1-.103-.714l.001-.002.002-.002.004-.006.005-.005.01-.012c.01-.015.027-.035.047-.059a4.934 4.934 0 0 1 .833-.76ZM9 6a1 1 0 1 1 2 0 1 1 0 0 1-2 0Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'folder-plus-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.5 1A1.5 1.5 0 0 0 0 2.5V12a2 2 0 0 0 2 2h6.256A4.5 4.5 0 0 1 16 9.671V4a2 2 0 0 0-2-2H8.121a1 1 0 0 1-.707-.293l-.121-.121A2 2 0 0 0 5.879 1H1.5Zm5.854 2.354a.5.5 0 0 0-.708-.708l-.06.061A1 1 0 0 1 5.879 3H1.5a.5.5 0 1 0 0 1h4.379a2 2 0 0 0 1.414-.586l.06-.06Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 12.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0ZM12.5 10a.5.5 0 0 1 .5.5V12h1.5a.5.5 0 0 1 0 1H13v1.75a.5.5 0 0 1-1 0V13h-1.5a.5.5 0 0 1 0-1H12v-1.5a.5.5 0 0 1 .5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'folder-plus': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.5 1A1.5 1.5 0 0 0 0 2.5V12a2 2 0 0 0 2 2h5.5v-1H2a1 1 0 0 1-1-1V4h4.879a2 2 0 0 0 1.414-.586L7.707 3H14a1 1 0 0 1 1 1v4.5h1V4a2 2 0 0 0-2-2H7.707l-.414-.414A2 2 0 0 0 5.879 1H1.5Zm4.379 2H1v-.5a.5.5 0 0 1 .5-.5h4.379a1 1 0 0 1 .707.293l.207.207-.207.207A1 1 0 0 1 5.879 3Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 12.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0ZM12.5 10a.5.5 0 0 1 .5.5V12h1.5a.5.5 0 0 1 0 1H13v1.75a.5.5 0 0 1-1 0V13h-1.5a.5.5 0 0 1 0-1H12v-1.5a.5.5 0 0 1 .5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'folder-minus-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.5 1A1.5 1.5 0 0 0 0 2.5V12a2 2 0 0 0 2 2h6.267c.086-.148.192-.287.319-.414L9.672 12.5l-1.086-1.086a2 2 0 1 1 2.828-2.828L12.5 9.672l1.086-1.086A2 2 0 0 1 16 8.267V4a2 2 0 0 0-2-2H8.121a1 1 0 0 1-.707-.293l-.121-.121A2 2 0 0 0 5.879 1H1.5Zm5.854 2.354a.5.5 0 0 0-.708-.708l-.06.061A1 1 0 0 1 5.879 3H1.5a.5.5 0 1 0 0 1h4.379a2 2 0 0 0 1.414-.586l.06-.06Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M16 12c0 .34-.084.659-.233.938l-.439-.438.672-.672V12Z'/%3e%3cpath fill='%230E1011' d='M10.354 9.646a.5.5 0 0 0-.708.708l2.147 2.146-2.147 2.146a.5.5 0 0 0 .708.708l2.146-2.147 2.146 2.147a.5.5 0 0 0 .708-.708L13.207 12.5l2.147-2.146a.5.5 0 0 0-.708-.708L12.5 11.793l-2.146-2.147Z'/%3e%3c/svg%3e")`,
                'folder-minus': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 2.5A1.5 1.5 0 0 1 1.5 1h4.379a2 2 0 0 1 1.414.586L7.707 2H14a2 2 0 0 1 2 2v3.5a.5.5 0 0 1-1 0V4a1 1 0 0 0-1-1H7.707l-.414.414A2 2 0 0 1 5.879 4H1v8a1 1 0 0 0 1 1h5.5a.5.5 0 0 1 0 1H2a2 2 0 0 1-2-2V2.5ZM1 3h4.879a1 1 0 0 0 .707-.293l.207-.207-.207-.207A1 1 0 0 0 5.879 2H1.5a.5.5 0 0 0-.5.5V3Zm8.646 6.646a.5.5 0 0 1 .708 0l2.146 2.147 2.146-2.147a.5.5 0 0 1 .708.708L13.207 12.5l2.147 2.146a.5.5 0 0 1-.708.708L12.5 13.207l-2.146 2.147a.5.5 0 0 1-.708-.708l2.147-2.146-2.147-2.146a.5.5 0 0 1 0-.708Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'folder-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.5 1A1.5 1.5 0 0 0 0 2.5V12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H8.121a1 1 0 0 1-.707-.293l-.121-.121A2 2 0 0 0 5.879 1H1.5Zm5.854 2.354a.5.5 0 0 0-.708-.708l-.06.061A1 1 0 0 1 5.879 3H1.5a.5.5 0 1 0 0 1h4.379a2 2 0 0 0 1.414-.586l.06-.06Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'folder': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 2.5A1.5 1.5 0 0 1 1.5 1h4.379a2 2 0 0 1 1.414.586L7.707 2H14a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2.5Zm6.793 0-.207-.207A1 1 0 0 0 5.879 2H1.5a.5.5 0 0 0-.5.5V3h4.879a1 1 0 0 0 .707-.293l.207-.207ZM1 4v8a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4a1 1 0 0 0-1-1H7.707l-.414.414A2 2 0 0 1 5.879 4H1Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'flag-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.758 1.407C2.208 1.188 2.912 1 4 1c1.073 0 2.589.255 4.043.5l.04.007C9.585 1.76 11.021 2 12 2c1.01 0 1.601-.07 1.928-.134a2.026 2.026 0 0 0 .326-.087.5.5 0 0 1 .746.435v8.572a.5.5 0 0 1-.277.447l-.223-.447.223.447-.002.001-.002.001-.005.003-.016.008a5.388 5.388 0 0 1-.268.116c-.181.072-.441.167-.768.261A9.65 9.65 0 0 1 11 12c-1.082 0-2.356-.258-3.564-.503L7.4 11.49C6.15 11.237 4.97 11 4 11c-1.01 0-1.602.07-1.928.134a3.72 3.72 0 0 0-.072.014V14.5a.5.5 0 0 1-1 0V2.214a.5.5 0 0 1 .074-.26l.426.26c-.426-.26-.426-.262-.426-.262l.002-.002.002-.004.006-.009a.708.708 0 0 1 .052-.07c.03-.038.073-.083.127-.133.11-.1.27-.217.495-.327ZM2 2.422v7.708c.413-.07 1.044-.13 2-.13 1.082 0 2.356.258 3.564.503l.035.007c1.25.253 2.43.49 3.401.49a8.65 8.65 0 0 0 2.384-.337 7.35 7.35 0 0 0 .616-.207V2.87c-.413.07-1.044.13-2 .13-1.073 0-2.589-.255-4.043-.5l-.04-.007C6.415 2.24 4.979 2 4 2c-.975 0-1.521.169-1.805.307-.087.042-.15.082-.195.115Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M2 10.13V2.422c.044-.033.108-.073.195-.115C2.48 2.169 3.025 2 4 2c.98 0 2.415.24 3.917.493l.04.007c1.454.245 2.97.5 4.043.5.956 0 1.587-.06 2-.13v7.586a7.35 7.35 0 0 1-.616.207A8.65 8.65 0 0 1 11 11c-.97 0-2.15-.237-3.4-.49l-.035-.007C6.355 10.258 5.082 10 4 10c-.956 0-1.587.06-2 .13Z'/%3e%3c/svg%3e")`,
                'flag': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.758 1.407C2.208 1.188 2.912 1 4 1c1.073 0 2.589.255 4.043.5l.04.007C9.585 1.76 11.021 2 12 2c1.01 0 1.601-.07 1.928-.134a2.026 2.026 0 0 0 .326-.087.5.5 0 0 1 .746.435v8.572a.5.5 0 0 1-.277.447l-.223-.447.223.447-.002.001-.002.001-.005.003-.016.008a5.388 5.388 0 0 1-.268.116c-.181.072-.441.167-.768.261A9.65 9.65 0 0 1 11 12c-1.082 0-2.356-.258-3.564-.503L7.4 11.49C6.15 11.237 4.97 11 4 11c-1.01 0-1.602.07-1.928.134a3.72 3.72 0 0 0-.072.014V14.5a.5.5 0 0 1-1 0V2.214a.5.5 0 0 1 .074-.26l.426.26c-.426-.26-.426-.261-.426-.262l.002-.002.002-.004.006-.009a.708.708 0 0 1 .052-.07c.03-.038.073-.083.127-.133.11-.1.27-.217.495-.327ZM2 2.422v7.708c.413-.07 1.044-.13 2-.13 1.082 0 2.356.258 3.564.503l.035.007c1.25.253 2.43.49 3.401.49a8.65 8.65 0 0 0 2.384-.337 7.35 7.35 0 0 0 .616-.207V2.87c-.413.07-1.044.13-2 .13-1.073 0-2.589-.255-4.043-.5l-.04-.007C6.415 2.24 4.979 2 4 2c-.975 0-1.521.169-1.805.307-.087.042-.15.082-.195.115Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'fire-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 16a6 6 0 0 0 6-6c0-2.574-1.723-4.088-3.327-5.497C9.163 3.175 7.757 1.94 8 0 3.5 2.5 2 5.5 2 10a6 6 0 0 0 6 6Zm0 0a3 3 0 0 1-3-3c0-2.25.75-3.75 3-5-.121.97.581 1.588 1.337 2.251C10.139 10.956 11 11.713 11 13a3 3 0 0 1-3 3Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'fire': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 16a6 6 0 0 1-6-6C2 5.86 3.27 2.99 6.976.61 7.3.405 7.64.2 8 0c-.05.403-.03.775.048 1.125.297 1.332 1.428 2.326 2.625 3.378C12.277 5.912 14 7.426 14 10a6 6 0 0 1-6 6Zm1.448-1.213A4.998 4.998 0 0 1 8 15c-.503 0-.99-.074-1.448-.213A2.295 2.295 0 0 1 5.7 13c0-1.048.175-1.853.563-2.525.269-.466.66-.902 1.224-1.32.085.192.192.369.312.533.3.41.71.769 1.062 1.077l.083.073c.802.706 1.356 1.264 1.356 2.162 0 .722-.332 1.366-.852 1.787Zm1.317-.62A2.99 2.99 0 0 0 11 13c0-1.287-.861-2.044-1.663-2.749-.538-.472-1.049-.921-1.255-1.49A1.607 1.607 0 0 1 8 8c-.253.14-.487.285-.704.432C5.591 9.597 5 11.003 5 13c0 .414.084.808.235 1.167A4.995 4.995 0 0 1 3 10c0-2.14.357-3.825 1.179-5.25.637-1.106 1.589-2.113 2.985-3.065.168.534.435 1.016.756 1.454.575.782 1.362 1.473 2.072 2.097l.16.14C11.744 6.776 13 8.002 13 10c0 1.74-.888 3.271-2.235 4.167Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'filter-x-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.36 2.067A.625.625 0 0 1 1.802 1h12.396c.557 0 .836.673.442 1.067L9 7.707v5.5l-2 2v-7.5l-5.64-5.64ZM2.707 2 8 7.293 4.293 2H2.707Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.396 10.396a.5.5 0 0 1 .708 0L13 12.293l1.896-1.897a.5.5 0 0 1 .708.708L13.707 13l1.897 1.896a.5.5 0 0 1-.707.708L13 13.707l-1.896 1.897a.5.5 0 0 1-.707-.708L12.293 13l-1.896-1.896a.5.5 0 0 1 0-.708Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'filter-x': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.36 2.067A.625.625 0 0 1 1.802 1h12.396c.557 0 .836.673.442 1.067L9 7.707v5.5l-2 2v-7.5l-5.64-5.64ZM2.707 2 8 7.293 13.293 2H2.707Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.396 10.396a.5.5 0 0 1 .708 0L13 12.293l1.896-1.897a.5.5 0 0 1 .708.708L13.707 13l1.897 1.896a.5.5 0 0 1-.707.708L13 13.707l-1.896 1.897a.5.5 0 0 1-.707-.708L12.293 13l-1.896-1.896a.5.5 0 0 1 0-.708Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'filter-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.36 2.067A.625.625 0 0 1 1.802 1h12.396c.557 0 .836.673.442 1.067L9 7.707v5.5l-2 2v-7.5l-5.64-5.64ZM2.707 2 8 7.293 4.293 2H2.707Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'filter': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.36 2.067A.625.625 0 0 1 1.802 1h12.396c.557 0 .836.673.442 1.067L9 7.707v5.5l-2 2v-7.5l-5.64-5.64ZM2.707 2 8 7.293 13.293 2H2.707Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'film-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.25.5A2.25 2.25 0 0 0 2 2.75v10.5a2.25 2.25 0 0 0 2.25 2.25h7.5A2.25 2.25 0 0 0 14 13.25V2.75A2.25 2.25 0 0 0 11.75.5h-7.5ZM3 2.75c0-.69.56-1.25 1.25-1.25H5V4H3V2.75ZM5 5H3v2.5h2V5ZM3 8.5h2V11H3V8.5ZM3 12h2v2.5h-.75c-.69 0-1.25-.56-1.25-1.25V12Zm10-9.25c0-.69-.56-1.25-1.25-1.25H11V4h2V2.75ZM11 5h2v2.5h-2V5Zm2 3.5h-2V11h2V8.5Zm0 3.5h-2v2.5h.75c.69 0 1.25-.56 1.25-1.25V12Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'film': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.25.5A2.25 2.25 0 0 0 2 2.75v10.5a2.25 2.25 0 0 0 2.25 2.25h7.5A2.25 2.25 0 0 0 14 13.25V2.75A2.25 2.25 0 0 0 11.75.5h-7.5ZM3 2.75c0-.69.56-1.25 1.25-1.25h.875v2.625H3V2.75Zm0 2.125v2.75h2.125v-2.75H3Zm0 3.5v2.75h2.125v-2.75H3Zm0 3.5v1.375c0 .69.56 1.25 1.25 1.25h.875v-2.625H3ZM5.875 14.5h4.25V8.375h-4.25V14.5Zm5 0h.875c.69 0 1.25-.56 1.25-1.25v-1.375h-2.125V14.5ZM13 11.125v-2.75h-2.125v2.75H13Zm0-3.5v-2.75h-2.125v2.75H13Zm0-3.5V2.75c0-.69-.56-1.25-1.25-1.25h-.875v2.625H13ZM10.125 1.5h-4.25v6.125h4.25V1.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'file-text-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 16a2 2 0 0 0 2-2V4.25L9.75 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8ZM9.5 1.5a.5.5 0 0 1 .5.5v1.5a.5.5 0 0 0 .5.5H12a.5.5 0 0 1 0 1h-1.5A1.5 1.5 0 0 1 9 3.5V2a.5.5 0 0 1 .5-.5Zm-5.375 5c0-.207.168-.375.375-.375h3a.375.375 0 1 1 0 .75h-3a.375.375 0 0 1-.375-.375Zm0 2c0-.207.168-.375.375-.375h7a.375.375 0 0 1 0 .75h-7a.375.375 0 0 1-.375-.375Zm0 2c0-.207.168-.375.375-.375h7a.375.375 0 0 1 0 .75h-7a.375.375 0 0 1-.375-.375Zm0 2c0-.207.168-.375.375-.375h5a.375.375 0 0 1 0 .75h-5a.375.375 0 0 1-.375-.375Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'file-text': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M4.5 6.125a.375.375 0 1 0 0 .75h3a.375.375 0 1 0 0-.75h-3ZM4.5 8.125a.375.375 0 1 0 0 .75h7a.375.375 0 0 0 0-.75h-7ZM4.5 10.125a.375.375 0 0 0 0 .75h7a.375.375 0 0 0 0-.75h-7ZM4.5 12.125a.375.375 0 0 0 0 .75h5a.375.375 0 0 0 0-.75h-5Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.75 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.25L9.75 0ZM4 15h8a1 1 0 0 0 1-1V5h-2.5A1.5 1.5 0 0 1 9 3.5V1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1Zm6-13.336L12.336 4H10.5a.5.5 0 0 1-.5-.5V1.664Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'file-plus-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11 15.5c0 .175.03.344.085.5H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h5.75L14 4.25V9.5a1.5 1.5 0 0 0-3 0V11H9.5a1.5 1.5 0 0 0 0 3H11v1.5ZM10 2a.5.5 0 0 0-1 0v1.5A1.5 1.5 0 0 0 10.5 5H12a.5.5 0 0 0 0-1h-1.5a.5.5 0 0 1-.5-.5V2Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M13 9.5a.5.5 0 0 0-1 0V12H9.5a.5.5 0 0 0 0 1H12v2.5a.5.5 0 0 0 1 0V13h2.5a.5.5 0 0 0 0-1H13V9.5Z'/%3e%3c/svg%3e")`,
                'file-plus-circle-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2 2a2 2 0 0 1 2-2h5.707L14 4.293v3.963A4.5 4.5 0 0 0 9.671 16H4a2 2 0 0 1-2-2V2Zm8 0a.5.5 0 0 0-1 0v1.5A1.5 1.5 0 0 0 10.5 5H12a.5.5 0 0 0 0-1h-1.5a.5.5 0 0 1-.5-.5V2Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 12.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0ZM12.5 10a.5.5 0 0 1 .5.5V12h1.5a.5.5 0 0 1 0 1H13v1.75a.5.5 0 0 1-1 0V13h-1.5a.5.5 0 0 1 0-1H12v-1.5a.5.5 0 0 1 .5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'file-plus-circle': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 2a1 1 0 0 1 1-1h5v2a2 2 0 0 0 2 2h2v2.5a.5.5 0 0 0 1 0V4.293L9.707 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h4a.5.5 0 0 0 0-1H4a1 1 0 0 1-1-1V2Zm9.293 2L10 1.707V3a1 1 0 0 0 1 1h1.293Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 12.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0ZM12.5 10a.5.5 0 0 1 .5.5V12h1.5a.5.5 0 0 1 0 1H13v1.75a.5.5 0 0 1-1 0V13h-1.5a.5.5 0 0 1 0-1H12v-1.5a.5.5 0 0 1 .5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'file-plus': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4 1a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h4a.5.5 0 0 1 0 1H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h5.707L14 4.293V7.5a.5.5 0 0 1-1 0V5h-2a2 2 0 0 1-2-2V1H4Zm6 .707L12.293 4H11a1 1 0 0 1-1-1V1.707Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M13 9.5a.5.5 0 0 0-1 0V12H9.5a.5.5 0 0 0 0 1H12v2.5a.5.5 0 0 0 1 0V13h2.5a.5.5 0 0 0 0-1H13V9.5Z'/%3e%3c/svg%3e")`,
                'file-minus': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4 1a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h5a.5.5 0 0 1 0 1H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h5.707L14 4.293V8.5a.5.5 0 0 1-1 0V5h-2a2 2 0 0 1-2-2V1H4Zm6 .707L12.293 4H11a1 1 0 0 1-1-1V1.707Zm.396 8.69a.5.5 0 0 1 .708 0L13 12.292l1.896-1.897a.5.5 0 0 1 .708.708L13.707 13l1.897 1.896a.5.5 0 0 1-.708.708L13 13.707l-1.896 1.897a.5.5 0 0 1-.708-.708L12.293 13l-1.897-1.896a.5.5 0 0 1 0-.708Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'file-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 16a2 2 0 0 0 2-2V4.25L9.75 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8ZM10 2a.5.5 0 0 0-1 0v1.5A1.5 1.5 0 0 0 10.5 5H12a.5.5 0 0 0 0-1h-1.5a.5.5 0 0 1-.5-.5V2Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'file': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4 0h5.75L14 4.25V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2Zm8 15H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5v2.5A1.5 1.5 0 0 0 10.5 5H13v9a1 1 0 0 1-1 1Zm.336-11L10 1.664V3.5a.5.5 0 0 0 .5.5h1.836Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'feather-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M9.707 13h-6L.854 15.853a.5.5 0 1 1-.708-.707L3 12.293v-6l4.818-4.818a4.5 4.5 0 0 1 6.364 0l.343.343a4.5 4.5 0 0 1 0 6.364L13.707 9h-6l5.897-5.897a.5.5 0 0 0-.708-.707l-9.75 9.75a.5.5 0 1 0 .708.707L6.707 10h6l-3 3Z'/%3e%3c/svg%3e")`,
                'feather': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M13.475 2.182a3.5 3.5 0 0 0-4.95 0L4 6.707v4.586l6.146-6.146a.5.5 0 0 1 .708.707L7.707 9h4.586l1.525-1.525a3.5 3.5 0 0 0 0-4.95l-.343-.343ZM11.293 10H6.707l-2 2h4.586l2-2Zm-7.586 3h6l4.818-4.818a4.5 4.5 0 0 0 0-6.364l-.343-.343a4.5 4.5 0 0 0-6.364 0L3 6.293v6L.146 15.147a.5.5 0 1 0 .708.707L3.707 13Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'fast-forward-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='m2.3 11.9 4.667-3.5a.5.5 0 0 0 0-.8L2.3 4.1a.5.5 0 0 0-.8.4v7a.5.5 0 0 0 .8.4ZM9.3 11.9l4.667-3.5a.5.5 0 0 0 0-.8L9.3 4.1a.5.5 0 0 0-.8.4v7a.5.5 0 0 0 .8.4Z'/%3e%3c/svg%3e")`,
                'fast-forward': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.8 3.1a.5.5 0 0 0-.8.4v9a.5.5 0 0 0 .8.4l6-4.5A.5.5 0 0 0 8 8v4.5a.5.5 0 0 0 .8.4l6-4.5a.5.5 0 0 0 0-.8l-6-4.5a.5.5 0 0 0-.8.4V8a.5.5 0 0 0-.2-.4l-6-4.5ZM6.667 8 2 11.5v-7L6.667 8Zm7 0L9 11.5v-7L13.667 8Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'facebook-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 3.5C6 1.567 7.067 0 9 0h2.75a.75.75 0 0 1 .75.75v2a.75.75 0 0 1-.75.75H10a.5.5 0 0 0-.5.5v2h2.153a.75.75 0 0 1 .712.987l-.834 2a.75.75 0 0 1-.711.513H9.5v5.75a.75.75 0 0 1-.75.75h-2a.75.75 0 0 1-.75-.75V9.5H4.75A.75.75 0 0 1 4 8.75v-2A.75.75 0 0 1 4.75 6H6V3.5ZM9 1C7.62 1 7 2.12 7 3.5V7H5v1.5h2V15h1.5V8.5h2.14l.666-1.5H8.5V4A1.5 1.5 0 0 1 10 2.5h1.5V1H9Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M7 3.5C7 2.12 7.62 1 9 1h2.5v1.5H10A1.5 1.5 0 0 0 8.5 4v3h2.806l-.666 1.5H8.5V15H7V8.5H5V7h2V3.5Z'/%3e%3c/svg%3e")`,
                'facebook': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 3.5A3.5 3.5 0 0 1 9.5 0h2.75a.75.75 0 0 1 .75.75v2.5a.75.75 0 0 1-.75.75H10.5a.5.5 0 0 0-.5.5V6h2.153a.75.75 0 0 1 .712.987l-.834 2.5a.75.75 0 0 1-.711.513H10v5.25a.75.75 0 0 1-.75.75h-2.5a.75.75 0 0 1-.75-.75V10H4.75A.75.75 0 0 1 4 9.25v-2.5A.75.75 0 0 1 4.75 6H6V3.5ZM9.5 1A2.5 2.5 0 0 0 7 3.5V7H5v2h2v6h2V9h2.14l.666-2H9V4.5A1.5 1.5 0 0 1 10.5 3H12V1H9.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'eye-off-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.104.396a.5.5 0 1 0-.708.708L3.21 3.917C1.128 5.673 0 8 0 8s2.91 6 8 6c1.534 0 2.87-.545 3.987-1.306l2.91 2.91a.5.5 0 0 0 .707-.708L1.104.396Zm8.299 9.714L5.93 6.637a2.5 2.5 0 0 0 3.472 3.472Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M16 8s-.712 1.468-2.048 2.952l-3.529-3.529a2.504 2.504 0 0 0-1.806-1.806L5.5 2.5C6.262 2.189 7.097 2 8 2c5.09 0 8 6 8 6Z'/%3e%3c/svg%3e")`,
                'eye-off': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.121 1.146a.5.5 0 0 1 .707 0l2.44 2.44 2.338 2.312 3.435 3.435c.042.023.08.052.115.086l2.285 2.285a.5.5 0 0 1 .087.116l2.325 2.326a.5.5 0 0 1-.707.708l-2.133-2.133C10.904 13.457 9.558 14 8 14c-2.588 0-4.586-1.49-5.906-2.91A14.017 14.017 0 0 1 .19 8.48a8.32 8.32 0 0 1-.128-.237l-.007-.014-.002-.005v-.001L.5 8a91.22 91.22 0 0 1-.448-.222v-.001l.002-.003.003-.006.012-.024.046-.088a13.851 13.851 0 0 1 .856-1.365c.516-.724 1.25-1.614 2.191-2.396l-2.04-2.041a.5.5 0 0 1 0-.708Zm2.754 3.458c-.888.722-1.591 1.568-2.089 2.267A12.85 12.85 0 0 0 1.067 8a13.011 13.011 0 0 0 1.76 2.41C4.062 11.74 5.814 13 8 13c1.25 0 2.356-.41 3.309-1.014l-1.53-1.53A3 3 0 0 1 5.57 6.28L3.874 4.604Zm2.417 2.395a2 2 0 0 0 2.75 2.75l-2.75-2.75ZM.5 8l-.448-.222a.502.502 0 0 0 0 .445L.5 8ZM8 3c-.655 0-1.268.113-1.84.305a.5.5 0 0 1-.32-.947A6.728 6.728 0 0 1 8 2c2.588 0 4.586 1.49 5.906 2.91a14.007 14.007 0 0 1 1.904 2.61 8.027 8.027 0 0 1 .127.237l.008.014.002.005v.002L15.5 8l.448.222-.001.002-.002.004-.007.013a5.334 5.334 0 0 1-.115.217 14.136 14.136 0 0 1-1.729 2.427.5.5 0 1 1-.747-.666A13.148 13.148 0 0 0 14.933 8a13.019 13.019 0 0 0-1.76-2.41C11.938 4.26 10.186 3 8 3Zm7.5 5 .448.222a.501.501 0 0 0 0-.444L15.5 8Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'eye-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 2C2.91 2 0 8 0 8s2.91 6 8 6 8-6 8-6-2.91-6-8-6Zm2.5 6.04a2.5 2.5 0 1 1-5 0 2.5 2.5 0 0 1 5 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'eye': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.067 8a13.011 13.011 0 0 0 1.76 2.41C4.062 11.74 5.814 13 8 13s3.937-1.26 5.174-2.59A13.001 13.001 0 0 0 14.933 8a13.003 13.003 0 0 0-1.76-2.41C11.938 4.26 10.186 3 8 3S4.063 4.26 2.826 5.59A13.014 13.014 0 0 0 1.067 8ZM15.5 8l.448-.222-.001-.002-.002-.005-.008-.014a5.964 5.964 0 0 0-.127-.237 14.013 14.013 0 0 0-1.904-2.61C12.586 3.49 10.588 2 8 2 5.412 2 3.414 3.49 2.094 4.91A14.014 14.014 0 0 0 .19 7.52a8.32 8.32 0 0 0-.127.237l-.008.014-.002.005v.001L.5 8l-.448-.223a.502.502 0 0 0 0 .445L.5 8l-.448.222.001.002.002.005.008.014a4.859 4.859 0 0 0 .127.237 14.017 14.017 0 0 0 1.904 2.61C3.414 12.51 5.412 14 8 14c2.588 0 4.586-1.49 5.906-2.91a14.016 14.016 0 0 0 1.904-2.61 8.027 8.027 0 0 0 .127-.237l.008-.014.002-.005v-.002L15.5 8Zm0 0 .448.222a.502.502 0 0 0 0-.444L15.5 8ZM8 6.04a2 2 0 1 0 0 4 2 2 0 0 0 0-4Zm-3 2a3 3 0 1 1 6 0 3 3 0 0 1-6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'external-link': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10 .5a.5.5 0 0 1 .5-.5H16v5.5a.5.5 0 0 1-1 0V1.707L7.854 8.854a.5.5 0 1 1-.708-.708L14.293 1H10.5a.5.5 0 0 1-.5-.5ZM1 4.25A2.25 2.25 0 0 1 3.25 2H7.5a.5.5 0 0 1 0 1H3.25C2.56 3 2 3.56 2 4.25v8.5c0 .69.56 1.25 1.25 1.25h8.5c.69 0 1.25-.56 1.25-1.25V8.5a.5.5 0 0 1 1 0v4.25A2.25 2.25 0 0 1 11.75 15h-8.5A2.25 2.25 0 0 1 1 12.75v-8.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'edit-3-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 17'%3e%3cpath fill='%230E1011' d='m13.207 1.25.586.586a1 1 0 0 1 0 1.414l-1.44 1.44-2-2 1.44-1.44a1 1 0 0 1 1.414 0ZM9.646 3.396 1.5 11.543v2h2l8.146-8.147-2-2ZM.5 15.543a.5.5 0 0 1 .5-.5h14a.5.5 0 0 1 0 1H1a.5.5 0 0 1-.5-.5Z'/%3e%3c/svg%3e")`,
                'edit-3': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 17'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M13.56.896a1.5 1.5 0 0 0-2.12 0L1.145 11.19a.5.5 0 0 0-.146.354v2a.5.5 0 0 0 .5.5h2a.5.5 0 0 0 .354-.147L14.146 3.603a1.5 1.5 0 0 0 0-2.12l-.585-.587Zm-1.414.707a.5.5 0 0 1 .708 0l.585.586a.5.5 0 0 1 0 .707L12 4.336l-1.293-1.293 1.44-1.44ZM10 3.75l1.293 1.293-8 8H2V11.75l8-8Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1 15.043a.5.5 0 0 0 0 1h14a.5.5 0 1 0 0-1H1Z'/%3e%3c/svg%3e")`,
                'edit-2-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='m15.014 1.764-.778-.778a1 1 0 0 0-1.442.029l-1.955 2.117 2.029 2.029 2.117-1.955a1 1 0 0 0 .029-1.442ZM12.151 5.859l-2.01-2.01-8.49 8.254a.5.5 0 0 0-.151.358v1.54a.5.5 0 0 0 .5.5h1.539a.5.5 0 0 0 .358-.152l8.254-8.49Z'/%3e%3c/svg%3e")`,
                'edit-2': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12.44.853a1.5 1.5 0 0 1 2.12 0l.586.586a1.5 1.5 0 0 1 0 2.122L3.854 14.853A.5.5 0 0 1 3.5 15h-2a.5.5 0 0 1-.5-.5v-2a.5.5 0 0 1 .146-.354L12.44.853Zm1.414.708a.5.5 0 0 0-.708 0L11.207 3.5 12.5 4.793l1.94-1.94a.5.5 0 0 0 0-.707l-.586-.585ZM11.793 5.5 10.5 4.207l-8.5 8.5V14h1.293l8.5-8.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'edit': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.56.44a1.5 1.5 0 0 0-2.12 0l-1.647 1.646-.707.707-5.647 5.646c-.408.409-.704 1.25-.845 2.06A5.959 5.959 0 0 0 4.5 11.5c.303 0 .65-.032 1.001-.094.81-.141 1.651-.437 2.06-.845l8-8a1.5 1.5 0 0 0 0-2.122ZM6.147 9.145 11.793 3.5l.707.707-5.646 5.647c-.11.108-.423.286-.942.434a5.52 5.52 0 0 1-.27.07c.021-.09.044-.18.07-.27.148-.52.326-.833.434-.942ZM12.5 2.793l.707.707 1.647-1.646a.5.5 0 0 0-.707-.708l-.705-.704.704.704L12.5 2.793ZM1 3.25A2.25 2.25 0 0 1 3.25 1H8.5a.5.5 0 0 1 0 1H3.25C2.56 2 2 2.56 2 3.25v9.5c0 .69.56 1.25 1.25 1.25h9.5c.69 0 1.25-.56 1.25-1.25V7.5a.5.5 0 0 1 1 0v5.25A2.25 2.25 0 0 1 12.75 15h-9.5A2.25 2.25 0 0 1 1 12.75v-9.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'droplet-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M14 9.806C14 13.227 11.314 16 8 16s-6-2.773-6-6.194C2 6.386 4.5 4.13 8 0c3.5 4.129 6 6.386 6 9.806Z'/%3e%3c/svg%3e")`,
                'droplet': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 15c2.732 0 5-2.295 5-5.194 0-1.43-.51-2.65-1.505-4.061-.708-1.006-1.607-2.037-2.686-3.276-.26-.298-.529-.607-.809-.932-.28.325-.55.634-.81.932-1.078 1.239-1.977 2.27-2.685 3.276C3.51 7.156 3 8.375 3 9.806 3 12.705 5.268 15 8 15ZM7.342.77c-.297.344-.586.675-.865.995C3.797 4.843 2 6.906 2 9.806 2 13.227 4.686 16 8 16s6-2.773 6-6.194c0-2.9-1.797-4.963-4.477-8.04-.28-.32-.568-.652-.865-.996C8.443.52 8.224.264 8 0c-.224.264-.443.52-.658.77Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'download-cloud': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 17'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 3a5 5 0 0 0-2.727 9.192.5.5 0 1 1-.546.837 6 6 0 1 1 8.936-7.015 4 4 0 0 1 2.623 7.269.5.5 0 1 1-.572-.82 3 3 0 0 0-2.305-5.405l-.459.092-.121-.452A5.002 5.002 0 0 0 6 3Zm2.5 5a.5.5 0 0 1 .5.5v5.793l2.146-2.147a.5.5 0 0 1 .708.708L8.5 16.207l-3.354-3.353a.5.5 0 0 1 .708-.708L8 14.293V8.5a.5.5 0 0 1 .5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'download': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 1a.5.5 0 0 1 .5.5v8.793l2.146-2.147a.5.5 0 0 1 .708.708L8 12.207 4.646 8.854a.5.5 0 1 1 .708-.708L7.5 10.293V1.5A.5.5 0 0 1 8 1Zm-6.5 9a.5.5 0 0 1 .5.5V13a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1v-2.5a.5.5 0 0 1 1 0V13a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-2.5a.5.5 0 0 1 .5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'dot-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 12a4 4 0 1 0 0-8 4 4 0 0 0 0 8Z'/%3e%3c/svg%3e")`,
                'dot': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 11a3 3 0 1 0 0-6 3 3 0 0 0 0 6Zm4-3a4 4 0 1 1-8 0 4 4 0 0 1 8 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'dollar-sign': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.5 1.5a.5.5 0 0 0-1 0V2H7a3 3 0 0 0-3 3v.08a3 3 0 0 0 2.227 2.898l1.273.34V13H7a2 2 0 0 1-2-2H4a3 3 0 0 0 3 3h.5v.5a.5.5 0 0 0 1 0V14h1a3 3 0 0 0 3-3v-.08a3 3 0 0 0-2.227-2.898L8.5 7.549V3H9a2 2 0 0 1 2 2h1a3 3 0 0 0-3-3h-.5v-.5ZM7.5 3H7a2 2 0 0 0-2 2v.08a2 2 0 0 0 1.485 1.932l1.015.27V3Zm1 5.584V13h1a2 2 0 0 0 2-2v-.08a2 2 0 0 0-1.485-1.932L8.5 8.584Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'disc-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0ZM11 8a3 3 0 1 1-6 0 3 3 0 0 1 6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'disc': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11 8a3 3 0 1 1-6 0 3 3 0 0 1 6 0Zm-1 0a2 2 0 1 1-4 0 2 2 0 0 1 4 0Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'delete-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.46 3a3 3 0 0 0-2.008.77L.166 7.628a.5.5 0 0 0 0 .744l4.286 3.858A3 3 0 0 0 6.46 13h7.291A2.25 2.25 0 0 0 16 10.75v-5.5A2.25 2.25 0 0 0 13.75 3H6.46Zm1.894 2.646a.5.5 0 1 0-.708.708L9.293 8 7.646 9.646a.5.5 0 0 0 .708.708L10 8.707l1.646 1.647a.5.5 0 0 0 .708-.708L10.707 8l1.647-1.646a.5.5 0 0 0-.708-.708L10 7.293 8.354 5.646Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'delete': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.46 4a2 2 0 0 0-1.339.513L1.247 8l3.874 3.487A2 2 0 0 0 6.46 12h7.291c.69 0 1.25-.56 1.25-1.25v-5.5C15 4.56 14.44 4 13.75 4H6.46Zm-2.008-.23A3 3 0 0 1 6.46 3h7.291A2.25 2.25 0 0 1 16 5.25v5.5A2.25 2.25 0 0 1 13.75 13H6.46a3 3 0 0 1-2.008-.77L.166 8.372a.5.5 0 0 1 0-.744L4.452 3.77Zm3.194 1.876a.5.5 0 0 1 .708 0L10 7.293l1.646-1.647a.5.5 0 0 1 .708.708L10.707 8l1.647 1.646a.5.5 0 0 1-.708.708L10 8.707l-1.646 1.647a.5.5 0 0 1-.708-.708L9.293 8 7.646 6.354a.5.5 0 0 1 0-.708Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'database-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' d='M6 3.857c2.761 0 5-.64 5-1.428C11 1.639 8.761 1 6 1s-5 .64-5 1.429 2.239 1.428 5 1.428Z'/%3e%3cpath fill='%230E1011' d='M6 4.571c2.761 0 5-.64 5-1.428v2.5c0 .986-2.239 1.786-5 1.786s-5-.8-5-1.786v-2.5C1 3.932 3.239 4.57 6 4.57Z'/%3e%3cpath fill='%230E1011' d='M6 8.143c2.761 0 5-.64 5-1.429v2.5C11 10.2 8.761 11 6 11s-5-.8-5-1.786v-2.5c0 .79 2.239 1.429 5 1.429Z'/%3e%3c/svg%3e")`,
                'database-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 5c3.866 0 7-.895 7-2s-3.134-2-7-2-7 .895-7 2 3.134 2 7 2Z'/%3e%3cpath fill='%230E1011' d='M8 6c3.866 0 7-.895 7-2v3.5c0 1.38-3.134 2.5-7 2.5S1 8.88 1 7.5V4c0 1.105 3.134 2 7 2Z'/%3e%3cpath fill='%230E1011' d='M8 11c3.866 0 7-.895 7-2v3.5c0 1.38-3.134 2.5-7 2.5s-7-1.12-7-2.5V9c0 1.105 3.134 2 7 2Z'/%3e%3c/svg%3e")`,
                'database-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M7 4c3.866 0 7-.895 7-2s-3.134-2-7-2-7 .895-7 2 3.134 2 7 2Z'/%3e%3cpath fill='%230E1011' d='M7 5c3.866 0 7-.895 7-2v3.5c0 .223-.082.44-.236.646A5.516 5.516 0 0 0 12.5 7c-1.688 0-3.198.76-4.207 1.957C7.873 8.985 7.442 9 7 9 3.134 9 0 7.88 0 6.5V3c0 1.105 3.134 2 7 2Z'/%3e%3cpath fill='%230E1011' d='M7 12.5c0-.903.218-1.755.603-2.507-.198.005-.4.007-.603.007-3.866 0-7-.895-7-2v3.5C0 12.88 3.134 14 7 14l.207-.001A5.504 5.504 0 0 1 7 12.5Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 12.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0ZM12.5 10a.5.5 0 0 1 .5.5V12h1.5a.5.5 0 0 1 0 1H13v1.5a.5.5 0 0 1-1 0V13h-1.5a.5.5 0 0 1 0-1H12v-1.5a.5.5 0 0 1 .5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'database': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.5.125c-1.423 0-2.699.095-3.628.274C1.41.487 1.012.6.718.746a1.356 1.356 0 0 0-.393.277c-.111.119-.2.28-.2.477V5c0 .104.018.2.05.291l-.05.049v3.535c0 .38.247.682.531.9.293.226.697.42 1.167.579.944.318 2.236.521 3.677.521a.375.375 0 0 0 0-.75c-1.38 0-2.587-.195-3.438-.482-.427-.144-.745-.305-.948-.462C.9 9.018.875 8.91.875 8.875V6.023c.266.154.593.286.959.397.942.285 2.23.455 3.666.455s2.724-.17 3.666-.455c.47-.142.873-.319 1.169-.532.288-.208.54-.503.54-.888V1.5a.697.697 0 0 0-.2-.477 1.356 1.356 0 0 0-.393-.277C9.989.6 9.59.487 9.128.399 8.2.22 6.923.125 5.5.125ZM1.05 1.582A.875.875 0 0 1 .914 1.5a.875.875 0 0 1 .138-.082c.204-.101.526-.199.962-.283C2.878.97 4.103.875 5.5.875c1.398 0 2.622.094 3.487.26.436.084.758.182.962.283.064.031.108.06.138.082a.878.878 0 0 1-.138.082c-.204.101-.526.199-.962.283-.865.166-2.09.26-3.487.26-1.398 0-2.622-.094-3.487-.26-.436-.084-.758-.182-.962-.283Zm9.075.743a5.345 5.345 0 0 1-.997.276c-.929.179-2.205.274-3.628.274s-2.699-.095-3.628-.274a5.345 5.345 0 0 1-.997-.276V5c0 .03.02.129.23.28.2.145.517.292.946.422.853.258 2.064.423 3.449.423 1.385 0 2.596-.165 3.45-.423.428-.13.745-.277.946-.422.209-.151.229-.25.229-.28V2.325Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 9.5a2.5 2.5 0 1 1-5 0 2.5 2.5 0 0 1 5 0ZM9.5 7.6c.22 0 .4.18.4.4v1.1H11a.4.4 0 0 1 0 .8H9.9V11a.4.4 0 0 1-.8 0V9.9H8a.4.4 0 0 1 0-.8h1.1V8c0-.22.18-.4.4-.4Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'database': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.291 1.452C4.514 1.17 6.18 1 8 1c1.821 0 3.486.17 4.709.452.607.14 1.133.314 1.52.525.193.105.374.233.513.389.141.16.258.374.258.634 0 .09-.014.175-.038.254l.038.039V7.5c0 .23-.067.435-.176.617l.176.176V12.5c0 .513-.336.906-.717 1.183-.39.284-.925.52-1.54.71C11.507 14.772 9.831 15 8 15c-1.83 0-3.507-.228-4.743-.608-.615-.19-1.15-.425-1.54-.71-.38-.276-.717-.67-.717-1.182V8.293l.176-.176A1.19 1.19 0 0 1 1 7.5V3.293l.038-.039A.861.861 0 0 1 1 3c0-.26.116-.474.258-.634.139-.156.32-.284.513-.389.387-.21.913-.385 1.52-.525ZM2.036 3c.04.038.109.087.214.145.272.148.697.297 1.266.428C4.646 3.834 6.231 4 8 4c1.769 0 3.354-.166 4.484-.427.569-.13.994-.28 1.266-.428A1.12 1.12 0 0 0 13.964 3a1.119 1.119 0 0 0-.214-.145c-.272-.148-.697-.297-1.266-.428C11.354 2.166 9.769 2 8 2c-1.769 0-3.354.166-4.484.427-.569.13-.994.28-1.266.428A1.12 1.12 0 0 0 2.036 3ZM2 8.867V12.5c0 .04.027.172.305.374.267.194.684.39 1.246.562C4.668 13.78 6.24 14 8 14c1.76 0 3.332-.22 4.45-.564.56-.172.979-.368 1.245-.562.278-.202.305-.335.305-.374V8.867c-.35.203-.78.378-1.257.525C11.507 9.772 9.831 10 8 10c-1.83 0-3.507-.228-4.743-.608A6.098 6.098 0 0 1 2 8.867Zm10.709-4.32c.495-.113.936-.25 1.291-.41V7.5c0 .04-.027.172-.305.374-.267.194-.684.39-1.246.562C11.332 8.78 9.76 9 8 9c-1.76 0-3.332-.22-4.45-.564-.56-.172-.978-.368-1.245-.562C2.027 7.672 2 7.54 2 7.5V4.136c.355.16.796.298 1.291.412C4.514 4.83 6.18 5 8 5c1.821 0 3.486-.17 4.709-.452Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'database': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7 0C5.179 0 3.514.17 2.291.452c-.607.14-1.133.314-1.52.525a1.893 1.893 0 0 0-.513.389A.954.954 0 0 0 0 2v4.5c0 .23.067.435.176.617L0 7.293V11.5c0 .513.336.906.717 1.183.39.284.925.52 1.54.71C3.493 13.772 5.169 14 7 14a.5.5 0 0 0 0-1c-1.76 0-3.332-.22-4.45-.564-.56-.172-.978-.368-1.245-.562C1.027 11.672 1 11.54 1 11.5V7.867c.35.203.78.378 1.257.525C3.493 8.772 5.169 9 7 9c1.83 0 3.507-.228 4.743-.608.615-.19 1.15-.425 1.54-.71.38-.276.717-.67.717-1.182V2a.954.954 0 0 0-.258-.634 1.893 1.893 0 0 0-.513-.389c-.387-.21-.913-.385-1.52-.525C10.486.17 8.82 0 7 0ZM1.25 2.145A1.12 1.12 0 0 1 1.036 2a1.12 1.12 0 0 1 .214-.145c.272-.148.697-.297 1.266-.428C3.646 1.166 5.231 1 7 1c1.769 0 3.354.166 4.484.427.569.13.994.28 1.266.428.105.058.173.107.214.145a1.12 1.12 0 0 1-.214.145c-.272.148-.697.297-1.266.428C10.354 2.834 8.769 3 7 3c-1.769 0-3.354-.166-4.484-.427-.569-.13-.994-.28-1.266-.428ZM13 3.136c-.355.16-.796.298-1.291.412C10.486 3.83 8.82 4 7 4c-1.821 0-3.486-.17-4.709-.452A7.046 7.046 0 0 1 1 3.136V6.5c0 .04.027.172.305.374.267.194.684.39 1.246.562C3.668 7.78 5.24 8 7 8c1.76 0 3.332-.22 4.45-.564.56-.172.979-.368 1.245-.562.278-.202.305-.334.305-.374V3.136Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 12.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0ZM12.5 10a.5.5 0 0 1 .5.5V12h1.5a.5.5 0 0 1 0 1H13v1.5a.5.5 0 0 1-1 0V13h-1.5a.5.5 0 0 1 0-1H12v-1.5a.5.5 0 0 1 .5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'cup-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m5.316 11.286 2.184.596V15h-2a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-2v-3.118l2.184-.596A4.5 4.5 0 0 0 14 6.945V1.5A1.5 1.5 0 0 0 12.5 0h-9A1.5 1.5 0 0 0 2 1.5v5.445a4.5 4.5 0 0 0 3.316 4.341Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1 3a.5.5 0 0 0-1 0v4a.5.5 0 0 0 1 0V3ZM16 3a.5.5 0 0 0-1 0v4a.5.5 0 0 0 1 0V3Z'/%3e%3c/svg%3e")`,
                'cup': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m5.316 11.286 2.184.596V15h-2a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-2v-3.118l2.184-.596A4.5 4.5 0 0 0 14 6.945V1.5A1.5 1.5 0 0 0 12.5 0h-9A1.5 1.5 0 0 0 2 1.5v5.445a4.5 4.5 0 0 0 3.316 4.341ZM3 1.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 .5.5v5.445a3.5 3.5 0 0 1-2.58 3.377l-2.42.66-2.42-.66A3.5 3.5 0 0 1 3 6.945V1.5Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1 3a.5.5 0 0 0-1 0v4a.5.5 0 0 0 1 0V3ZM16 3a.5.5 0 0 0-1 0v4a.5.5 0 0 0 1 0V3Z'/%3e%3c/svg%3e")`,
                'crosshair-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M7.571 11.714v1.841A5.573 5.573 0 0 1 2.445 8.43h1.84a.429.429 0 1 0 0-.858h-1.84A5.573 5.573 0 0 1 7.57 2.445v1.84a.429.429 0 1 0 .858 0v-1.84a5.573 5.573 0 0 1 5.126 5.126h-1.84a.429.429 0 1 0 0 .858h1.84a5.573 5.573 0 0 1-5.126 5.126v-1.84a.429.429 0 1 0-.858 0Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0ZM2 8a6 6 0 1 0 12 0A6 6 0 0 0 2 8Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'crosshair': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0ZM7.5 14.28V13a.5.5 0 0 1 1 0v1.28a6.3 6.3 0 0 0 5.775-5.78H13a.5.5 0 0 1 0-1h1.275A6.3 6.3 0 0 0 8.5 1.72V3a.5.5 0 0 1-1 0V1.72A6.3 6.3 0 0 0 1.715 7.5H3a.5.5 0 1 1 0 1H1.715A6.3 6.3 0 0 0 7.5 14.28Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'crop': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4 1.5a.5.5 0 0 0-1 0V3H1.5a.5.5 0 0 0 0 1H3v6.75A2.25 2.25 0 0 0 5.25 13H12v1.5a.5.5 0 0 0 1 0V13h1.5a.5.5 0 0 0 0-1H13V5.25A2.25 2.25 0 0 0 10.75 3H4V1.5ZM4 4v6.75c0 .69.56 1.25 1.25 1.25H12V5.25C12 4.56 11.44 4 10.75 4H4Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'credit-card-plus': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M2.5 9.125a.375.375 0 1 0 0 .75h5a.375.375 0 1 0 0-.75h-5ZM2.5 11.125a.375.375 0 0 0 0 .75h2a.375.375 0 0 0 0-.75h-2Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 4.25A2.25 2.25 0 0 1 2.25 2h11.5A2.25 2.25 0 0 1 16 4.25V9.5a.5.5 0 0 1-1 0V7H1v4.75c0 .69.56 1.25 1.25 1.25H6.5a.5.5 0 0 1 0 1H2.25A2.25 2.25 0 0 1 0 11.75v-7.5Zm1 0C1 3.56 1.56 3 2.25 3h11.5c.69 0 1.25.56 1.25 1.25V5H1v-.75Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M12.5 9a.5.5 0 0 1 .5.5V12h2.5a.5.5 0 0 1 0 1H13v2.5a.5.5 0 0 1-1 0V13H9.5a.5.5 0 0 1 0-1H12V9.5a.5.5 0 0 1 .5-.5Z'/%3e%3c/svg%3e")`,
                'credit-card-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.25 2A2.25 2.25 0 0 0 0 4.25v7.5A2.25 2.25 0 0 0 2.25 14h11.5A2.25 2.25 0 0 0 16 11.75v-7.5A2.25 2.25 0 0 0 13.75 2H2.25ZM1 7V5h14v2H1Zm1.125 2.5c0-.207.168-.375.375-.375h5a.375.375 0 1 1 0 .75h-5a.375.375 0 0 1-.375-.375Zm0 2c0-.207.168-.375.375-.375h2a.375.375 0 0 1 0 .75h-2a.375.375 0 0 1-.375-.375Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'credit-card': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M2.5 9.125a.375.375 0 1 0 0 .75h5a.375.375 0 1 0 0-.75h-5ZM2.5 11.125a.375.375 0 0 0 0 .75h2a.375.375 0 0 0 0-.75h-2Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 4.25A2.25 2.25 0 0 1 2.25 2h11.5A2.25 2.25 0 0 1 16 4.25v7.5A2.25 2.25 0 0 1 13.75 14H2.25A2.25 2.25 0 0 1 0 11.75v-7.5ZM2.25 3C1.56 3 1 3.56 1 4.25V5h14v-.75C15 3.56 14.44 3 13.75 3H2.25ZM1 11.75V7h14v4.75c0 .69-.56 1.25-1.25 1.25H2.25C1.56 13 1 12.44 1 11.75Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'cpu-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6 6h4v4H6V6Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 1h4V0h1v1h1.5A2.5 2.5 0 0 1 15 3.5V5h1v1h-1v4h1v1h-1v1.5a2.5 2.5 0 0 1-2.5 2.5H11v1h-1v-1H6v1H5v-1H3.5A2.5 2.5 0 0 1 1 12.5V11H0v-1h1V6H0V5h1V3.5A2.5 2.5 0 0 1 3.5 1H5V0h1v1Zm0 4a1 1 0 0 0-1 1v4a1 1 0 0 0 1 1h4a1 1 0 0 0 1-1V6a1 1 0 0 0-1-1H6Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'cpu': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5 6a1 1 0 0 1 1-1h4a1 1 0 0 1 1 1v4a1 1 0 0 1-1 1H6a1 1 0 0 1-1-1V6Zm5 0H6v4h4V6Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 1h4V0h1v1h1.5A2.5 2.5 0 0 1 15 3.5V5h1v1h-1v4h1v1h-1v1.5a2.5 2.5 0 0 1-2.5 2.5H11v1h-1v-1H6v1H5v-1H3.5A2.5 2.5 0 0 1 1 12.5V11H0v-1h1V6H0V5h1V3.5A2.5 2.5 0 0 1 3.5 1H5V0h1v1Zm6.5 1h-9A1.5 1.5 0 0 0 2 3.5v9A1.5 1.5 0 0 0 3.5 14h9a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 12.5 2Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'corner-up-right': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.146 2.146a.5.5 0 0 0 0 .708L13.293 6H6a4 4 0 0 0-4 4v4.5a.5.5 0 0 0 1 0V10a3 3 0 0 1 3-3h7.293l-3.147 3.146a.5.5 0 0 0 .708.708L15.207 6.5l-4.353-4.354a.5.5 0 0 0-.708 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'corner-up-left': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.854 2.146a.5.5 0 0 1 0 .708L2.707 6H10a4 4 0 0 1 4 4v4.5a.5.5 0 1 1-1 0V10a3 3 0 0 0-3-3H2.707l3.147 3.146a.5.5 0 0 1-.708.708L.793 6.5l4.353-4.354a.5.5 0 0 1 .708 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'corner-right-up': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M14.854 5.854a.5.5 0 0 1-.708 0L11 2.707V10a4 4 0 0 1-4 4H2.5a.5.5 0 0 1 0-1H7a3 3 0 0 0 3-3V2.707L6.854 5.854a.5.5 0 1 1-.708-.707L10.5.793l4.354 4.354a.5.5 0 0 1 0 .707Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'corner-right-down': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M14.854 10.146a.5.5 0 0 0-.708 0L11 13.293V6a4 4 0 0 0-4-4H2.5a.5.5 0 0 0 0 1H7a3 3 0 0 1 3 3v7.293l-3.146-3.147a.5.5 0 0 0-.708.708l4.354 4.353 4.354-4.353a.5.5 0 0 0 0-.708Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'corner-left-up': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.146 5.854a.5.5 0 0 0 .708 0L5 2.707V10a4 4 0 0 0 4 4h4.5a.5.5 0 0 0 0-1H9a3 3 0 0 1-3-3V2.707l3.146 3.147a.5.5 0 1 0 .708-.707L5.5.793 1.146 5.147a.5.5 0 0 0 0 .707Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'corner-left-down': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.146 9.146a.5.5 0 0 1 .708 0L5 12.293V5a4 4 0 0 1 4-4h4.5a.5.5 0 0 1 0 1H9a3 3 0 0 0-3 3v7.293l3.146-3.147a.5.5 0 1 1 .708.708L5.5 14.207 1.146 9.854a.5.5 0 0 1 0-.708Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'corner-down-right': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10.146 13.854a.5.5 0 0 1 0-.708L13.293 10H6a4 4 0 0 1-4-4V1.5a.5.5 0 0 1 1 0V6a3 3 0 0 0 3 3h7.293l-3.147-3.146a.5.5 0 0 1 .708-.708L15.207 9.5l-4.353 4.354a.5.5 0 0 1-.708 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'corner-down-left': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.854 13.854a.5.5 0 0 0 0-.708L2.707 10H10a4 4 0 0 0 4-4V1.5a.5.5 0 0 0-1 0V6a3 3 0 0 1-3 3H2.707l3.147-3.146a.5.5 0 0 0-.708-.708L.793 9.5l4.353 4.354a.5.5 0 0 0 .708 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'copy-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M3 1a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h.5a.5.5 0 0 0 0-1H3a1 1 0 0 1-1-1V3a1 1 0 0 1 1-1h6a1 1 0 0 1 1 1v.5a.5.5 0 0 0 1 0V3a2 2 0 0 0-2-2H3Z'/%3e%3cpath fill='%230E1011' d='M7 5a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2V7a2 2 0 0 0-2-2H7Z'/%3e%3c/svg%3e")`,
                'copy': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M3 1a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h.5a.5.5 0 0 0 0-1H3a1 1 0 0 1-1-1V3a1 1 0 0 1 1-1h6a1 1 0 0 1 1 1v.5a.5.5 0 0 0 1 0V3a2 2 0 0 0-2-2H3Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7 5a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2V7a2 2 0 0 0-2-2H7ZM6 7a1 1 0 0 1 1-1h6a1 1 0 0 1 1 1v6a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1V7Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'compass-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='m6.37 9.63 1.12-2.14 2.14-1.12-1.12 2.14-2.14 1.12Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0ZM6.75 6.75 12 4 9.25 9.25 4 12l2.75-5.25Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'compass': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 4 6.75 6.75 4 12l5.25-2.75L12 4ZM7.49 7.49 6.37 9.63l2.14-1.12 1.12-2.14-2.14 1.12Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 0 .695 8a7.3 7.3 0 0 0 14.6 0Zm-1 0A6.3 6.3 0 1 0 1.695 8a6.3 6.3 0 0 0 12.6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'command': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 3.75a2.75 2.75 0 0 1 5.5 0V5.5h3V3.75a2.75 2.75 0 1 1 2.75 2.75H10.5v3h1.75a2.75 2.75 0 1 1-2.75 2.75V10.5h-3v1.75A2.75 2.75 0 1 1 3.75 9.5H5.5v-3H3.75A2.75 2.75 0 0 1 1 3.75ZM5.5 5.5V3.75A1.75 1.75 0 1 0 3.75 5.5H5.5Zm1 1v3h3v-3h-3Zm-1 4H3.75a1.75 1.75 0 1 0 1.75 1.75V10.5Zm5 0v1.75a1.75 1.75 0 1 0 1.75-1.75H10.5Zm0-5h1.75a1.75 1.75 0 1 0-1.75-1.75V5.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'columns-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5.923 15H2.077A1.077 1.077 0 0 1 1 13.923V2.077C1 1.482 1.482 1 2.077 1h3.846C6.518 1 7 1.482 7 2.077v11.846C7 14.518 6.518 15 5.923 15ZM13.923 15h-3.846A1.077 1.077 0 0 1 9 13.923V2.077C9 1.482 9.482 1 10.077 1h3.846C14.518 1 15 1.482 15 2.077v11.846c0 .595-.482 1.077-1.077 1.077Z'/%3e%3c/svg%3e")`,
                'columns': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2 13.5a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-11a.5.5 0 0 0-.5-.5h-3a.5.5 0 0 0-.5.5v11Zm.5 1.5A1.5 1.5 0 0 1 1 13.5v-11A1.5 1.5 0 0 1 2.5 1h3A1.5 1.5 0 0 1 7 2.5v11A1.5 1.5 0 0 1 5.5 15h-3Zm7.5-1.5a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-11a.5.5 0 0 0-.5-.5h-3a.5.5 0 0 0-.5.5v11Zm.5 1.5A1.5 1.5 0 0 1 9 13.5v-11A1.5 1.5 0 0 1 10.5 1h3A1.5 1.5 0 0 1 15 2.5v11a1.5 1.5 0 0 1-1.5 1.5h-3Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'coffee-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5.5A.5.5 0 0 1 4 1v2a.5.5 0 0 1-1 0V1a.5.5 0 0 1 .5-.5Zm3 0A.5.5 0 0 1 7 1v2a.5.5 0 0 1-1 0V1a.5.5 0 0 1 .5-.5Zm3 0a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-1 0V1a.5.5 0 0 1 .5-.5ZM2 6a1 1 0 0 0-1 1v4a2 2 0 0 0 2 2h7a2 2 0 0 0 2-2V6H2Zm11 0v3.691l1.447-.724A1 1 0 0 0 15 8.073V7a1 1 0 0 0-1-1h-1Zm0 4.809 1.894-.947A2 2 0 0 0 16 8.073V7a2 2 0 0 0-2-2H2a2 2 0 0 0-2 2v4a3 3 0 0 0 3 3h7a3 3 0 0 0 3-3v-.191Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1 7a1 1 0 0 1 1-1h10v5a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V7Z'/%3e%3c/svg%3e")`,
                'coffee': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M4 1a.5.5 0 0 0-1 0v2a.5.5 0 0 0 1 0V1ZM7 1a.5.5 0 0 0-1 0v2a.5.5 0 0 0 1 0V1ZM10 1a.5.5 0 0 0-1 0v2a.5.5 0 0 0 1 0V1Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M14.894 9.862 13 10.809V11a3 3 0 0 1-3 3H3a3 3 0 0 1-3-3V7a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v1.073a2 2 0 0 1-1.106 1.789ZM1 7a1 1 0 0 1 1-1h10v5a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V7Zm12 2.691V6h1a1 1 0 0 1 1 1v1.073a1 1 0 0 1-.553.894L13 9.691Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'codepen': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.654 1.084a.75.75 0 0 1 .708 0l7.225 3.867a.75.75 0 0 1 .396.66v4.701a.75.75 0 0 1-.396.662L8.362 14.84a.75.75 0 0 1-.708 0L.43 10.974a.75.75 0 0 1-.396-.662v-4.7A.75.75 0 0 1 .43 4.95l7.225-3.867ZM1.545 5.488l5.963-3.191v3.382l-2.822 1.7-3.14-1.891Zm-.512.859v3.23l2.684-1.615-2.684-1.615Zm3.653 2.199-3.14 1.89 5.962 3.191v-3.382l-2.822-1.7Zm3.822 5.081 5.963-3.19-3.14-1.891-2.823 1.699v3.382ZM12.3 7.962l2.683 1.615v-3.23L12.3 7.962Zm2.171-2.474-3.14 1.89L8.507 5.68V2.297l5.963 3.19Zm-4.11 2.474L8.008 9.378 5.655 7.962l2.353-1.416 2.353 1.416Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'code': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5.687 4.354a.5.5 0 1 0-.708-.708l-4 4a.5.5 0 0 0 0 .708l4 4a.5.5 0 0 0 .708-.708L2.04 8l3.647-3.646ZM11.02 3.646a.5.5 0 1 0-.707.708L13.959 8l-3.646 3.646a.5.5 0 0 0 .707.708l4-4a.5.5 0 0 0 0-.708l-4-4Z'/%3e%3c/svg%3e")`,
                'cloud-snow': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M1 8a5 5 0 0 1 9.829-1.302l.121.452.46-.092a3 3 0 0 1 1.234 5.873.5.5 0 1 0 .213.977 4.001 4.001 0 0 0-1.194-7.894A6.002 6.002 0 0 0 0 8a6.002 6.002 0 0 0 3.818 5.59.5.5 0 1 0 .364-.93A5.002 5.002 0 0 1 1 8Z'/%3e%3cpath fill='%230E1011' d='M6.875 10.5a.375.375 0 0 0-.75 0v.5a.375.375 0 0 0 .75 0v-.5ZM10.875 10.5a.375.375 0 0 0-.75 0v.5a.375.375 0 0 0 .75 0v-.5ZM8.875 11a.375.375 0 0 0-.75 0v.5a.375.375 0 0 0 .75 0V11ZM6.875 12.5a.375.375 0 0 0-.75 0v.5a.375.375 0 0 0 .75 0v-.5ZM10.875 12.5a.375.375 0 0 0-.75 0v.5a.375.375 0 0 0 .75 0v-.5ZM8.875 13a.375.375 0 0 0-.75 0v.5a.375.375 0 0 0 .75 0V13ZM6.875 14.5a.375.375 0 0 0-.75 0v.5a.375.375 0 0 0 .75 0v-.5ZM10.875 14.5a.375.375 0 0 0-.75 0v.5a.375.375 0 0 0 .75 0v-.5ZM8.875 15a.375.375 0 0 0-.75 0v.5a.375.375 0 0 0 .75 0V15Z'/%3e%3c/svg%3e")`,
                'cloud-rain': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M1 8a5 5 0 0 1 9.829-1.302l.121.452.46-.092a3 3 0 0 1 1.234 5.873.5.5 0 1 0 .213.977 4.001 4.001 0 0 0-1.194-7.894A6.002 6.002 0 0 0 0 8a6.002 6.002 0 0 0 3.818 5.59.5.5 0 1 0 .364-.93A5.002 5.002 0 0 1 1 8Z'/%3e%3cpath fill='%230E1011' d='M6.875 10.5a.375.375 0 0 0-.75 0v4a.375.375 0 0 0 .75 0v-4ZM10.875 10.5a.375.375 0 0 0-.75 0v4a.375.375 0 0 0 .75 0v-4ZM8.875 11.5a.375.375 0 0 0-.75 0v4a.375.375 0 0 0 .75 0v-4Z'/%3e%3c/svg%3e")`,
                'cloud-off-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.396.396a.5.5 0 0 1 .708 0l14.5 14.5a.5.5 0 0 1-.708.708l-1.765-1.766A4.002 4.002 0 0 1 12 14H6A6 6 0 0 1 2.453 3.16L.396 1.104a.5.5 0 0 1 0-.708Zm5.082 1.626a6.002 6.002 0 0 1 6.186 3.992 4 4 0 0 1 3.678 6.185l-.338.512L4.408 2.115l1.07-.093Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'cloud-off': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.854.146a.5.5 0 1 0-.707.708L2.453 3.16A6 6 0 0 0 6 14h6c.393 0 .772-.057 1.131-.162l2.016 2.016a.5.5 0 0 0 .707-.708l-15-15ZM12.28 12.987l-9.11-9.11A5 5 0 0 0 6 13h6c.095 0 .188-.004.28-.013Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M16 10c0 .85-.265 1.636-.716 2.284l-.722-.722a3 3 0 0 0-2.815-4.551l-.771.064-.256-.73A5.002 5.002 0 0 0 6 3l-.929-.929a6.002 6.002 0 0 1 6.592 3.943A4 4 0 0 1 16 10Z'/%3e%3c/svg%3e")`,
                'cloud-lightning': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m8.8 8.5-1.2 3.086 2.4.625L6.8 16l1.6-3.086L6 12.29 8.8 8.5Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1 8a5 5 0 0 1 9.829-1.302l.121.452.46-.092a3 3 0 0 1 1.234 5.873.5.5 0 1 0 .213.977 4.001 4.001 0 0 0-1.194-7.894A6.002 6.002 0 0 0 0 8a6.002 6.002 0 0 0 3.818 5.59.5.5 0 1 0 .364-.93A5.002 5.002 0 0 1 1 8Z'/%3e%3c/svg%3e")`,
                'cloud-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 14a6 6 0 1 1 5.663-7.986A4 4 0 1 1 12 14H6Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'cloud-drizzle': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 3a5 5 0 0 0-2.086 9.546l-.417.908a6 6 0 1 1 8.166-7.44 4 4 0 0 1 1.48 7.82l-.286-.958a3.002 3.002 0 0 0-1.448-5.818l-.459.092-.121-.452A5.002 5.002 0 0 0 6 3Zm2.5 6a.5.5 0 0 1 .5.5V12a.5.5 0 0 1-1 0V9.5a.5.5 0 0 1 .5-.5Zm-2 1a.5.5 0 0 1 .5.5V12a.5.5 0 0 1-1 0v-1.5a.5.5 0 0 1 .5-.5Zm4 0a.5.5 0 0 1 .5.5V12a.5.5 0 0 1-1 0v-1.5a.5.5 0 0 1 .5-.5Zm-4 2.855a.5.5 0 0 1 .5.5V14.5a.5.5 0 0 1-1 0v-1.145a.5.5 0 0 1 .5-.5Zm2 0a.5.5 0 0 1 .5.5V15.5a.5.5 0 0 1-1 0v-2.145a.5.5 0 0 1 .5-.5Zm2 0a.5.5 0 0 1 .5.5V14.5a.5.5 0 0 1-1 0v-1.145a.5.5 0 0 1 .5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'cloud': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 3a5 5 0 0 0 0 10h6a3 3 0 1 0-.59-5.942l-.46.092-.121-.452A5.002 5.002 0 0 0 6 3ZM0 8a6 6 0 0 1 11.663-1.986A4 4 0 1 1 12 14H6a6 6 0 0 1-6-6Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'clock-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 .7a7.3 7.3 0 1 0 0 14.6A7.3 7.3 0 0 0 8 .7Zm1.36 2.827a.456.456 0 1 0-.895-.179L7.553 7.91c-.03.15.017.305.124.413l2.738 2.737a.456.456 0 0 0 .645-.645L8.495 7.85l.865-4.323Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'clock': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M9.098 2.51a.5.5 0 0 1 .392.588l-.947 4.738 2.81 2.81a.5.5 0 0 1-.707.708l-3-3a.5.5 0 0 1-.136-.452l1-5a.5.5 0 0 1 .588-.392Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'clipboard-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6 0a1 1 0 0 0-1 1v.5a1 1 0 0 0 1 1h4a1 1 0 0 0 1-1V1a1 1 0 0 0-1-1H6Z'/%3e%3cpath fill='%230E1011' d='M2 3a2 2 0 0 1 2-2v.5a2 2 0 0 0 2 2h4a2 2 0 0 0 2-2V1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V3Z'/%3e%3c/svg%3e")`,
                'clipboard': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.25 1a.25.25 0 0 0-.25.25v.5c0 .138.112.25.25.25h3.5a.25.25 0 0 0 .25-.25v-.5A.25.25 0 0 0 9.75 1h-3.5ZM5.025 1c.116-.57.62-1 1.225-1h3.5c.605 0 1.11.43 1.225 1H12a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1.025Zm0 1H4a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1h-1.025c-.116.57-.62 1-1.225 1h-3.5a1.25 1.25 0 0 1-1.225-1Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'circle-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 15.3A7.3 7.3 0 1 0 8 .7a7.3 7.3 0 0 0 0 14.6Z'/%3e%3c/svg%3e")`,
                'circle': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.995 14.3a6.3 6.3 0 1 0 0-12.6 6.3 6.3 0 0 0 0 12.6Zm0 1a7.3 7.3 0 1 0 0-14.6 7.3 7.3 0 0 0 0 14.6Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'chrome-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 10.4a2.4 2.4 0 0 1-2.078-1.2l-.026-.043a2.4 2.4 0 1 1 4.18.048l-.01.017A2.4 2.4 0 0 1 8 10.4Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0ZM2.87 3.896a.5.5 0 1 0-.867.5L5.02 9.638a3.4 3.4 0 0 0 3.889 1.639L7.08 14.522a.5.5 0 0 0 .871.491l2.977-5.284c.3-.507.471-1.098.471-1.729a3.39 3.39 0 0 0-.992-2.4h3.708a.5.5 0 1 0 0-1H8a3.402 3.402 0 0 0-3.282 2.508L2.87 3.896Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'chrome': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-8.062 6.254 1.677-2.976a3.404 3.404 0 0 1-3.89-1.64L2.406 5.094a6.3 6.3 0 0 0 4.828 9.16Zm1.128.035a6.3 6.3 0 0 0 5.46-8.69h-3.412A3.39 3.39 0 0 1 11.4 8c0 .631-.172 1.222-.471 1.729l-2.569 4.56Zm4.939-9.69H8a3.402 3.402 0 0 0-3.282 2.51L3.013 4.144A6.289 6.289 0 0 1 7.995 1.7a6.295 6.295 0 0 1 5.304 2.9ZM8 10.4a2.4 2.4 0 0 1-2.07-1.184l-.008-.015-.026-.044a2.4 2.4 0 1 1 4.18.048l-.01.017A2.4 2.4 0 0 1 8 10.4Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'chevrons-up': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M4.854 11.854a.5.5 0 0 1-.708-.708l3.5-3.5a.5.5 0 0 1 .708 0l3.5 3.5a.5.5 0 0 1-.708.708L8 8.707l-3.146 3.147Z'/%3e%3cpath fill='%230E1011' d='M4.854 7.854a.5.5 0 1 1-.708-.708l3.5-3.5a.5.5 0 0 1 .708 0l3.5 3.5a.5.5 0 0 1-.708.708L8 4.707 4.854 7.854Z'/%3e%3c/svg%3e")`,
                'chevrons-right': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M4.146 4.854a.5.5 0 1 1 .708-.708l3.5 3.5a.5.5 0 0 1 0 .708l-3.5 3.5a.5.5 0 0 1-.708-.708L7.293 8 4.146 4.854Z'/%3e%3cpath fill='%230E1011' d='M8.146 4.854a.5.5 0 1 1 .708-.708l3.5 3.5a.5.5 0 0 1 0 .708l-3.5 3.5a.5.5 0 0 1-.708-.708L11.293 8 8.146 4.854Z'/%3e%3c/svg%3e")`,
                'chevrons-left': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11.854 4.854a.5.5 0 0 0-.708-.708l-3.5 3.5a.5.5 0 0 0 0 .708l3.5 3.5a.5.5 0 0 0 .708-.708L8.707 8l3.147-3.146Z'/%3e%3cpath fill='%230E1011' d='M7.854 4.854a.5.5 0 1 0-.708-.708l-3.5 3.5a.5.5 0 0 0 0 .708l3.5 3.5a.5.5 0 0 0 .708-.708L4.707 8l3.147-3.146Z'/%3e%3c/svg%3e")`,
                'chevrons-down': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M4.854 4.146a.5.5 0 1 0-.708.708l3.5 3.5a.5.5 0 0 0 .708 0l3.5-3.5a.5.5 0 0 0-.708-.708L8 7.293 4.854 4.146Z'/%3e%3cpath fill='%230E1011' d='M4.854 8.146a.5.5 0 1 0-.708.708l3.5 3.5a.5.5 0 0 0 .708 0l3.5-3.5a.5.5 0 0 0-.708-.708L8 11.293 4.854 8.146Z'/%3e%3c/svg%3e")`,
                'chevron-up': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.396 10.604a.5.5 0 0 0 .708 0L8 6.707l3.896 3.897a.5.5 0 0 0 .708-.708l-4.25-4.25a.5.5 0 0 0-.708 0l-4.25 4.25a.5.5 0 0 0 0 .708Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'chevron-right': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.396 12.604a.5.5 0 0 1 0-.708L9.293 8 5.396 4.104a.5.5 0 1 1 .708-.708l4.25 4.25a.5.5 0 0 1 0 .708l-4.25 4.25a.5.5 0 0 1-.708 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'chevron-left': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.604 12.604a.5.5 0 0 0 0-.708L5.707 8l3.897-3.896a.5.5 0 1 0-.708-.708l-4.25 4.25a.5.5 0 0 0 0 .708l4.25 4.25a.5.5 0 0 0 .708 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'chevron-down': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.396 5.396a.5.5 0 0 1 .708 0L8 9.293l3.896-3.897a.5.5 0 0 1 .708.708l-4.25 4.25a.5.5 0 0 1-.708 0l-4.25-4.25a.5.5 0 0 1 0-.708Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'check-stamp-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.324.523a1.937 1.937 0 0 0-2.648 0l-.746.698c-.343.321-.79.507-1.26.522l-1.021.034a1.937 1.937 0 0 0-1.872 1.872L1.743 4.67c-.015.469-.2.916-.522 1.259l-.698.746a1.937 1.937 0 0 0 0 2.648l.698.746c.321.343.507.79.522 1.26l.034 1.021a1.937 1.937 0 0 0 1.872 1.872l1.022.034c.469.015.916.2 1.259.522l.746.698a1.937 1.937 0 0 0 2.648 0l.746-.698c.343-.321.79-.507 1.26-.522l1.021-.034a1.937 1.937 0 0 0 1.872-1.872l.034-1.022c.015-.469.2-.916.522-1.259l.698-.746a1.937 1.937 0 0 0 0-2.648l-.698-.746a1.937 1.937 0 0 1-.522-1.26l-.034-1.021a1.937 1.937 0 0 0-1.872-1.872l-1.022-.034c-.469-.015-.916-.2-1.259-.522L9.324.523Zm3.03 5.83a.5.5 0 0 0-.708-.707L7.5 9.793 5.354 7.646a.5.5 0 1 0-.708.708L7.5 11.207l4.854-4.853Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'check-stamp': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M12.354 6.354a.5.5 0 0 0-.708-.708L7.5 9.793 5.354 7.646a.5.5 0 1 0-.708.708L7.5 11.207l4.854-4.853Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.676.523a1.937 1.937 0 0 1 2.648 0l.746.698c.343.321.79.507 1.26.522l1.021.034a1.937 1.937 0 0 1 1.872 1.872l.034 1.022c.015.469.2.916.522 1.259l.698.746a1.937 1.937 0 0 1 0 2.648l-.698.746c-.321.343-.507.79-.522 1.26l-.034 1.021a1.937 1.937 0 0 1-1.872 1.872l-1.022.034c-.469.015-.916.2-1.259.522l-.746.698a1.937 1.937 0 0 1-2.648 0l-.746-.698a1.937 1.937 0 0 0-1.26-.522l-1.021-.034a1.937 1.937 0 0 1-1.872-1.872l-.034-1.022c-.015-.469-.2-.916-.522-1.259l-.698-.746a1.937 1.937 0 0 1 0-2.648l.698-.746c.321-.343.507-.79.522-1.26l.034-1.021a1.937 1.937 0 0 1 1.872-1.872l1.022-.034c.469-.015.916-.2 1.259-.522l.746-.698Zm1.964.73.747.698c.52.487 1.198.768 1.91.792l1.021.033c.493.017.89.413.906.906l.034 1.022c.023.711.304 1.39.79 1.91l.7.746c.336.36.336.92 0 1.28l-.7.747a2.937 2.937 0 0 0-.79 1.91l-.034 1.021a.937.937 0 0 1-.906.906l-1.022.034a2.937 2.937 0 0 0-1.91.79l-.746.7a.937.937 0 0 1-1.28 0l-.747-.7a2.937 2.937 0 0 0-1.91-.79l-1.021-.034a.937.937 0 0 1-.906-.906l-.033-1.022a2.937 2.937 0 0 0-.792-1.91l-.698-.746a.937.937 0 0 1 0-1.28l.698-.747c.487-.52.768-1.198.792-1.91l.033-1.021a.937.937 0 0 1 .906-.906l1.022-.033a2.937 2.937 0 0 0 1.91-.792l.746-.698a.937.937 0 0 1 1.28 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'check-square-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 1A2.5 2.5 0 0 0 1 3.5v9A2.5 2.5 0 0 0 3.5 15h9a2.5 2.5 0 0 0 2.5-2.5v-9A2.5 2.5 0 0 0 12.5 1h-9Zm8.854 4.147a.5.5 0 0 1 0 .707l-5 5a.5.5 0 0 1-.708 0l-2.5-2.5a.5.5 0 1 1 .708-.707L7 9.793l4.646-4.646a.5.5 0 0 1 .708 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'check-square': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M12.354 5.147a.5.5 0 0 1 0 .707l-5 5a.5.5 0 0 1-.708 0l-2.5-2.5a.5.5 0 1 1 .708-.707L7 9.793l4.646-4.646a.5.5 0 0 1 .708 0Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 3.5A2.5 2.5 0 0 1 3.5 1h9A2.5 2.5 0 0 1 15 3.5v9a2.5 2.5 0 0 1-2.5 2.5h-9A2.5 2.5 0 0 1 1 12.5v-9ZM3.5 2h9A1.5 1.5 0 0 1 14 3.5v9a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 2 12.5v-9A1.5 1.5 0 0 1 3.5 2Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'check-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M14.207 3.793a1 1 0 0 1 0 1.414L6.5 12.914l-4-4A1 1 0 1 1 3.914 7.5L6.5 10.086l6.293-6.293a1 1 0 0 1 1.414 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'check-circle-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-2.94-2.854a.5.5 0 0 1 0 .708l-5 5a.5.5 0 0 1-.708 0l-2.5-2.5a.5.5 0 1 1 .708-.708L7 9.793l4.646-4.647a.5.5 0 0 1 .708 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'check-circle': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M12.354 5.146a.5.5 0 0 1 0 .708l-5 5a.5.5 0 0 1-.708 0l-2.5-2.5a.5.5 0 1 1 .708-.708L7 9.793l4.646-4.647a.5.5 0 0 1 .708 0Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'check': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M13.854 4.146a.5.5 0 0 1 0 .708L6.5 12.207 2.146 7.854a.5.5 0 1 1 .708-.708L6.5 10.793l6.646-6.647a.5.5 0 0 1 .708 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'cast-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.25 2A2.25 2.25 0 0 0 0 4.25v7.5A2.25 2.25 0 0 0 2.25 14h11.5A2.25 2.25 0 0 0 16 11.75v-7.5A2.25 2.25 0 0 0 13.75 2H2.25Zm.25 3a.5.5 0 0 0 0 1H3a5 5 0 0 1 5 5v.5a.5.5 0 0 0 1 0V11a6 6 0 0 0-6-6h-.5Zm0 3a.5.5 0 0 0 0 1H3a2 2 0 0 1 2 2v.5a.5.5 0 0 0 1 0V11a3 3 0 0 0-3-3h-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'cast': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M2.5 5a.5.5 0 0 0 0 1H3a5 5 0 0 1 5 5v.5a.5.5 0 0 0 1 0V11a6 6 0 0 0-6-6h-.5Z'/%3e%3cpath fill='%230E1011' d='M2.5 8a.5.5 0 0 0 0 1H3a2 2 0 0 1 2 2v.5a.5.5 0 0 0 1 0V11a3 3 0 0 0-3-3h-.5Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.25 2A2.25 2.25 0 0 0 0 4.25v7.5A2.25 2.25 0 0 0 2.25 14h11.5A2.25 2.25 0 0 0 16 11.75v-7.5A2.25 2.25 0 0 0 13.75 2H2.25ZM1 4.25C1 3.56 1.56 3 2.25 3h11.5c.69 0 1.25.56 1.25 1.25v7.5c0 .69-.56 1.25-1.25 1.25H2.25C1.56 13 1 12.44 1 11.75v-7.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'caret-up-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m8 4.481-4.978 5.69a.5.5 0 0 0 .376.829h9.204a.5.5 0 0 0 .376-.83L8 4.482Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'caret-up': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m8 4.481-4.978 5.69a.5.5 0 0 0 .376.829h9.204a.5.5 0 0 0 .376-.83L8 4.482ZM8 6l3.5 4h-7L8 6Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'caret-down-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 11.52 3.022 5.83a.5.5 0 0 1 .376-.829h9.204a.5.5 0 0 1 .376.83L8 11.52Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'caret-down': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 11.52 3.022 5.83a.5.5 0 0 1 .376-.829h9.204a.5.5 0 0 1 .376.83L8 11.52Zm0-1.518 3.5-4h-7l3.5 4Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'camera-off-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.104.396a.5.5 0 1 0-.708.708l1.046 1.045A2.25 2.25 0 0 0 0 4.25v7.5A2.25 2.25 0 0 0 2.25 14h11.043l1.603 1.604a.5.5 0 0 0 .708-.708L1.104.396Zm9.349 10.764-.715-.715a3 3 0 0 1-4.184-4.184l-.714-.714a4 4 0 0 0 5.613 5.613ZM6.118 6.825a1.866 1.866 0 0 0-.243.925V8h.75v-.25c0-.126.02-.246.059-.36l-.566-.564Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M16 11.75c0 .364-.086.707-.24 1.01L11.9 8.9a4 4 0 0 0-4.797-4.797L4.645 1.645 5 1.293A1 1 0 0 1 5.707 1h4.586a1 1 0 0 1 .707.293l.707.707h2.043A2.25 2.25 0 0 1 16 4.25v7.5Z'/%3e%3cpath fill='%230E1011' d='M11 8a3 3 0 0 0-3-3l3 3Z'/%3e%3c/svg%3e")`,
                'camera-off': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.104.396a.5.5 0 1 0-.708.708l1.046 1.045A2.25 2.25 0 0 0 0 4.25v7.5A2.25 2.25 0 0 0 2.25 14h11.043l1.603 1.604a.5.5 0 0 0 .708-.708L1.104.396ZM2.25 3h.043l2.636 2.636a3.875 3.875 0 0 0 5.434 5.434l1.93 1.93H2.25C1.56 13 1 12.44 1 11.75v-7.5C1 3.56 1.56 3 2.25 3Zm7.578 7.535L5.465 6.172a3.125 3.125 0 0 0 4.363 4.363Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M5.707 1A1 1 0 0 0 5 1.293l-.354.353a.5.5 0 1 0 .708.708L5.707 2h4.586l.707.707a1 1 0 0 0 .707.293h2.043c.69 0 1.25.56 1.25 1.25v7.5c0 .16-.03.312-.084.452a.5.5 0 0 0 .932.361c.098-.253.152-.527.152-.813v-7.5A2.25 2.25 0 0 0 13.75 2h-2.043L11 1.293A1 1 0 0 0 10.293 1H5.707Z'/%3e%3cpath fill='%230E1011' d='M7.58 4.903a3.125 3.125 0 0 1 3.516 3.516.375.375 0 1 0 .745.1 3.875 3.875 0 0 0-4.36-4.36.375.375 0 0 0 .1.744Z'/%3e%3c/svg%3e")`,
                'camera-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 5a3 3 0 1 0 0 6 3 3 0 0 0 0-6ZM5.875 7.75c0-1.036.84-1.875 1.875-1.875H8v.75h-.25c-.621 0-1.125.504-1.125 1.125V8h-.75v-.25Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5.707 1A1 1 0 0 0 5 1.293L4.293 2H2.25A2.25 2.25 0 0 0 0 4.25v7.5A2.25 2.25 0 0 0 2.25 14h11.5A2.25 2.25 0 0 0 16 11.75v-7.5A2.25 2.25 0 0 0 13.75 2h-2.043L11 1.293A1 1 0 0 0 10.293 1H5.707ZM4 8a4 4 0 1 1 8 0 4 4 0 0 1-8 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'camera': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M5.875 7.75c0-1.036.84-1.875 1.875-1.875H8v.75h-.25c-.621 0-1.125.504-1.125 1.125V8h-.75v-.25Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 4a4 4 0 1 0 0 8 4 4 0 0 0 0-8ZM5 8a3 3 0 1 1 6 0 3 3 0 0 1-6 0Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M5 1.293A1 1 0 0 1 5.707 1h4.586a1 1 0 0 1 .707.293l.707.707h2.043A2.25 2.25 0 0 1 16 4.25v7.5A2.25 2.25 0 0 1 13.75 14H2.25A2.25 2.25 0 0 1 0 11.75v-7.5A2.25 2.25 0 0 1 2.25 2h2.043L5 1.293ZM10.293 2H5.707L5 2.707A1 1 0 0 1 4.293 3H2.25C1.56 3 1 3.56 1 4.25v7.5c0 .69.56 1.25 1.25 1.25h11.5c.69 0 1.25-.56 1.25-1.25v-7.5C15 3.56 14.44 3 13.75 3h-2.043A1 1 0 0 1 11 2.707L10.293 2Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'calendar-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M10 .5a.5.5 0 0 1 1 0V1h2.75A2.25 2.25 0 0 1 16 3.25v9.5A2.25 2.25 0 0 1 13.75 15H2.25A2.25 2.25 0 0 1 0 12.75v-9.5A2.25 2.25 0 0 1 2.25 1H5V.5a.5.5 0 0 1 1 0V1h4V.5Zm4.875 5a.375.375 0 0 0-.375-.375h-13a.375.375 0 1 0 0 .75h13a.375.375 0 0 0 .375-.375Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'calendar': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M10 .5a.5.5 0 0 1 1 0v2a.5.5 0 0 1-1 0v-2ZM5 .5a.5.5 0 0 1 1 0v2a.5.5 0 0 1-1 0v-2Z'/%3e%3cpath fill='%230E1011' d='M15 3.25C15 2.56 14.44 2 13.75 2H12.5a.5.5 0 0 1 0-1h1.25A2.25 2.25 0 0 1 16 3.25v9.5A2.25 2.25 0 0 1 13.75 15H2.25A2.25 2.25 0 0 1 0 12.75v-9.5A2.25 2.25 0 0 1 2.25 1H3.5a.5.5 0 0 1 0 1H2.25C1.56 2 1 2.56 1 3.25v9.5c0 .69.56 1.25 1.25 1.25h11.5c.69 0 1.25-.56 1.25-1.25v-9.5Z'/%3e%3cpath fill='%230E1011' d='M9 2H7V1h2v1ZM13.5 5.125a.375.375 0 0 1 0 .75h-11a.375.375 0 1 1 0-.75h11Z'/%3e%3c/svg%3e")`,
                'briefcase-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6.625 8.5v-.625h2.75V8.5c0 .345-.28.625-.625.625h-1.5a.625.625 0 0 1-.625-.625Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 1a1 1 0 0 0-1 1v1H1.25C.56 3 0 3.56 0 4.25v8.5C0 13.44.56 14 1.25 14h13.5c.69 0 1.25-.56 1.25-1.25v-8.5C16 3.56 15.44 3 14.75 3H11V2a1 1 0 0 0-1-1H6Zm4 2H6V2h4v1ZM1.5 7.125a.375.375 0 1 0 0 .75h4.375V8.5c0 .76.616 1.375 1.375 1.375h1.5c.76 0 1.375-.616 1.375-1.375v-.625H14.5a.375.375 0 0 0 0-.75h-13Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'briefcase': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6 1a1 1 0 0 0-1 1v1H2a2 2 0 0 0-2 2v7a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V5a2 2 0 0 0-2-2h-3V2a1 1 0 0 0-1-1H6Zm4 2H6V2h4v1ZM1 5a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1v2.125H1V5Zm0 2.875V12a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V7.875h-4.875V8.5c0 .76-.616 1.375-1.375 1.375h-1.5c-.76 0-1.375-.616-1.375-1.375v-.625H1Zm5.625.625v-.625h2.75V8.5c0 .345-.28.625-.625.625h-1.5a.625.625 0 0 1-.625-.625Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'box-wire': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8.142.084A.5.5 0 0 0 8 .09a.5.5 0 0 0-.142-.007 1.5 1.5 0 0 0-.415.1l-2.438.975a.5.5 0 0 0 .372.929l2.437-.975a.5.5 0 0 1 .138-.034A.508.508 0 0 0 8 1.073a.508.508 0 0 0 .047.006.5.5 0 0 1 .139.034l2.437.975a.5.5 0 1 0 .372-.929L8.557.184a1.5 1.5 0 0 0-.415-.1ZM3.752 2.738a.5.5 0 1 0-.372-.929l-2.437.975a1.499 1.499 0 0 0-.547.377.498.498 0 0 0-.11.194.498.498 0 0 0-.139.174A1.498 1.498 0 0 0 0 4.177v2.867a.5.5 0 1 0 1 0V4.24l2.127.85a.5.5 0 0 0 .371-.928L1.846 3.5l1.906-.762ZM12.62 1.81a.5.5 0 1 0-.372.928l1.906.762-1.652.66a.5.5 0 1 0 .371.93L15 4.238v2.805a.5.5 0 0 0 1 0V4.177c0-.229-.052-.45-.147-.648a.498.498 0 0 0-.139-.174.5.5 0 0 0-.11-.194 1.5 1.5 0 0 0-.547-.377L12.62 1.81ZM16 8.956a.5.5 0 0 0-1 0v2.867c0 .076-.017.15-.049.216a.486.486 0 0 0-.027.07.504.504 0 0 0-.056.053.498.498 0 0 1-.182.125l-2.438.975a.5.5 0 0 0 .372.929l2.437-.975a1.5 1.5 0 0 0 .547-.377.5.5 0 0 0 .11-.194.497.497 0 0 0 .139-.174c.095-.199.147-.42.147-.648V8.956ZM1 8.956a.5.5 0 1 0-1 0v2.867c0 .229.052.45.147.648.034.07.082.129.139.174.02.07.057.136.11.194a1.5 1.5 0 0 0 .547.377l2.437.975a.5.5 0 1 0 .372-.929l-2.438-.975a.499.499 0 0 1-.182-.125.507.507 0 0 0-.055-.052.503.503 0 0 0-.028-.071.498.498 0 0 1-.049-.216V8.956ZM5.377 13.912a.5.5 0 0 0-.372.929l2.438.975c.134.053.273.087.415.1A.5.5 0 0 0 8 15.91a.5.5 0 0 0 .142.007c.142-.013.281-.047.415-.1l2.438-.975a.5.5 0 1 0-.372-.929l-2.123.85v-2.637a.5.5 0 0 0-1 0v2.636l-2.123-.849ZM5.373 4.91a.5.5 0 0 0-.371.93l2.498.999v3.036a.5.5 0 1 0 1 0V6.839l2.498-1a.5.5 0 1 0-.371-.928L8 5.96l-2.627-1.05Z'/%3e%3c/svg%3e")`,
                'box-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.47.633.619 3.055A1 1 0 0 0 0 3.979v8.042a1 1 0 0 0 .618.924l5.853 2.422a4 4 0 0 0 3.058 0l5.853-2.422a1 1 0 0 0 .618-.924V3.98a1 1 0 0 0-.618-.924L9.53.633a4 4 0 0 0-3.058 0Zm-4.519 3.16a.5.5 0 1 0-.402.915L7.5 7.326V14a.5.5 0 1 0 1 0V7.326l5.951-2.618a.5.5 0 0 0-.402-.916L8 6.454 1.951 3.792Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'box': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.557.184a1.5 1.5 0 0 0-1.114 0l-6.5 2.6A1.5 1.5 0 0 0 0 4.177v7.646a1.5 1.5 0 0 0 .943 1.393l6.5 2.6a1.5 1.5 0 0 0 1.114 0l6.5-2.6A1.5 1.5 0 0 0 16 11.823V4.177a1.5 1.5 0 0 0-.943-1.393l-6.5-2.6Zm-.743.929a.5.5 0 0 1 .372 0l6.102 2.441L8 6.069 1.712 3.554l6.102-2.441ZM1.002 4.132A.499.499 0 0 0 1 4.177v7.646a.5.5 0 0 0 .314.464L7.6 14.802V6.77L1.002 4.13ZM8.4 14.802l6.286-2.515a.5.5 0 0 0 .314-.464V4.177c0-.015 0-.03-.002-.045L8.4 6.77v8.03Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'bookmark-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.25 1C3.56 1 3 1.56 3 2.25v12.33l4.728-3.07a.5.5 0 0 1 .544 0L13 14.58V2.25C13 1.56 12.44 1 11.75 1h-7.5ZM2 2.25A2.25 2.25 0 0 1 4.25 0h7.5A2.25 2.25 0 0 1 14 2.25V15.5a.5.5 0 0 1-.772.42L8 12.524l-5.228 3.394A.5.5 0 0 1 2 15.5V2.25Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M3 2.25C3 1.56 3.56 1 4.25 1h7.5c.69 0 1.25.56 1.25 1.25v12.33l-4.728-3.07a.5.5 0 0 0-.544 0L3 14.58V2.25Z'/%3e%3c/svg%3e")`,
                'bookmark': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.25 1C3.56 1 3 1.56 3 2.25v12.33l4.728-3.07a.5.5 0 0 1 .544 0L13 14.58V2.25C13 1.56 12.44 1 11.75 1h-7.5ZM2 2.25A2.25 2.25 0 0 1 4.25 0h7.5A2.25 2.25 0 0 1 14 2.25V15.5a.5.5 0 0 1-.772.42L8 12.524l-5.228 3.394A.5.5 0 0 1 2 15.5V2.25Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'book-open-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.777 2.084A.5.5 0 0 1 16 2.5v11a.5.5 0 0 1-.735.441l-.003-.001-.013-.007a4.84 4.84 0 0 0-.278-.134 9.907 9.907 0 0 0-.596-.25v.951a.375.375 0 0 1-.458.366l-5.182-1.178a9.28 9.28 0 0 0-.487.222l-.013.007-.003.001a.5.5 0 0 1-.464 0l-.003-.001-.013-.007a7.272 7.272 0 0 0-.487-.222l-5.182 1.178a.375.375 0 0 1-.458-.366v-.95a9.908 9.908 0 0 0-.874.383l-.013.007H.736A.5.5 0 0 1 0 13.5v-11a.5.5 0 0 1 .223-.416l.001-.001.002-.001.006-.004.017-.011.062-.038a7.19 7.19 0 0 1 1.042-.496A8.169 8.169 0 0 1 4.25 1c1.237 0 2.26.412 2.967.816.329.188.593.376.783.525.19-.149.454-.337.783-.525C9.49 1.412 10.513 1 11.75 1c1.199 0 2.197.266 2.897.533a7.19 7.19 0 0 1 1.042.496l.062.038.017.011.006.004.002.001.001.001Zm-5.682 11.144 3.53.802v-.732c-.572-.167-1.228-.297-1.876-.298a6.714 6.714 0 0 0-1.655.228ZM4.25 13a6.714 6.714 0 0 1 1.655.228l-3.531.802v-.732C2.947 13.13 3.603 13 4.251 13ZM8.5 3.5c0-.483-.224-.875-.5-.875s-.5.392-.5.875V12c0 .483.224.875.5.875s.5-.392.5-.875V3.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'book-open': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m7.767 13.918-.002-.001-.013-.007a7.272 7.272 0 0 0-.487-.222l-5.182 1.178a.375.375 0 0 1-.458-.366v-.95a9.908 9.908 0 0 0-.874.383l-.013.007H.736A.5.5 0 0 1 0 13.5v-11a.5.5 0 0 1 .223-.416L.5 2.5l-.277-.416.001-.001.002-.001.006-.004.017-.011.062-.038a7.19 7.19 0 0 1 1.042-.496A8.169 8.169 0 0 1 4.25 1c1.237 0 2.26.412 2.967.816.329.188.593.376.783.525.19-.149.454-.337.783-.525C9.49 1.412 10.513 1 11.75 1c1.199 0 2.197.266 2.897.533a7.19 7.19 0 0 1 1.042.496l.062.038.017.011.006.004.002.001s.001.001-.276.417l.277-.416A.5.5 0 0 1 16 2.5v11a.5.5 0 0 1-.736.441l-.002-.001-.013-.007a4.84 4.84 0 0 0-.278-.134 9.907 9.907 0 0 0-.596-.25v.951a.375.375 0 0 1-.458.366l-5.182-1.178a9.28 9.28 0 0 0-.487.222l-.013.007h-.002a.503.503 0 0 1-.466 0ZM1 12.722V2.788l.005-.003c.16-.085.398-.201.704-.318A7.169 7.169 0 0 1 4.25 2c1.013 0 1.865.338 2.47.684a5.47 5.47 0 0 1 .78.54v9.48c-.15-.061-.319-.126-.503-.19-.728-.253-1.726-.516-2.748-.514-1.023.002-2.02.271-2.749.53-.183.065-.351.13-.5.192Zm9.095.506 3.53.802v-.732c-.572-.167-1.228-.297-1.876-.298a6.714 6.714 0 0 0-1.655.228ZM4.25 13a6.714 6.714 0 0 1 1.655.228l-3.531.802v-.732C2.947 13.13 3.603 13 4.251 13Zm4.249-.297c.15-.06.319-.124.503-.189.728-.253 1.726-.516 2.748-.514 1.023.002 2.02.271 2.749.53.183.065.351.13.5.192V2.788l-.005-.003a6.201 6.201 0 0 0-.704-.318A7.17 7.17 0 0 0 11.75 2c-1.013 0-1.865.338-2.47.684a5.47 5.47 0 0 0-.78.54v9.48Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'book-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2 2.25A2.25 2.25 0 0 1 4.25 0H14v12.5a.5.5 0 0 1-.637.481V15h.137a.5.5 0 0 1 0 1H4.25A2.25 2.25 0 0 1 2 13.75V2.25ZM4.25 15a1.25 1.25 0 0 1-1.243-1.122 1.125 1.125 0 0 1 1.118-1.003h8.488V15H4.25Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'book': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4.25 0A2.25 2.25 0 0 0 2 2.25v11.5A2.25 2.25 0 0 0 4.25 16h9.25a.5.5 0 0 0 0-1h-.137v-2.019A.5.5 0 0 0 14 12.5V0H4.25ZM13 12.125V1H4.25C3.56 1 3 1.56 3 2.25V12.5a1.867 1.867 0 0 1 1.125-.375H13Zm-9.993 1.753A1.25 1.25 0 0 0 4.25 15h8.363v-2.125H4.125c-.58 0-1.058.44-1.118 1.003Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'bold': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3.5 1.875a.625.625 0 1 0 0 1.25h.375v9.75H3.5a.625.625 0 1 0 0 1.25h6a3.625 3.625 0 0 0 1.648-6.855A3.125 3.125 0 0 0 9 1.875H3.5Zm5.5 5a1.875 1.875 0 0 0 0-3.75H5.125v3.75H9Zm-3.875 1.25v4.75H9.5a2.375 2.375 0 1 0 0-4.75H5.125Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'bluetooth': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.309.038a.5.5 0 0 1 .545.108l4 4a.5.5 0 0 1 0 .708L8.707 8l3.147 3.146a.5.5 0 0 1 0 .708l-4 4A.5.5 0 0 1 7 15.5V9.707l-2.146 2.147a.5.5 0 0 1-.708-.707L7 8.293v-.586L4.146 4.854a.5.5 0 1 1 .708-.708L7 6.293V.5a.5.5 0 0 1 .309-.462ZM8 8.708v5.585l2.793-2.793L8 8.707Zm0-1.415L10.793 4.5 8 1.707v5.586Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'bell-off-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='black' fill-rule='evenodd' d='M.854.146a.5.5 0 1 0-.708.708L3.38 4.086A4.985 4.985 0 0 0 3 6v1.343a3.5 3.5 0 0 1-1.025 2.475l-.536.536A1.5 1.5 0 0 0 1 11.414V12a1 1 0 0 0 1 1h10.293l2.853 2.854a.5.5 0 0 0 .708-.708l-15-15Zm4.88 6.296-.72-.722A3.003 3.003 0 0 0 5 6a.5.5 0 0 0 .735.442ZM15 12a.997.997 0 0 1-.293.707L6.586 4.586A2 2 0 0 1 8 4a.5.5 0 0 0 0-1 3 3 0 0 0-2.121.879L4.464 2.464A5 5 0 0 1 13 6v1.343a3.5 3.5 0 0 0 1.025 2.475l.536.536a1.5 1.5 0 0 1 .439 1.06V12Zm-7 4a2.5 2.5 0 0 1-2.5-2.5h1a1.5 1.5 0 0 0 3 0h1A2.5 2.5 0 0 1 8 16Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'bell-off': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='black' fill-rule='evenodd' d='M.854.146a.5.5 0 1 0-.708.708L3.38 4.086A4.985 4.985 0 0 0 3 6v1.343a3.5 3.5 0 0 1-1.025 2.475l-.536.536A1.5 1.5 0 0 0 1 11.414V12a1 1 0 0 0 1 1h10.293l2.853 2.854a.5.5 0 0 0 .708-.708l-15-15ZM11.293 12 5.735 6.442A.5.5 0 0 1 5 6c0-.094.004-.187.013-.28l-.85-.85A4.001 4.001 0 0 0 4 6v1.343a4.5 4.5 0 0 1-1.318 3.182l-.536.536a.5.5 0 0 0-.146.353V12h9.293ZM8 1c-1.38 0-2.63.56-3.536 1.464l.708.708A4 4 0 0 1 12 6v1.343a4.5 4.5 0 0 0 1.318 3.182l.536.536a.5.5 0 0 1 .146.353V12l.707.707A.997.997 0 0 0 15 12v-.586a1.5 1.5 0 0 0-.44-1.06l-.535-.536A3.5 3.5 0 0 1 13 7.343V6a5 5 0 0 0-5-5ZM5.879 3.879l.707.707A2 2 0 0 1 8 4a.5.5 0 0 0 0-1 3 3 0 0 0-2.121.879ZM8 16a2.5 2.5 0 0 1-2.5-2.5h1a1.5 1.5 0 0 0 3 0h1A2.5 2.5 0 0 1 8 16Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'bell-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 16a2.5 2.5 0 0 1-2.5-2.5h1a1.5 1.5 0 0 0 3 0h1A2.5 2.5 0 0 1 8 16Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 1a5 5 0 0 0-5 5v1.343a3.5 3.5 0 0 1-1.025 2.475l-.536.536A1.5 1.5 0 0 0 1 11.414V12a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-.586a1.5 1.5 0 0 0-.44-1.06l-.535-.536A3.5 3.5 0 0 1 13 7.343V6a5 5 0 0 0-5-5ZM6.586 4.586A2 2 0 0 1 8 4a.5.5 0 0 0 0-1 3 3 0 0 0-3 3 .5.5 0 0 0 1 0 2 2 0 0 1 .586-1.414Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'bell': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M3 6a5 5 0 0 1 10 0v1.343a3.5 3.5 0 0 0 1.025 2.475l.536.536a1.5 1.5 0 0 1 .439 1.06V12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1v-.586c0-.398.158-.78.44-1.06l.535-.536A3.5 3.5 0 0 0 3 7.343V6Zm5-4a4 4 0 0 0-4 4v1.343a4.5 4.5 0 0 1-1.318 3.182l-.536.536a.5.5 0 0 0-.146.353V12h12v-.586a.5.5 0 0 0-.146-.353l-.536-.536A4.5 4.5 0 0 1 12 7.343V6a4 4 0 0 0-4-4Zm0 14a2.5 2.5 0 0 1-2.5-2.5h1a1.5 1.5 0 0 0 3 0h1A2.5 2.5 0 0 1 8 16ZM6.586 4.586A2 2 0 0 1 8 4a.5.5 0 0 0 0-1 3 3 0 0 0-3 3 .5.5 0 0 0 1 0 2 2 0 0 1 .586-1.414Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'battery-charging': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M7.5 7 9 2 5.25 8 8 9l-1.5 5 3.75-6L7.5 7ZM1 5.25C1 4.56 1.56 4 2.25 4H4.5a.5.5 0 0 0 0-1H2.25A2.25 2.25 0 0 0 0 5.25v5.5A2.25 2.25 0 0 0 2.25 13H4.5a.5.5 0 0 0 0-1H2.25C1.56 12 1 11.44 1 10.75v-5.5Z'/%3e%3cpath fill='%230E1011' d='M10.5 3a.5.5 0 0 0 0 1h2.25c.69 0 1.25.56 1.25 1.25v5.5c0 .69-.56 1.25-1.25 1.25H10.5a.5.5 0 0 0 0 1h2.25A2.25 2.25 0 0 0 15 10.75V10h.25a.75.75 0 0 0 .75-.75v-2a.75.75 0 0 0-.75-.75H15V5.25A2.25 2.25 0 0 0 12.75 3H10.5Z'/%3e%3c/svg%3e")`,
                'battery': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.688 3a.937.937 0 0 0-.938.938v4.124c0 .518.42.938.938.938h7.875c.517 0 .937-.42.937-.938V3.939A.937.937 0 0 0 9.562 3H1.689ZM0 3.938C0 3.006.756 2.25 1.688 2.25h7.875c.931 0 1.687.756 1.687 1.688v.937h.188c.31 0 .562.252.562.563v1.5c0 .31-.252.562-.563.562h-.187v.563c0 .931-.755 1.687-1.688 1.687H1.689A1.688 1.688 0 0 1 0 8.062V3.939Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1.5 4.125c0-.207.168-.375.375-.375h7.5c.207 0 .375.168.375.375v3.75a.375.375 0 0 1-.375.375h-7.5a.375.375 0 0 1-.375-.375v-3.75Z'/%3e%3c/svg%3e")`,
                'battery': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.688 3a.937.937 0 0 0-.938.938v4.124c0 .518.42.938.938.938h7.875c.517 0 .937-.42.937-.938V3.939A.937.937 0 0 0 9.562 3H1.689ZM0 3.938C0 3.006.756 2.25 1.688 2.25h7.875c.931 0 1.687.756 1.687 1.688v.937h.188c.31 0 .562.252.562.563v1.5c0 .31-.252.562-.563.562h-.187v.563c0 .931-.755 1.687-1.688 1.687H1.689A1.688 1.688 0 0 1 0 8.062V3.939Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1.5 4.125c0-.207.168-.375.375-.375h3.75c.207 0 .375.168.375.375v3.75a.375.375 0 0 1-.375.375h-3.75a.375.375 0 0 1-.375-.375v-3.75Z'/%3e%3c/svg%3e")`,
                'battery': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 12 12'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.688 3a.937.937 0 0 0-.938.938v4.124c0 .518.42.938.938.938h7.875c.517 0 .937-.42.937-.938V3.939A.937.937 0 0 0 9.562 3H1.689ZM0 3.938C0 3.006.756 2.25 1.688 2.25h7.875c.931 0 1.687.756 1.687 1.688v.937h.188c.31 0 .562.252.562.563v1.5c0 .31-.252.562-.563.562h-.187v.563c0 .931-.755 1.687-1.688 1.687H1.689A1.688 1.688 0 0 1 0 8.062V3.939Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M1.5 4.125c0-.207.168-.375.375-.375h1.5c.207 0 .375.168.375.375v3.75a.375.375 0 0 1-.375.375h-1.5a.375.375 0 0 1-.375-.375v-3.75Z'/%3e%3c/svg%3e")`,
                'battery': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.25 4C1.56 4 1 4.56 1 5.25v5.5c0 .69.56 1.25 1.25 1.25h10.5c.69 0 1.25-.56 1.25-1.25v-5.5C14 4.56 13.44 4 12.75 4H2.25ZM0 5.25A2.25 2.25 0 0 1 2.25 3h10.5A2.25 2.25 0 0 1 15 5.25V6.5h.25a.75.75 0 0 1 .75.75v2a.75.75 0 0 1-.75.75H15v.75A2.25 2.25 0 0 1 12.75 13H2.25A2.25 2.25 0 0 1 0 10.75v-5.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'battery': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.25 4C1.56 4 1 4.56 1 5.25v5.5c0 .69.56 1.25 1.25 1.25h10.5c.69 0 1.25-.56 1.25-1.25v-5.5C14 4.56 13.44 4 12.75 4H2.25ZM0 5.25A2.25 2.25 0 0 1 2.25 3h10.5A2.25 2.25 0 0 1 15 5.25V6.5h.25a.75.75 0 0 1 .75.75v2a.75.75 0 0 1-.75.75H15v.75A2.25 2.25 0 0 1 12.75 13H2.25A2.25 2.25 0 0 1 0 10.75v-5.5Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M2 5.5a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v5a.5.5 0 0 1-.5.5h-10a.5.5 0 0 1-.5-.5v-5Z'/%3e%3c/svg%3e")`,
                'battery': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.25 4C1.56 4 1 4.56 1 5.25v5.5c0 .69.56 1.25 1.25 1.25h10.5c.69 0 1.25-.56 1.25-1.25v-5.5C14 4.56 13.44 4 12.75 4H2.25ZM0 5.25A2.25 2.25 0 0 1 2.25 3h10.5A2.25 2.25 0 0 1 15 5.25V6.5h.25a.75.75 0 0 1 .75.75v2a.75.75 0 0 1-.75.75H15v.75A2.25 2.25 0 0 1 12.75 13H2.25A2.25 2.25 0 0 1 0 10.75v-5.5Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M2 5.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 .5.5v5a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5v-5Z'/%3e%3c/svg%3e")`,
                'battery': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.25 4C1.56 4 1 4.56 1 5.25v5.5c0 .69.56 1.25 1.25 1.25h10.5c.69 0 1.25-.56 1.25-1.25v-5.5C14 4.56 13.44 4 12.75 4H2.25ZM0 5.25A2.25 2.25 0 0 1 2.25 3h10.5A2.25 2.25 0 0 1 15 5.25V6.5h.25a.75.75 0 0 1 .75.75v2a.75.75 0 0 1-.75.75H15v.75A2.25 2.25 0 0 1 12.75 13H2.25A2.25 2.25 0 0 1 0 10.75v-5.5Z' clip-rule='evenodd'/%3e%3cpath fill='%230E1011' d='M2 5.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v5a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-5Z'/%3e%3c/svg%3e")`,
                'bar-chart-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11 2v12a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1h-2a1 1 0 0 0-1 1ZM6 6v8a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1V6a1 1 0 0 0-1-1H7a1 1 0 0 0-1 1ZM1 10v4a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1v-4a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1Z'/%3e%3c/svg%3e")`,
                'bar-chart-2-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11 6.5V14a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1V6.5a1 1 0 0 0-1-1h-2a1 1 0 0 0-1 1ZM6 2v12a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H7a1 1 0 0 0-1 1ZM1 9v5a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1V9a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1Z'/%3e%3c/svg%3e")`,
                'bar-chart-2': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.5 2a.5.5 0 0 0-.5.5v11a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-11a.5.5 0 0 0-.5-.5h-1ZM6 2.5A1.5 1.5 0 0 1 7.5 1h1A1.5 1.5 0 0 1 10 2.5v11A1.5 1.5 0 0 1 8.5 15h-1A1.5 1.5 0 0 1 6 13.5v-11Zm6.5 4a.5.5 0 0 0-.5.5v6.5a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5V7a.5.5 0 0 0-.5-.5h-1ZM11 7a1.5 1.5 0 0 1 1.5-1.5h1A1.5 1.5 0 0 1 15 7v6.5a1.5 1.5 0 0 1-1.5 1.5h-1a1.5 1.5 0 0 1-1.5-1.5V7ZM2.5 9a.5.5 0 0 0-.5.5v4a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-4a.5.5 0 0 0-.5-.5h-1ZM1 9.5A1.5 1.5 0 0 1 2.5 8h1A1.5 1.5 0 0 1 5 9.5v4A1.5 1.5 0 0 1 3.5 15h-1A1.5 1.5 0 0 1 1 13.5v-4Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'bar-chart': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12.5 2a.5.5 0 0 0-.5.5v11a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-11a.5.5 0 0 0-.5-.5h-1Zm-1.5.5A1.5 1.5 0 0 1 12.5 1h1A1.5 1.5 0 0 1 15 2.5v11a1.5 1.5 0 0 1-1.5 1.5h-1a1.5 1.5 0 0 1-1.5-1.5v-11ZM7.5 6a.5.5 0 0 0-.5.5v7a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-7a.5.5 0 0 0-.5-.5h-1ZM6 6.5A1.5 1.5 0 0 1 7.5 5h1A1.5 1.5 0 0 1 10 6.5v7A1.5 1.5 0 0 1 8.5 15h-1A1.5 1.5 0 0 1 6 13.5v-7ZM2.5 10a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5h-1Zm-1.5.5A1.5 1.5 0 0 1 2.5 9h1A1.5 1.5 0 0 1 5 10.5v3A1.5 1.5 0 0 1 3.5 15h-1A1.5 1.5 0 0 1 1 13.5v-3Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'award-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 10A5 5 0 1 0 8 0a5 5 0 0 0 0 10ZM4.006 15.424l.82-5.331C5.746 10.668 6.835 11 8 11a5.972 5.972 0 0 0 3.174-.907l.82 5.331a.5.5 0 0 1-.742.51L8 14.076l-3.252 1.858a.5.5 0 0 1-.742-.51Z'/%3e%3c/svg%3e")`,
                'award': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 0a5 5 0 0 0-3.005 8.996l-.99 6.428a.5.5 0 0 0 .743.51L8 14.076l3.252 1.858a.5.5 0 0 0 .742-.51l-.989-6.428A5 5 0 0 0 8 0ZM4 5a4 4 0 1 1 8 0 4 4 0 0 1-8 0Zm6.079 4.549A4.982 4.982 0 0 1 8 10a4.982 4.982 0 0 1-2.079-.451l-.77 5.003 2.6-1.486a.5.5 0 0 1 .497 0l2.6 1.486-.77-5.003Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'at-sign': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 0C5.791 0 3.79.896 2.343 2.343a8 8 0 1 0 11.314 11.314.5.5 0 0 0-.707-.707A7 7 0 1 1 15 8v.75a1.75 1.75 0 1 1-3.5 0V5a.5.5 0 0 0-1 0v.55a3.5 3.5 0 1 0 .33 4.508A2.75 2.75 0 0 0 16 8.75V8a8 8 0 0 0-8-8Zm2.5 8a2.5 2.5 0 1 0-5 0 2.5 2.5 0 0 0 5 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'arrow-up-right': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 4.5a.5.5 0 0 0-.5-.5h-6a.5.5 0 0 0 0 1h4.793l-6.147 6.146a.5.5 0 0 0 .708.708L11 5.707V10.5a.5.5 0 0 0 1 0v-6Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'arrow-up-left': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4 4.5a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1H5.707l6.147 6.146a.5.5 0 0 1-.708.708L5 5.707V10.5a.5.5 0 0 1-1 0v-6Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'arrow-up-down': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11.146 14.854a.5.5 0 0 0 .708 0l4-4a.5.5 0 0 0-.708-.708L12 13.293V3.5a.5.5 0 0 0-1 0v9.793l-3.146-3.147a.5.5 0 0 0-.708.708l4 4ZM4.146 1.146a.5.5 0 0 1 .708 0l4 4a.5.5 0 1 1-.708.708L5 2.707V12.5a.5.5 0 0 1-1 0V2.707L.854 5.854a.5.5 0 1 1-.708-.708l4-4Z'/%3e%3c/svg%3e")`,
                'arrow-up-circle-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-3.94.354a.5.5 0 0 1-.708 0L8.5 6.207V11a.5.5 0 0 1-1 0V6.207L5.354 8.354a.5.5 0 0 1-.708-.708l3-3a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1 0 .708Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'arrow-up-circle': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11.354 8.354a.5.5 0 0 1-.708 0L8.5 6.207V11a.5.5 0 0 1-1 0V6.207L5.354 8.354a.5.5 0 0 1-.708-.708l3-3a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1 0 .708Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'arrow-up': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.646 7.354a.5.5 0 0 1 0-.708l5-5a.5.5 0 0 1 .708 0l5 5a.5.5 0 0 1-.708.708L8.5 3.207V14a.5.5 0 0 1-1 0V3.207L3.354 7.354a.5.5 0 0 1-.708 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'arrow-right-circle-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 .706a7.3 7.3 0 1 0 0 14.599 7.3 7.3 0 0 0 0-14.6Zm-.354 3.94a.5.5 0 0 0 0 .708L9.793 7.5H5a.5.5 0 1 0 0 1h4.793l-2.147 2.146a.5.5 0 1 0 .708.708l3-3a.5.5 0 0 0 0-.707l-3-3a.5.5 0 0 0-.708 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'arrow-right-circle': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M7.646 4.647a.5.5 0 0 0 0 .707L9.793 7.5H5a.5.5 0 1 0 0 1h4.793l-2.147 2.146a.5.5 0 1 0 .708.708l3-3a.5.5 0 0 0 0-.707l-3-3a.5.5 0 0 0-.708 0Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 .706a7.3 7.3 0 1 0 0 14.599 7.3 7.3 0 0 0 0-14.6Zm0 1a6.3 6.3 0 1 0 0 12.599 6.3 6.3 0 0 0 0-12.6Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'arrow-right': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8.646 2.646a.5.5 0 0 1 .708 0l5 5a.5.5 0 0 1 0 .708l-5 5a.5.5 0 0 1-.708-.708L12.793 8.5H2a.5.5 0 0 1 0-1h10.793L8.646 3.354a.5.5 0 0 1 0-.708Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'arrow-left-right': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M1.146 4.854a.5.5 0 0 1 0-.708l4-4a.5.5 0 1 1 .708.708L2.707 4H12.5a.5.5 0 0 1 0 1H2.707l3.147 3.146a.5.5 0 1 1-.708.708l-4-4ZM14.854 11.854a.5.5 0 0 0 0-.708l-4-4a.5.5 0 0 0-.708.708L13.293 11H3.5a.5.5 0 0 0 0 1h9.793l-3.147 3.146a.5.5 0 0 0 .708.708l4-4Z'/%3e%3c/svg%3e")`,
                'arrow-left-circle-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 .706a7.3 7.3 0 1 1 0 14.599 7.3 7.3 0 0 1 0-14.6Zm.354 3.94a.5.5 0 0 1 0 .708L6.207 7.5H11a.5.5 0 0 1 0 1H6.207l2.147 2.146a.5.5 0 0 1-.708.708l-3-3a.5.5 0 0 1 0-.707l3-3a.5.5 0 0 1 .708 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'arrow-left-circle': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8.354 4.647a.5.5 0 0 1 0 .707L6.207 7.5H11a.5.5 0 0 1 0 1H6.207l2.147 2.146a.5.5 0 0 1-.708.708l-3-3a.5.5 0 0 1 0-.707l3-3a.5.5 0 0 1 .708 0Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 .706a7.3 7.3 0 1 1 0 14.599 7.3 7.3 0 0 1 0-14.6Zm0 1a6.3 6.3 0 1 1 0 12.599 6.3 6.3 0 0 1 0-12.6Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'arrow-left': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M7.854 2.646a.5.5 0 0 0-.708 0l-5 5a.5.5 0 0 0 0 .708l5 5a.5.5 0 0 0 .708-.708L3.707 8.5H14.5a.5.5 0 0 0 0-1H3.707l4.147-4.146a.5.5 0 0 0 0-.708Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'arrow-down-right': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M12 11.5a.5.5 0 0 1-.5.5h-6a.5.5 0 0 1 0-1h4.793L4.146 4.854a.5.5 0 1 1 .708-.708L11 10.293V5.5a.5.5 0 0 1 1 0v6Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'arrow-down-left': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M4 11.5a.5.5 0 0 0 .5.5h6a.5.5 0 0 0 0-1H5.707l6.147-6.146a.5.5 0 0 0-.708-.708L5 10.293V5.5a.5.5 0 0 0-1 0v6Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'arrow-down-circle-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M.706 8a7.3 7.3 0 1 1 14.599 0 7.3 7.3 0 0 1-14.6 0Zm3.94-.353a.5.5 0 0 1 .708 0L7.5 9.793V5a.5.5 0 0 1 1 0v4.793l2.146-2.146a.5.5 0 1 1 .707.707l-3 3a.5.5 0 0 1-.707 0l-3-3a.5.5 0 0 1 0-.707Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'arrow-down-circle': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M11.354 7.647a.5.5 0 0 0-.708 0L8.5 9.793V5a.5.5 0 0 0-1 0v4.793L5.354 7.647a.5.5 0 1 0-.708.707l3 3a.5.5 0 0 0 .708 0l3-3a.5.5 0 0 0 0-.707Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 0 .695 8a7.3 7.3 0 0 0 14.6 0Zm-1 0A6.3 6.3 0 1 0 1.695 8a6.3 6.3 0 0 0 12.6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'arrow-down': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.646 8.646a.5.5 0 0 0 0 .708l5 5a.5.5 0 0 0 .708 0l5-5a.5.5 0 0 0-.708-.708L8.5 12.793V2a.5.5 0 0 0-1 0v10.793L3.354 8.646a.5.5 0 0 0-.708 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'archive-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M0 3a1 1 0 0 1 1-1h14a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1v5.75A2.25 2.25 0 0 1 12.75 14h-9.5A2.25 2.25 0 0 1 1 11.75V6a1 1 0 0 1-1-1V3Zm1.75 2.5a.5.5 0 0 1 .5-.5h11.5a.5.5 0 0 1 0 1H2.25a.5.5 0 0 1-.5-.5Zm4.375 2.75c0-.207.168-.375.375-.375h3a.375.375 0 1 1 0 .75h-3a.375.375 0 0 1-.375-.375Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'archive': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M6.5 8a.25.25 0 0 0 0 .5h3a.25.25 0 0 0 0-.5h-3Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1 2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1v5.75A2.25 2.25 0 0 0 3.25 14h9.5A2.25 2.25 0 0 0 15 11.75V6a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H1Zm1 9.75V6h12v5.75c0 .69-.56 1.25-1.25 1.25h-9.5C2.56 13 2 12.44 2 11.75ZM1 3h14v2H1V3Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'appearance': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M14.294 8a6.3 6.3 0 0 1-6.3 6.3V11H8a3 3 0 1 0 0-6h-.005V1.7a6.3 6.3 0 0 1 6.3 6.3Zm-6.3-3a3 3 0 0 0 0 6V5Zm7.3 3A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'aperture-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-7.907 6.408a.356.356 0 0 1-.13-.486l1.67-2.892H2.5a.356.356 0 1 1 0-.713h3.34L2.625 4.752a.356.356 0 1 1 .617-.357l1.67 2.892 3.213-5.565a.356.356 0 0 1 .617.356L7.073 4.97H13.5a.356.356 0 0 1 0 .712h-3.34l3.214 5.566a.356.356 0 1 1-.617.356l-1.67-2.892-3.213 5.566a.356.356 0 0 1-.487.13Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'aperture': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-2.34 3.886a6.289 6.289 0 0 1-5.091 2.412l3.224-5.586 1.77 3.065c.025.044.058.08.097.109Zm.43-.622L10.16 5.682H13.7c.05 0 .099-.01.142-.03.292.726.452 1.518.452 2.348a6.27 6.27 0 0 1-.91 3.264Zm.135-6.294H7.073l1.77-3.065a.355.355 0 0 0 .046-.142 6.304 6.304 0 0 1 4.63 3.207ZM8.137 1.702A6.288 6.288 0 0 0 3.04 4.109c.04.03.076.067.103.113l1.77 3.065 3.224-5.585ZM2.611 4.727A6.27 6.27 0 0 0 1.695 8c0 .831.161 1.625.454 2.351a.354.354 0 0 1 .151-.034h3.54L2.61 4.728Zm-.14 6.303a6.304 6.304 0 0 0 4.64 3.208.355.355 0 0 1 .046-.143l1.77-3.065H2.47Zm6.867-5.348L10.676 8l-1.338 2.317H6.662L5.324 8l1.338-2.318h2.676Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'anchor': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M8 1.5a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3ZM5.5 3a2.5 2.5 0 1 1 3 2.45v9.033c2.954-.198 5.238-2.152 5.479-4.983H13a.5.5 0 0 1 0-1h2V9c0 3.917-3.188 6.5-7 6.5S1 12.917 1 9v-.5h2a.5.5 0 0 1 0 1h-.979c.241 2.831 2.525 4.785 5.479 4.983V5.45A2.5 2.5 0 0 1 5.5 3Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'align-right': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.5 3.5A.5.5 0 0 1 2 3h12a.5.5 0 0 1 0 1H2a.5.5 0 0 1-.5-.5Zm4 3A.5.5 0 0 1 6 6h8a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5Zm-4 3A.5.5 0 0 1 2 9h12a.5.5 0 0 1 0 1H2a.5.5 0 0 1-.5-.5Zm4 3A.5.5 0 0 1 6 12h8a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'align-left': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.5 3.5A.5.5 0 0 1 2 3h12a.5.5 0 0 1 0 1H2a.5.5 0 0 1-.5-.5Zm0 3A.5.5 0 0 1 2 6h8a.5.5 0 0 1 0 1H2a.5.5 0 0 1-.5-.5Zm0 3A.5.5 0 0 1 2 9h12a.5.5 0 0 1 0 1H2a.5.5 0 0 1-.5-.5Zm0 3A.5.5 0 0 1 2 12h8a.5.5 0 0 1 0 1H2a.5.5 0 0 1-.5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'align-justify': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.5 3.5A.5.5 0 0 1 2 3h12a.5.5 0 0 1 0 1H2a.5.5 0 0 1-.5-.5Zm0 3A.5.5 0 0 1 2 6h12a.5.5 0 0 1 0 1H2a.5.5 0 0 1-.5-.5Zm0 3A.5.5 0 0 1 2 9h12a.5.5 0 0 1 0 1H2a.5.5 0 0 1-.5-.5Zm0 3A.5.5 0 0 1 2 12h12a.5.5 0 0 1 0 1H2a.5.5 0 0 1-.5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'align-center': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M1.5 3.5A.5.5 0 0 1 2 3h12a.5.5 0 0 1 0 1H2a.5.5 0 0 1-.5-.5Zm2 3A.5.5 0 0 1 4 6h8a.5.5 0 0 1 0 1H4a.5.5 0 0 1-.5-.5Zm-2 3A.5.5 0 0 1 2 9h12a.5.5 0 0 1 0 1H2a.5.5 0 0 1-.5-.5Zm2 3A.5.5 0 0 1 4 12h8a.5.5 0 0 1 0 1H4a.5.5 0 0 1-.5-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'alert-triangle-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M9.547.921C8.889-.32 7.11-.32 6.453.921L.36 12.431A1.75 1.75 0 0 0 1.907 15h12.186a1.75 1.75 0 0 0 1.547-2.569L9.547.921ZM8 4.5a.5.5 0 0 1 .5.5v3.5a.5.5 0 1 1-1 0V5a.5.5 0 0 1 .5-.5ZM8 10a.5.5 0 0 1 .5.5v.5a.5.5 0 1 1-1 0v-.5A.5.5 0 0 1 8 10Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'alert-triangle': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 4.5a.5.5 0 0 1 .5.5v3.5a.5.5 0 1 1-1 0V5a.5.5 0 0 1 .5-.5ZM8 10a.5.5 0 0 1 .5.5v.5a.5.5 0 1 1-1 0v-.5A.5.5 0 0 1 8 10Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.453.921C7.111-.32 8.89-.32 9.547.921l6.093 11.51A1.75 1.75 0 0 1 14.093 15H1.907A1.75 1.75 0 0 1 .36 12.431L6.453.921Zm2.21.468 6.093 11.51A.75.75 0 0 1 14.093 14H1.907a.75.75 0 0 1-.663-1.1L7.337 1.39a.75.75 0 0 1 1.326 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'alert-octagon-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M11.312 0H4.688L0 4.688v6.624L4.688 16h6.624L16 11.312V4.688L11.312 0ZM8.875 5a.875.875 0 1 0-1.75 0v3.5a.875.875 0 1 0 1.75 0V5Zm0 5.5a.875.875 0 0 0-1.75 0v.5a.875.875 0 1 0 1.75 0v-.5Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'alert-octagon': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 4.5a.5.5 0 0 1 .5.5v3.5a.5.5 0 0 1-1 0V5a.5.5 0 0 1 .5-.5ZM8 10a.5.5 0 0 1 .5.5v.5a.5.5 0 1 1-1 0v-.5A.5.5 0 0 1 8 10Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='m11.003.75 4.247 4.247v6.006l-4.247 4.247H4.997L.75 11.003V4.997L4.997.75h6.006Zm-5.592 1h5.178l3.661 3.661v5.178l-3.661 3.661H5.41L1.75 10.589V5.41L5.411 1.75Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'alert-circle-filled': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0ZM8 4.5a.5.5 0 0 1 .5.5v3.5a.5.5 0 0 1-1 0V5a.5.5 0 0 1 .5-.5ZM8 10a.5.5 0 0 1 .5.5v.5a.5.5 0 1 1-1 0v-.5A.5.5 0 0 1 8 10Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'alert-circle': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' d='M8 4.5a.5.5 0 0 1 .5.5v3.5a.5.5 0 0 1-1 0V5a.5.5 0 0 1 .5-.5ZM8 10a.5.5 0 0 1 .5.5v.5a.5.5 0 1 1-1 0v-.5A.5.5 0 0 1 8 10Z'/%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M15.294 8A7.3 7.3 0 1 1 .695 8a7.3 7.3 0 0 1 14.6 0Zm-1 0A6.3 6.3 0 1 1 1.695 8a6.3 6.3 0 0 1 12.6 0Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'airplay': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M2.25 3C1.56 3 1 3.56 1 4.25v6.5c0 .69.56 1.25 1.25 1.25H3.5a.5.5 0 0 1 0 1H2.25A2.25 2.25 0 0 1 0 10.75v-6.5A2.25 2.25 0 0 1 2.25 2h11.5A2.25 2.25 0 0 1 16 4.25v6.5A2.25 2.25 0 0 1 13.75 13H12.5a.5.5 0 0 1 0-1h1.25c.69 0 1.25-.56 1.25-1.25v-6.5C15 3.56 14.44 3 13.75 3H2.25ZM8 9.186 12.522 15H3.478L8 9.186ZM5.522 14h4.956L8 10.814 5.522 14Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
                'activity': `url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath fill='%230E1011' fill-rule='evenodd' d='M6.53 1.5a.5.5 0 0 1 .455.379l2.616 10.465 1.932-5.023A.5.5 0 0 1 12 7h3.5a.5.5 0 0 1 0 1h-3.157l-2.376 6.18a.5.5 0 0 1-.952-.059L6.399 3.656 4.467 8.68A.5.5 0 0 1 4 9H.5a.5.5 0 0 1 0-1h3.157l2.376-6.18a.5.5 0 0 1 .498-.32Z' clip-rule='evenodd'/%3e%3c/svg%3e")`,
            }
        }
    )

    matchUtilities(
        {
            'icon': (value) => ({
                '--icon-size': value
            })
        },
        {
            values: {
                'sm': 'var(--icon-size-sm)',
                'base': 'var(--icon-size-base)',
                'md': 'var(--icon-size-md)',
                'lg': 'var(--icon-size-lg)',
                'xl': 'var(--icon-size-xl)',
                'xl2': 'var(--icon-size-xl2)',
                'xl3': 'var(--icon-size-xl3)',
                'xl4': 'var(--icon-size-xl4)',
                'xl5': 'var(--icon-size-xl5)',
            }
        }
    )
});